(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1056466,      29398]*)
(*NotebookOutlinePosition[   1057306,      29425]*)
(*  CellTagsIndexPosition[   1057262,      29421]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  " :Author:  Z\[EAcute]lia da ROCHA \n\n:Address: \n            Departamento \
de Matem\[AAcute]tica Aplicada da\n            Faculdade de Ci\[EHat]ncias do \
Porto\n            Rua das Taipas, 135\n            4050 Porto\n            \
Portugal\n  \n            Tel: ++351 02 2080313\n            Fax: ++351 02 \
2004109\n            Email: mrdioh@fc.up.pt\n\n :Summary:\n    The ",
  StyleBox["testshfv6",
    FontSize->18],
  " notebook contains the results produced by the package\n    shfv.m \
corresponding to the ",
  StyleBox["example 6",
    FontSize->18],
  " of the first paper cited bellow.    \n\n :Date:  July 1999. \n\n\
:Available at http://netlib.bell-labs.com/ in the numeralgo library in \
netlib:     \n\n :Notebook Version: 1.0 \n\n :Mathematica Version: 3.0   \n \n\
 :Keywords: Shohat-Favard's method, regular forms, d-dimensional canonical \
forms, \n d-orthogonal polynomial sequences.\n\n :Sources:\n \n - \
Z\[EAcute]lia da Rocha, Shohat-Favard and Chebyshev's methods in \
d-orthogonality, \n Numerical Algorithms, 20 (1999) 139 - 164.\n   \n - About \
the example treated here see p.286,293,294 of\n   K. Douak, The relation of \
the d-orthogonal polynomials to the Appell \npolynomials,  J. Comput. Appl. \
Math., 70 (1996) 279-295.\n"
}], "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Computing the moments of the d-dimensional canonical form \
performing formal computations\
\>", "Section",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Loading the package shfv.m, the package datashfv6.m is \
automatically loaded\
\>", "Subsection"],

Cell[BoxData[
    \(\(<< shohatfavard`shfv`\ ; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The recurrence coefficients are given in the package \
datashfv6.m\
\>", "Subsection",
  AspectRatioFixed->True],

Cell[BoxData[
    \( (*\ showing\ the\ recurrence\ coefficients\ given\ *) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\( (*\ set\ the\ values\ of\ d\ and\ imax\ *) \nd = 5; imax = \ 10; 
    \ \ \ \ \ \  (*\ for\ example\ *) \)\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \( : \ \) 
      "Possible spelling error: new symbol name \"\!\(imax\)\" is similar to \
existing symbol \"\!\(nmax\)\"."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Do[\ 
      Do[Print["\<gamma[\>", d, "\<,\>", r, "\<,\>", n, "\<]=\>", \n
          \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ gamma[d, r, n]\ ], \ \ \ \ \ \ \ \n
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {n, 1, imax + r - d + 1}]; 
      Print["\<  \>"], \ \n\ \ \ \ \ \ {r, 0, d - 1}]\ \)\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]1\/6\),
      SequenceForm[ "gamma[", 5, ",", 0, ",", 1, "]=", 
        Rational[ 1, 6]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "gamma[", 5, ",", 0, ",", 2, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]7\/2\),
      SequenceForm[ "gamma[", 5, ",", 0, ",", 3, "]=", 
        Rational[ 7, 2]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]28\/3\),
      SequenceForm[ "gamma[", 5, ",", 0, ",", 4, "]=", 
        Rational[ 28, 3]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]21\),
      SequenceForm[ "gamma[", 5, ",", 0, ",", 5, "]=", 21],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]42\),
      SequenceForm[ "gamma[", 5, ",", 0, ",", 6, "]=", 42],
      Editable->False]], "Print"],

Cell[BoxData[
    \("  "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 1, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 1, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 1, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 1, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 1, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 1, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 1, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("  "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 2, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 2, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 2, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 2, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 2, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 2, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 2, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 2, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("  "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 3, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 3, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 3, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 3, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 3, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 3, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 3, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 3, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 3, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("  "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 4, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 4, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 4, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 4, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 4, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 4, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 4, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 4, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 4, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("gamma["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "gamma[", 5, ",", 4, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("  "\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\ Do[Print["\<beta[\>", d, "\<,\>", n, "\<]=\>", beta[d, n]\ ], 
      \ \ \ \ \ \ \ \n\ \ \ \ \ \ \ \ \ \ {n, 0, imax - 1}]\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      \("beta["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "beta[", 5, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("beta["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "beta[", 5, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("beta["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "beta[", 5, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("beta["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "beta[", 5, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("beta["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "beta[", 5, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("beta["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "beta[", 5, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("beta["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "beta[", 5, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("beta["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "beta[", 5, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("beta["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "beta[", 5, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("beta["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "beta[", 5, ",", 9, "]=", 0],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The exact expressions of the moments of the d-dimensional form are \
given in the package datashfv6.m\
\>", "Subsection"],

Cell[BoxData[
    \(\( (*\ set\ the\ values\ of\ d\ and\ nmax\ *) \nd = 5; \ 
    nmax = \ 10\ \ ; \ \ \  (*\ for\ example\ *) \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\n\t
      Do[Do[Print["\<formexact[\>", d "\<,\>", r, "\<,\>", i, "\<]=\>", \n
            \t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
            formexact[d, r, i]\ ], {i, 0, imax}]; \n\t\t\ \ \ \ \ 
        Print["\<   \>"], {r, 1, d}\ ]\n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ ]\)], 
  "Input"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 1, ",", 0, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 1, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 1, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 1, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 1, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 1, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]1\/6\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 1, ",", 6, "]=", 
        Rational[ 1, 6]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 1, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 1, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 1, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 1, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("   "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 2, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 2, ",", 1, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 2, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 2, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 2, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 2, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 2, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]7\/6\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 2, ",", 7, "]=", 
        Rational[ 7, 6]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 2, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 2, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 2, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("   "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 3, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 3, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 3, ",", 2, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 3, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 3, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 3, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 3, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 3, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]14\/3\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 3, ",", 8, "]=", 
        Rational[ 14, 3]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 3, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 3, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("   "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 4, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 4, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 4, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 4, ",", 3, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 4, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 4, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 4, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 4, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 4, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]14\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 4, ",", 9, "]=", 14],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 4, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("   "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 5, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 5, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 5, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 5, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 5, ",", 4, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 5, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 5, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 5, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 5, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 5, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]\(5\ ","\)\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]35\),
      SequenceForm[ "formexact[", 
        Times[ 5, ","], 5, ",", 10, "]=", 35],
      Editable->False]], "Print"],

Cell[BoxData[
    \("   "\)], "Print"],

Cell[BoxData[
    \({18.2833333333333314`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Computing the moments of the d-dimensional form", "Subsection"],

Cell[BoxData[
    \(\( (*\ set\ the\ values\ of\ d\ and\ nmax\ *) \nd = 5; \ nmax = \ 10; 
    \ \ \  (*\ for\ example\ *) \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MemoryInUse[]\)], "Input"],

Cell[BoxData[
    \(897904\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[printdcanform[d,nmax,Infinity,$MachinePrecision,True,False]]\
\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \("   "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "form[", 5, ",", 1, ",", 0, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 0, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]1\/6\),
      SequenceForm[ "form[", 5, ",", 1, ",", 6, "]=", 
        Rational[ 1, 6]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]1\/6\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 6, "]=", 
        Rational[ 1, 6]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    \("   "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "form[", 5, ",", 2, ",", 1, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 1, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]7\/6\),
      SequenceForm[ "form[", 5, ",", 2, ",", 7, "]=", 
        Rational[ 7, 6]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]7\/6\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 7, "]=", 
        Rational[ 7, 6]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    \("   "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "form[", 5, ",", 3, ",", 2, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 2, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]14\/3\),
      SequenceForm[ "form[", 5, ",", 3, ",", 8, "]=", 
        Rational[ 14, 3]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]14\/3\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 8, "]=", 
        Rational[ 14, 3]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    \("   "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "form[", 5, ",", 4, ",", 3, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 3, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]14\),
      SequenceForm[ "form[", 5, ",", 4, ",", 9, "]=", 14],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]14\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 9, "]=", 14],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    \("   "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "form[", 5, ",", 5, ",", 4, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]1\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 4, "]=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]35\),
      SequenceForm[ "form[", 5, ",", 5, ",", 10, "]=", 35],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]35\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 10, "]=", 35],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    \({30.1499999999999923`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MemoryInUse[]\)], "Input"],

Cell[BoxData[
    \(905320\)], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Computing the moments of the d-dimensional canonical form  \
performing numerical computations with the machine precision\
\>", "Section",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Loading the package shfv.m, the package datashfv6.m is \
automatically loaded\
\>", "Subsection"],

Cell[BoxData[
    \(\(<< shohatfavard`shfv`\ ; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the moments of the d-dimensional form", "Subsection"],

Cell[BoxData[
    \(\( (*\ set\ the\ values\ of\ d\ and\ nmax\ *) \nd = 5; \ 
    nmax = \ 180\ ; \ \ \ \  (*\ for\ example\ *) \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MemoryInUse[]\)], "Input"],

Cell[BoxData[
    \(906576\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Timing[printdcanform[d,nmax,$MachinePrecision,$MachinePrecision,\
True,True]]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \("   "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "0", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 1, ",", 0, "]=", 1.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "0", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "formexact[", 5, ",", 1, ",", 0, "]=", 1.0],
      Editable->False]], "Print"],

Cell[BoxData[
    \(MantissaExponent::"realx" \( : \ \) 
      "\!\(1\) is not an inexact real number."\)], "Message"],

Cell[BoxData[
    \(Part::"partw" \( : \ \) 
      "Part \!\(2\) of \!\(MantissaExponent[1]\) does not exist."\)], 
  "Message"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "0", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 1]]}],
      SequenceForm[ "exactdigits[", 5, ",", 1, ",", 0, "]=", 
        DirectedInfinity[ 1]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "6", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["0.166666666666666651`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 1, ",", 6, "]=", 0.16666666666666666],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "6", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["0.166666666666666651`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 6, "]=", 0.16666666666666666],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "6", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 1]]}],
      SequenceForm[ "exactdigits[", 5, ",", 1, ",", 6, "]=", 
        DirectedInfinity[ 1]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]11
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 11, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]11
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 11, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]11
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 11, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "12", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.8333333333333321`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 1, ",", 12, "]=", 12.833333333333332],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "12", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.8333333333333342`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 12, "]=", 12.833333333333334],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "12", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["15.7504697875350752`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 12, "]=", 15.750469787535074],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]13
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 13, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]13
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 13, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]13
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 13, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]14
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 14, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]14
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 14, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]14
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 14, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]15
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 15, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]15
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 15, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]15
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 15, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]16
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 16, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]16
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 16, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]16
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 16, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]17
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 17, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]17
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 17, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]17
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 17, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "18", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["13235.4444444444441`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 1, ",", 18, "]=", 13235.444444444442],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "18", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["13235.4444444444441`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 18, "]=", 13235.444444444445],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "18", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["15.439139835231284`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 18, "]=", 15.439139835231284],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]19
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 19, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]19
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 19, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]19
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 19, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]20
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 20, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]20
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 20, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]20
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 20, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]21
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 21, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]21
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 21, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]21
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 21, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]22
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 22, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]22
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 22, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]22
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 22, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]23
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 23, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]23
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 23, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]23
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 23, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "24", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.4226578351851824`*^7",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 1, ",", 24, "]=", 74226578.351851821],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "24", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.42265783518518595`*^7",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 24, "]=", 74226578.351851851],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "24", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["14.5257498915995286`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 24, "]=", 14.52574989159953],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]25
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 25, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]25
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 25, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]25
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 25, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]26
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 26, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]26
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 26, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]26
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 26, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]27
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 27, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]27
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 27, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]27
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 27, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]28
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 28, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]28
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 28, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]28
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 28, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]29
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 29, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]29
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 29, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]29
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 29, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "30", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.46912955202902821`*^12",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 1, ",", 30, "]=", 1469129552029.0283],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "30", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.46912955202902768`*^12",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 30, "]=", 1469129552029.0278],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "30", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["15.3113299523037937`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 30, "]=", 15.311329952303794],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]31
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 31, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]31
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 31, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]31
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 31, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]32
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 32, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]32
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 32, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]32
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 32, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]33
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 33, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]33
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 33, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]33
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 33, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]34
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 34, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]34
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 34, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]34
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 34, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]35
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 35, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]35
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 35, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]35
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 35, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "36", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.94877441223812475`*^16",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 1, ",", 36, "]=", 79487744122381248.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "36", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.94877441223812475`*^16",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 36, "]=", 79487744122381232.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "36", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["14.795880017344074`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 36, "]=", 14.795880017344075],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]37
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 37, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]37
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 37, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]37
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 37, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]38
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 38, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]38
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 38, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]38
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 38, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]39
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 39, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]39
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 39, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]39
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 39, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]40
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 40, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]40
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 40, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]40
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 40, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]41
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 41, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]41
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 41, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]41
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 41, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "42", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.92799274497051875`*^21",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 42, "]=", 9.9279927449705177*^+21],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "42", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.92799274497070527`*^21",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 42, "]=", 9.9279927449707065*^+21],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "42", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.7241275816170706`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 42, "]=", 12.72412758161707],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]43
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 43, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]43
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 43, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]43
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 43, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]44
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 44, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]44
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 44, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]44
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 44, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]45
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 45, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]45
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 45, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]45
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 45, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]46
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 46, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]46
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 46, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]46
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 46, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]47
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 47, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]47
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 47, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]47
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 47, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "48", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.53815587720429336`*^27",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 48, "]=", 2.5381558772042935*^+27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "48", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.53815587720460378`*^27",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 48, "]=", 2.5381558772046036*^+27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "48", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.5085510651213915`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 48, "]=", 12.508551065121392],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]49
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 49, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]49
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 49, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]49
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 49, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]50
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 50, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]50
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 50, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]50
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 50, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]51
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 51, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]51
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 51, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]51
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 51, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]52
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 52, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]52
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 52, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]52
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 52, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]53
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 53, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]53
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 53, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]53
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 53, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "54", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.21395130807873785`*^33",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 54, "]=", 1.2139513080787379*^+33],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "54", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.21395130807931539`*^33",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 54, "]=", 1.2139513080793155*^+33],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "54", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.238362534293885`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 54, "]=", 12.238362534293884],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]55
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 55, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]55
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 55, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]55
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 55, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]56
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 56, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]56
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 56, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]56
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 56, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]57
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 57, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]57
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 57, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]57
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 57, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]58
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 58, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]58
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 58, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]58
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 58, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]59
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 59, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]59
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 59, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]59
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 59, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "60", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.0129181389067885`*^39",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 60, "]=", 1.0129181389067884*^+39],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "60", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.01291813890832882`*^39",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 60, "]=", 1.0129181389083287*^+39],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "60", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["11.8123883096614479`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 60, "]=", 11.812388309661447],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]61
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 61, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]61
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 61, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]61
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 61, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]62
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 62, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]62
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 62, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]62
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 62, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]63
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 63, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]63
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 63, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]63
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 63, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]64
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 64, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]64
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 64, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]64
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 64, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]65
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 65, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]65
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 65, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]65
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 65, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "66", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.39443173008567322`*^45",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 66, "]=", 1.3944317300856735*^+45],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "66", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.39443173009187271`*^45",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 66, "]=", 1.3944317300918728*^+45],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "66", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["11.2076582709636629`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 66, "]=", 11.207658270963663],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]67
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 67, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]67
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 67, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]67
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 67, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]68
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 68, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]68
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 68, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]68
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 68, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]69
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 69, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]69
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 69, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]69
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 69, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]70
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 70, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]70
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 70, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]70
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 70, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]71
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 71, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]71
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 71, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]71
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 71, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "72", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.02589570538067098`*^51",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 72, "]=", 3.0258957053806713*^+51],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "72", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.02589570541812458`*^51",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 72, "]=", 3.0258957054181243*^+51],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "72", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["10.4265134749516752`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 72, "]=", 10.426513474951676],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]73
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 73, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]73
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 73, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]73
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 73, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]74
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 74, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]74
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 74, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]74
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 74, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]75
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 75, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]75
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 75, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]75
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 75, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]76
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 76, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]76
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 76, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]76
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 76, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]77
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 77, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]77
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 77, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]77
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 77, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "78", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.96418125915977981`*^57",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 78, "]=", 9.9641812591597778*^+57],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "78", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.96418125949096555`*^57",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 78, "]=", 9.9641812594909662*^+57],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "78", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.47992492629847305`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 78, "]=", 9.4799249262984731],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]79
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 79, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]79
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 79, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]79
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 79, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]80
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 80, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]80
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 80, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]80
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 80, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]81
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 81, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]81
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 81, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]81
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 81, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]82
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 82, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]82
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 82, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]82
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 82, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]83
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 83, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]83
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 83, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]83
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 83, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "84", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.82173307464644196`*^64",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 84, "]=", 4.8217330746464425*^+64],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "84", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.82173307506399062`*^64",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 84, "]=", 4.8217330750639917*^+64],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "84", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.37929227751213545`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 84, "]=", 9.3792922775121355],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]85
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 85, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]85
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 85, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]85
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 85, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]86
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 86, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]86
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 86, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]86
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 86, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]87
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 87, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]87
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 87, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]87
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 87, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]88
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 88, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]88
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 88, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]88
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 88, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]89
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 89, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]89
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 89, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]89
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 89, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "90", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.33564617092120752`*^71",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 90, "]=", 3.3356461709212072*^+71],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "90", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.33564617165525456`*^71",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 90, "]=", 3.3356461716552544*^+71],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "90", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.13427600216322588`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 90, "]=", 9.1342760021632259],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]91
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 91, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]91
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 91, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]91
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 91, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]92
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 92, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]92
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 92, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]92
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 92, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]93
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 93, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]93
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 93, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]93
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 93, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]94
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 94, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]94
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 94, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]94
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 94, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]95
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 95, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]95
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 95, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]95
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 95, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "96", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.22115117134890516`*^78",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 96, "]=", 3.2211511713489056*^+78],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "96", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.22115117310114262`*^78",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 96, "]=", 3.2211511731011425*^+78],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "96", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.75640717337252283`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 96, "]=", 8.7564071733725228],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]97
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 97, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]97
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 97, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]97
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 97, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]98
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 98, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]98
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 98, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]98
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 98, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]99
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 99, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]99
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 99, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]99
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 99, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]100
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 100, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]100
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 100, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]100
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 100, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]101
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 101, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]101
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 101, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]101
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 101, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "102", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.25238902585472011`*^85",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 102, "]=", 4.2523890258547209*^+85],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "102", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.25238903127698719`*^85",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 102, "]=", 4.2523890312769868*^+85],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "102", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.26581918792057024`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 102, "]=", 8.2658191879205702],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]103
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 103, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]103
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 103, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]103
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 103, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]104
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 104, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]104
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 104, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]104
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 104, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]105
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 105, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]105
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 105, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]105
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 105, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]106
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 106, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]106
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 106, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]106
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 106, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]107
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 107, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]107
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 107, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]107
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 107, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "108", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.53442297978323427`*^92",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 108, "]=", 7.5344229797832349*^+92],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "108", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.53442299981976226`*^92",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 108, "]=", 7.5344229998197614*^+92],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "108", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.69817756515494977`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 108, "]=", 7.6981775651549498],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]109
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 109, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]109
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 109, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]109
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 109, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]110
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 110, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]110
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 110, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]110
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 110, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]111
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 111, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]111
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 111, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]111
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 111, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]112
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 112, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]112
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 112, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]112
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 112, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]113
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 113, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]113
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 113, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]113
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 113, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "114", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.76260958970631858`*^100",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 114, "]=", 1.7626095897063184*^+100],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "114", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.76260959709956139`*^100",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 114, "]=", 1.7626095970995614*^+100],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "114", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.13116502055939349`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 114, "]=", 8.1311650205593935],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]115
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 115, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]115
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 115, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]115
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 115, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]116
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 116, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]116
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 116, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]116
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 116, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]117
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 117, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]117
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 117, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]117
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 117, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]118
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 118, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]118
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 118, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]118
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 118, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]119
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 119, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]119
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 119, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]119
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 119, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "120", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.36530349658074534`*^107",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 120, "]=", 5.3653034965807461*^+107],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "120", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.36530350296487767`*^107",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 120, "]=", 5.3653035029648769*^+107],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "120", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.19489822904017728`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 120, "]=", 8.1948982290401773],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]121
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 121, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]121
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 121, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]121
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 121, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]122
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 122, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]122
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 122, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]122
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 122, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]123
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 123, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]123
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 123, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]123
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 123, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]124
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 124, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]124
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 124, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]124
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 124, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]125
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 125, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]125
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 125, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]125
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 125, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "126", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.09721917637681398`*^115",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 126, "]=", 2.097219176376814*^+115],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "126", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.09721911885386536`*^115",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 126, "]=", 2.097219118853865*^+115],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "126", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.24015885674599246`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 126, "]=", 7.2401588567459925],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]127
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 127, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]127
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 127, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]127
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 127, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]128
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 128, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]128
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 128, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]128
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 128, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]129
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 129, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]129
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 129, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]129
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 129, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]130
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 130, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]130
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 130, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]130
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 130, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]131
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 131, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]131
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 131, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]131
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 131, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "132", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.04023013167448796`*^123",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 132, "]=", 1.0402301316744879*^+123],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "132", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.04022996664148292`*^123",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 132, "]=", 1.040229966641483*^+123],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "132", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.78242919284363665`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 132, "]=", 6.7824291928436367],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]133
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 133, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]133
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 133, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]133
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 133, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]134
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 134, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]134
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 134, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]134
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 134, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]135
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 135, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]135
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 135, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]135
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 135, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]136
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 136, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]136
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 136, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]136
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 136, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]137
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 137, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]137
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 137, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]137
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 137, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "138", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.47659632404872454`*^130",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 138, "]=", 6.4765963240487246*^+130],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "138", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.47659212691701391`*^130",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 138, "]=", 6.476592126917014*^+130],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "138", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.37704740193940722`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 138, "]=", 5.3770474019394072],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]139
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 139, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]139
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 139, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]139
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 139, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]140
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 140, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]140
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 140, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]140
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 140, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]141
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 141, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]141
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 141, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]141
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 141, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]142
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 142, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]142
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 142, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]142
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 142, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]143
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 143, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]143
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 143, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]143
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 143, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "144", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.01188824053002601`*^138",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 144, "]=", 5.0118882405300266*^+138],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "144", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.01187673974582281`*^138",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 144, "]=", 5.0118767397458234*^+138],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "144", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.93927254543177696`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 144, "]=", 4.939272545431777],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]145
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 145, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]145
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 145, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]145
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 145, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]146
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 146, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]146
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 146, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]146
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 146, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]147
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 147, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]147
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 147, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]147
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 147, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]148
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 148, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]148
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 148, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]148
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 148, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]149
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 149, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]149
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 149, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]149
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 149, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "150", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.77702269049955852`*^146",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 150, "]=", 4.7770226904995596*^+146],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "150", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.77698702545044451`*^146",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 150, "]=", 4.7769870254504451*^+146],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "150", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.44775717357413213`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 150, "]=", 4.4477571735741321],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]151
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 151, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]151
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 151, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]151
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 151, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]152
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 152, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]152
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 152, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]152
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 152, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]153
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 153, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]153
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 153, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]153
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 153, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]154
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 154, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]154
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 154, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]154
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 154, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]155
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 155, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]155
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 155, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]155
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 155, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "156", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.56154992742922527`*^154",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 156, "]=", 5.5615499274292257*^+154],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "156", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.56142327815007142`*^154",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 156, "]=", 5.5614232781500713*^+154],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "156", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.89739727772621336`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 156, "]=", 3.8973972777262134],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]157
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 157, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]157
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 157, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]157
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 157, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]158
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 158, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]158
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 158, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]158
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 158, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]159
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 159, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]159
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 159, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]159
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 159, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]160
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 160, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]160
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 160, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]160
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 160, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]161
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 161, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]161
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 161, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]161
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 161, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "162", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.84840923087037634`*^162",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 162, "]=", 7.8484092308703757*^+162],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "162", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.84789486395911684`*^162",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 162, "]=", 7.8478948639591181*^+162],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "162", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.28872697694316684`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 162, "]=", 3.2887269769431668],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]163
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 163, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]163
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 163, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]163
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 163, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]164
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 164, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]164
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 164, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]164
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 164, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]165
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 165, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]165
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 165, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]165
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 165, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]166
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 166, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]166
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 166, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]166
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 166, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]167
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 167, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]167
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 167, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]167
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 167, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "168", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.33302475289405153`*^171",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 168, "]=", 1.3330247528940515*^+171],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "168", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.33278665547591956`*^171",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 168, "]=", 1.3327866554759192*^+171],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "168", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.62324531394827431`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 168, "]=", 3.6232453139482743],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]169
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 169, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]169
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 169, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]169
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 169, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]170
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 170, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]170
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 170, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]170
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 170, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]171
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 171, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]171
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 171, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]171
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 171, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]172
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 172, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]172
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 172, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]172
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 172, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]173
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 173, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]173
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 173, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]173
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 173, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "174", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.70729920017372105`*^179",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 174, "]=", 2.7072992001737211*^+179],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "174", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.70604133191784868`*^179",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 174, "]=", 2.706041331917849*^+179],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "174", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.9003648427889459`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 174, "]=", 2.9003648427889459],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]175
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 175, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]175
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 175, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]175
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 175, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]176
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 176, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]176
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 176, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]176
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 176, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]177
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 177, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]177
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 177, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]177
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 177, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]178
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 178, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]178
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 178, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]178
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 178, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]179
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 1, ",", 179, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]179
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 1, ",", 179, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]","\[InvisibleSpace]179
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 1, ",", 179, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "180", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.53595928550422922`*^187",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 1, ",", 180, "]=", 6.5359592855042275*^+187],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "180", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.52828258920841086`*^187",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 1, ",", 180, "]=", 6.5282825892084103*^+187],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "180", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.11482564053940791`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 1, ",", 180, "]=", 2.1148256405394079],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    \("   "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 2, ",", 1, "]=", 1.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "formexact[", 5, ",", 2, ",", 1, "]=", 1.0],
      Editable->False]], "Print"],

Cell[BoxData[
    \(MantissaExponent::"realx" \( : \ \) 
      "\!\(1\) is not an inexact real number."\)], "Message"],

Cell[BoxData[
    \(Part::"partw" \( : \ \) 
      "Part \!\(2\) of \!\(MantissaExponent[1]\) does not exist."\)], 
  "Message"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "1", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 1]]}],
      SequenceForm[ "exactdigits[", 5, ",", 2, ",", 1, "]=", 
        DirectedInfinity[ 1]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "7", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.16666666666666674`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 2, ",", 7, "]=", 1.1666666666666667],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "7", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.16666666666666674`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 7, "]=", 1.1666666666666667],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "7", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 1]]}],
      SequenceForm[ "exactdigits[", 5, ",", 2, ",", 7, "]=", 
        DirectedInfinity[ 1]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]11
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 11, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]11
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 11, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]11
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 11, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]12
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 12, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]12
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 12, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]12
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 12, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "13", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["166.833333333333344`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 2, ",", 13, "]=", 166.83333333333334],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "13", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["166.833333333333344`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 13, "]=", 166.83333333333334],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "13", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 1]]}],
      SequenceForm[ "exactdigits[", 5, ",", 2, ",", 13, "]=", 
        DirectedInfinity[ 1]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]14
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 14, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]14
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 14, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]14
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 14, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]15
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 15, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]15
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 15, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]15
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 15, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]16
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 16, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]16
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 16, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]16
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 16, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]17
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 17, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]17
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 17, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]17
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 17, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]18
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 18, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]18
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 18, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]18
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 18, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "19", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["251473.444444444416`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 2, ",", 19, "]=", 251473.44444444444],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "19", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["251473.444444444416`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 19, "]=", 251473.44444444444],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "19", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 1]]}],
      SequenceForm[ "exactdigits[", 5, ",", 2, ",", 19, "]=", 
        DirectedInfinity[ 1]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]20
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 20, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]20
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 20, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]20
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 20, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]21
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 21, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]21
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 21, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]21
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 21, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]22
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 22, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]22
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 22, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]22
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 22, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]23
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 23, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]23
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 23, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]23
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 23, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]24
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 24, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]24
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 24, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]24
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 24, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "25", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.85566445879629604`*^9",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 2, ",", 25, "]=", 1855664458.7962961],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "25", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.8556644587962964`*^9",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 25, "]=", 1855664458.7962964],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "25", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["15.6226599046075875`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 25, "]=", 15.622659904607588],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]26
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 26, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]26
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 26, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]26
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 26, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]27
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 27, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]27
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 27, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]27
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 27, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]28
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 28, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]28
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 28, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]28
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 28, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]29
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 29, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]29
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 29, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]29
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 29, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]30
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 30, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]30
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 30, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]30
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 30, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "31", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.55430161128998456`*^13",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 2, ",", 31, "]=", 45543016112899.844],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "31", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.55430161128998545`*^13",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 31, "]=", 45543016112899.859],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "31", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["14.8061799739838884`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 31, "]=", 14.806179973983888],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]32
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 32, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]32
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 32, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]32
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 32, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]33
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 33, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]33
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 33, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]33
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 33, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]34
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 34, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]34
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 34, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]34
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 34, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]35
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 35, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]35
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 35, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]35
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 35, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]36
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 36, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]36
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 36, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]36
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 36, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "37", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.94104653252808923`*^18",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 37, "]=", 2.9410465325280891*^+18],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "37", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.94104653252810521`*^18",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 37, "]=", 2.9410465325281055*^+18],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "37", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["13.7855800607042633`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 37, "]=", 13.785580060704264],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]38
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 38, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]38
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 38, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]38
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 38, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]39
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 39, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]39
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 39, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]39
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 39, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]40
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 40, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]40
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 40, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]40
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 40, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]41
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 41, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]41
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 41, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]41
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 41, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]42
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 42, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]42
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 42, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]42
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 42, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "43", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.26903688033729444`*^23",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 43, "]=", 4.2690368803372949*^+23],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "43", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.26903688033740458`*^23",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 43, "]=", 4.2690368803374043*^+23],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "43", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.9610325083325328`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 43, "]=", 12.961032508332533],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]44
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 44, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]44
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 44, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]44
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 44, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]45
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 45, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]45
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 45, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]45
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 45, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]46
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 46, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]46
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 46, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]46
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 46, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]47
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 47, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]47
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 47, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]47
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 47, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]48
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 48, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]48
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 48, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]48
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 48, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "49", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.24369637983016745`*^29",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 49, "]=", 1.2436963798301676*^+29],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "49", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.2436963798302556`*^29",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 49, "]=", 1.2436963798302558*^+29],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "49", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["13.054842464917582`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 49, "]=", 13.054842464917582],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]50
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 50, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]50
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 50, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]50
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 50, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]51
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 51, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]51
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 51, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]51
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 51, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]52
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 52, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]52
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 52, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]52
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 52, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]53
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 53, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]53
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 53, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]53
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 53, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]54
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 54, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]54
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 54, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]54
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 54, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "55", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.67673219443516252`*^34",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 55, "]=", 6.676732194435162*^+34],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "55", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.67673219443623544`*^34",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 55, "]=", 6.6767321944362356*^+34],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "55", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["11.9691572928553169`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 55, "]=", 11.969157292855318],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]56
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 56, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]56
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 56, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]56
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 56, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]57
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 57, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]57
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 57, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]57
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 57, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]58
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 58, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]58
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 58, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]58
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 58, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]59
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 59, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]59
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 59, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]59
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 59, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]60
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 60, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]60
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 60, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]60
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 60, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "61", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.17880064733811451`*^40",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 61, "]=", 6.1788006473381146*^+40],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "61", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.17880064734080569`*^40",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 61, "]=", 6.1788006473408052*^+40],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "61", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["11.5701532342335378`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 61, "]=", 11.570153234233537],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]62
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 62, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]62
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 62, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]62
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 62, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]63
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 63, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]63
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 63, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]63
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 63, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]64
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 64, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]64
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 64, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]64
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 64, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]65
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 65, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]65
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 65, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]65
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 65, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]66
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 66, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]66
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 66, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]66
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 66, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "67", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.34269259160104859`*^46",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 67, "]=", 9.3426925916010497*^+46],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "67", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.34269259161554899`*^46",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 67, "]=", 9.3426925916155496*^+46],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "67", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["10.8386351538798342`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 67, "]=", 10.838635153879835],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]68
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 68, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]68
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 68, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]68
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 68, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]69
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 69, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]69
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 69, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]69
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 69, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]70
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 70, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]70
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 70, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]70
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 70, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]71
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 71, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]71
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 71, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]71
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 71, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]72
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 72, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]72
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 72, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]72
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 72, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "73", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.20890386494247126`*^53",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 73, "]=", 2.2089038649424712*^+53],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "73", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.20890386495523038`*^53",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 73, "]=", 2.2089038649552305*^+53],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "73", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["10.894172718902495`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 73, "]=", 10.894172718902496],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]74
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 74, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]74
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 74, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]74
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 74, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]75
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 75, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]75
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 75, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]75
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 75, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]76
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 76, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]76
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 76, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]76
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 76, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]77
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 77, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]77
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 77, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]77
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 77, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]78
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 78, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]78
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 78, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]78
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 78, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "79", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.87170319484230684`*^59",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 79, "]=", 7.8717031948423062*^+59],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "79", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.87170319499786508`*^59",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 79, "]=", 7.8717031949978637*^+59],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "79", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.80810901695074477`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 79, "]=", 9.8081090169507448],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]80
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 80, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]80
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 80, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]80
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 80, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]81
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 81, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]81
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 81, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]81
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 81, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]82
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 82, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]82
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 82, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]82
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 82, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]83
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 83, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]83
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 83, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]83
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 83, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]84
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 84, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]84
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 84, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]84
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 84, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "85", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.09847311355333498`*^66",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 85, "]=", 4.0984731135533358*^+66],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "85", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.09847311380439283`*^66",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 85, "]=", 4.0984731138043927*^+66],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "85", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.60022785265047673`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 85, "]=", 9.6002278526504767],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]86
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 86, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]86
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 86, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]86
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 86, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]87
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 87, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]87
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 87, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]87
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 87, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]88
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 88, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]88
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 88, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]88
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 88, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]89
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 89, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]89
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 89, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]89
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 89, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]90
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 90, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]90
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 90, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]90
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 90, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "91", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.03543801567661164`*^73",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 91, "]=", 3.0354380156766117*^+73],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "91", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.03543801620628173`*^73",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 91, "]=", 3.0354380162062817*^+73],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "91", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.27599462056578261`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 91, "]=", 9.2759946205657826],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]92
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 92, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]92
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 92, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]92
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 92, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]93
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 93, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]93
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 93, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]93
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 93, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]94
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 94, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]94
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 94, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]94
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 94, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]95
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 95, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]95
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 95, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]95
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 95, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]96
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 96, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]96
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 96, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]96
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 96, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "97", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.12451663646651756`*^80",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 97, "]=", 3.1245166364665177*^+80],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "97", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.1245166379081084`*^80",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 97, "]=", 3.1245166379081082*^+80],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "97", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.84115809640272232`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 97, "]=", 8.8411580964027223],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]98
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 98, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]98
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 98, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]98
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 98, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]99
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 99, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]99
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 99, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]99
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 99, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]100
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 100, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]100
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 100, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]100
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 100, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]101
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 101, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]101
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 101, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]101
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 101, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]102
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 102, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]102
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 102, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]102
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 102, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "103", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.37996069729280268`*^87",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 103, "]=", 4.3799606972928031*^+87],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "103", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.37996070221529709`*^87",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 103, "]=", 4.3799607022152965*^+87],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "103", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.307814862336798`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 103, "]=", 8.307814862336798],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]104
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 104, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]104
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 104, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]104
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 104, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]105
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 105, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]105
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 105, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]105
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 105, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]106
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 106, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]106
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 106, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]106
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 106, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]107
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 107, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]107
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 107, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]107
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 107, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]108
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 108, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]108
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 108, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]108
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 108, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "109", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.21252104993195075`*^94",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 109, "]=", 8.2125210499319519*^+94],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "109", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.21252106980353957`*^94",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 109, "]=", 8.2125210698035403*^+94],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "109", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.70176741613720139`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 109, "]=", 7.7017674161372014],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]110
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 110, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]110
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 110, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]110
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 110, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]111
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 111, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]111
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 111, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]111
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 111, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]112
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 112, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]112
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 112, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]112
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 112, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]113
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 113, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]113
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 113, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]113
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 113, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]114
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 114, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]114
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 114, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]114
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 114, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "115", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.02700102855093655`*^102",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 115, "]=", 2.0270010285509363*^+102],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "115", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.02700103666449527`*^102",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 115, "]=", 2.0270010366644956*^+102],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "115", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.09078858525968769`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 115, "]=", 8.0907885852596877],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]116
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 116, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]116
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 116, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]116
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 116, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]117
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 117, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]117
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 117, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]117
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 117, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]118
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 118, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]118
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 118, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]118
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 118, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]119
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 119, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]119
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 119, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]119
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 119, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]120
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 120, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]120
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 120, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]120
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 120, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "121", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.49201722850601736`*^109",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 121, "]=", 6.4920172285060174*^+109],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "121", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.49201723858750057`*^109",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 121, "]=", 6.4920172385875008*^+109],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "121", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.99647556309712115`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 121, "]=", 7.9964755630971212],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]122
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 122, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]122
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 122, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]122
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 122, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]123
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 123, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]123
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 123, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]123
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 123, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]124
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 124, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]124
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 124, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]124
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 124, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]125
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 125, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]125
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 125, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]125
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 125, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]126
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 126, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]126
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 126, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]126
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 126, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "127", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.66346835066579146`*^117",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 127, "]=", 2.6634683506657911*^+117],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "127", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.66346828094440812`*^117",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 127, "]=", 2.663468280944408*^+117],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "127", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.15663400628899637`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 127, "]=", 7.1566340062889964],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]128
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 128, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]128
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 128, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]128
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 128, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]129
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 129, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]129
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 129, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]129
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 129, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]130
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 130, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]130
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 130, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]130
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 130, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]131
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 131, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]131
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 131, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]131
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 131, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]132
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 132, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]132
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 132, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]132
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 132, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "133", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.3835060758376969`*^125",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 133, "]=", 1.3835060758376972*^+125],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "133", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.38350585563317229`*^125",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 133, "]=", 1.3835058556331724*^+125],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "133", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.6571737613095081`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 133, "]=", 6.6571737613095081],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]134
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 134, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]134
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 134, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]134
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 134, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]135
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 135, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]135
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 135, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]135
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 135, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]136
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 136, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]136
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 136, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]136
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 136, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]137
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 137, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]137
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 137, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]137
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 137, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]138
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 138, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]138
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 138, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]138
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 138, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "139", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.00246893935850778`*^132",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 139, "]=", 9.0024689393585078*^+132],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "139", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.00246305641465127`*^132",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 139, "]=", 9.0024630564146497*^+132],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "139", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.23040529613788862`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 139, "]=", 5.2304052961378886],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]140
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 140, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]140
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 140, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]140
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 140, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]141
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 141, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]141
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 141, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]141
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 141, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]142
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 142, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]142
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 142, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]142
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 142, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]143
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 143, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]143
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 143, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]143
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 143, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]144
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 144, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]144
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 144, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]144
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 144, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "145", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.26723749308449828`*^140",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 145, "]=", 7.2672374930844997*^+140],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "145", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.26722127263144379`*^140",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 145, "]=", 7.267221272631444*^+140],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "145", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.78993701961582019`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 145, "]=", 4.7899370196158202],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]146
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 146, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]146
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 146, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]146
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 146, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]147
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 147, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]147
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 147, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]147
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 147, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]148
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 148, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]148
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 148, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]148
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 148, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]149
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 149, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]149
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 149, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]149
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 149, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]150
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 150, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]150
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 150, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]150
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 150, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "151", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.21329889434953219`*^148",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 151, "]=", 7.2132988943495322*^+148],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "151", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.21325040843017184`*^148",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 151, "]=", 7.213250408430172*^+148],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "151", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.31438436515071543`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 151, "]=", 4.3143843651507154],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]152
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 152, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]152
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 152, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]152
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 152, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]153
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 153, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]153
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 153, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]153
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 153, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]154
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 154, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]154
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 154, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]154
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 154, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]155
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 155, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]155
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 155, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]155
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 155, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]156
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 156, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]156
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 156, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]156
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 156, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "157", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.73159416998499082`*^156",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 157, "]=", 8.7315941699849908*^+156],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "157", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.73143454669561336`*^156",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 157, "]=", 8.7314345466956115*^+156],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "157", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.79690374386851203`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 157, "]=", 3.796903743868512],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]158
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 158, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]158
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 158, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]158
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 158, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]159
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 159, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]159
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 159, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]159
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 159, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]160
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 160, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]160
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 160, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]160
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 160, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]161
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 161, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]161
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 161, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]161
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 161, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]162
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 162, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]162
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 162, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]162
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 162, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "163", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.27926497071986089`*^165",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 163, "]=", 1.2792649707198609*^+165],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "163", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.27920686282533635`*^165",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 163, "]=", 1.2792068628253363*^+165],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "163", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.23576486045774913`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 163, "]=", 4.2357648604577491],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]164
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 164, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]164
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 164, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]164
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 164, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]165
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 165, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]165
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 165, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]165
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 165, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]166
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 166, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]166
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 166, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]166
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 166, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]167
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 167, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]167
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 167, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]167
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 167, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]168
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 168, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]168
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 168, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]168
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 168, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "169", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.25264312849857128`*^173",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 169, "]=", 2.2526431284985712*^+173],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "169", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.25240944775430396`*^173",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 169, "]=", 2.2524094477543033*^+173],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "169", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.6313770728143595`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 169, "]=", 3.6313770728143595],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]170
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 170, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]170
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 170, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]170
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 170, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]171
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 171, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]171
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 171, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]171
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 171, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]172
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 172, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]172
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 172, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]172
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 172, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]173
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 173, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]173
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 173, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]173
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 173, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]174
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 174, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]174
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 174, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]174
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 174, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "175", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.73660979199163367`*^181",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 2, ",", 175, "]=", 4.7366097919916324*^+181],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "175", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.73557233085623519`*^181",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 2, ",", 175, "]=", 4.7355723308562347*^+181],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "175", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.98402816353009825`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 2, ",", 175, "]=", 2.9840281635300983],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]176
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 176, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]176
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 176, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]176
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 176, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]177
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 177, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]177
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 177, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]177
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 177, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]178
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 178, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]178
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 178, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]178
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 178, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]179
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 179, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]179
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 179, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]179
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 179, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]180
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 2, ",", 180, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]180
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 2, ",", 180, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]","\[InvisibleSpace]180
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 2, ",", 180, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    \("   "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 3, ",", 2, "]=", 1.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "formexact[", 5, ",", 3, ",", 2, "]=", 1.0],
      Editable->False]], "Print"],

Cell[BoxData[
    \(MantissaExponent::"realx" \( : \ \) 
      "\!\(1\) is not an inexact real number."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \( : \ \) 
      "Further output of \!\(MantissaExponent :: \"realx\"\) will be \
suppressed during this calculation."\)], "Message"],

Cell[BoxData[
    \(Part::"partw" \( : \ \) 
      "Part \!\(2\) of \!\(MantissaExponent[1]\) does not exist."\)], 
  "Message"],

Cell[BoxData[
    \(General::"stop" \( : \ \) 
      "Further output of \!\(Part :: \"partw\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "2", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 1]]}],
      SequenceForm[ "exactdigits[", 5, ",", 3, ",", 2, "]=", 
        DirectedInfinity[ 1]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "8", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.66666666666666696`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 3, ",", 8, "]=", 4.666666666666667],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "8", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.66666666666666696`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "formexact[", 5, ",", 3, ",", 8, "]=", 4.666666666666667],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "8", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 1]]}],
      SequenceForm[ "exactdigits[", 5, ",", 3, ",", 8, "]=", 
        DirectedInfinity[ 1]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]11
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 11, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]11
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 11, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]11
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 11, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]12
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 12, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]12
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 12, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]12
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 12, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]13
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 13, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]13
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 13, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]13
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 13, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "14", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1167.8333333333335`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 3, ",", 14, "]=", 1167.8333333333335],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "14", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1167.83333333333327`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 14, "]=", 1167.8333333333333],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "14", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["15.643259817887209`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 14, "]=", 15.643259817887209],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]15
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 15, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]15
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 15, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]15
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 15, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]16
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 16, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]16
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 16, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]16
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 16, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]17
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 17, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]17
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 17, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]17
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 17, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]18
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 18, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]18
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 18, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]18
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 18, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]19
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 19, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]19
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 19, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]19
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 19, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "20", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.51473444444444504`*^6",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 3, ",", 20, "]=", 2514734.444444445],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "20", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.5147344444444446`*^6",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 20, "]=", 2514734.4444444445],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "20", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["15.3319298655834179`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 20, "]=", 15.331929865583419],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]21
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 21, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]21
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 21, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]21
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 21, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]22
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 22, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]22
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 22, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]22
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 22, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]23
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 23, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]23
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 23, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]23
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 23, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]24
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 24, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]24
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 24, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]24
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 24, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]25
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 25, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]25
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 25, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]25
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 25, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "26", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.41236379643518539`*^10",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 3, ",", 26, "]=", 24123637964.351852],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "26", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.41236379643518539`*^10",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 26, "]=", 24123637964.351852],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "26", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 1]]}],
      SequenceForm[ "exactdigits[", 5, ",", 3, ",", 26, "]=", 
        DirectedInfinity[ 1]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]27
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 27, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]27
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 27, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]27
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 27, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]28
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 28, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]28
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 28, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]28
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 28, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]29
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 29, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]29
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 29, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]29
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 29, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]30
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 30, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]30
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 30, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]30
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 30, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]31
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 31, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]31
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 31, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]31
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 31, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "32", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.28688257806397565`*^14",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 3, ",", 32, "]=", 728688257806397.5],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "32", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.28688257806397654`*^14",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 32, "]=", 728688257806397.75],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "32", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["14.6020599913279625`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 32, "]=", 14.602059991327963],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]33
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 33, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]33
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 33, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]33
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 33, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]34
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 34, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]34
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 34, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]34
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 34, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]35
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 35, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]35
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 35, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]35
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 35, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]36
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 36, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]36
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 36, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]36
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 36, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]37
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 37, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]37
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 37, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]37
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 37, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "38", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.58798841180338268`*^19",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 38, "]=", 5.5879884118033826*^+19],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "38", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.58798841180340133`*^19",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 38, "]=", 5.5879884118034006*^+19],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "38", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["13.7441873755460397`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 38, "]=", 13.744187375546039],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]39
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 39, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]39
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 39, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]39
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 39, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]40
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 40, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]40
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 40, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]40
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 40, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]41
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 41, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]41
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 41, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]41
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 41, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]42
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 42, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]42
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 42, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]42
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 42, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]43
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 43, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]43
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 43, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]43
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 43, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "44", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.39188113674214442`*^24",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 44, "]=", 9.3918811367421434*^+24],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "44", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.3918811367422883`*^24",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 44, "]=", 9.3918811367422894*^+24],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "44", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.8355612217103477`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 44, "]=", 12.835561221710348],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]45
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 45, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]45
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 45, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]45
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 45, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]46
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 46, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]46
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 46, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]46
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 46, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]47
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 47, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]47
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 47, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]47
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 47, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]48
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 48, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]48
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 48, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]48
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 48, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]49
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 49, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]49
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 49, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]49
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 49, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "50", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.10924094957545449`*^30",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 50, "]=", 3.1092409495754546*^+30],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "50", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.10924094957563923`*^30",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 50, "]=", 3.1092409495756392*^+30],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "50", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.7336563687532455`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 50, "]=", 12.733656368753245],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]51
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 51, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]51
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 51, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]51
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 51, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]52
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 52, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]52
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 52, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]52
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 52, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]53
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 53, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]53
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 53, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]53
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 53, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]54
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 54, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]54
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 54, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]54
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 54, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]55
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 55, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]55
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 55, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]55
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 55, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "56", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.86948501444175043`*^36",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 56, "]=", 1.8694850144417503*^+36],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "56", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.8694850144421462`*^36",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 56, "]=", 1.8694850144421458*^+36],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "56", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.4028554964844728`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 56, "]=", 12.402855496484474],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]57
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 57, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]57
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 57, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]57
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 57, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]58
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 58, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]58
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 58, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]58
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 58, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]59
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 59, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]59
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 59, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]59
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 59, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]60
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 60, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]60
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 60, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]60
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 60, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]61
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 61, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]61
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 61, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]61
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 61, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "62", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.91542820067436565`*^42",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 62, "]=", 1.9154282006743657*^+42],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "62", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.9154282006756496`*^42",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 62, "]=", 1.9154282006756494*^+42],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "62", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["11.8915216338526551`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 62, "]=", 11.891521633852655],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]63
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 63, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]63
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 63, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]63
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 63, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]64
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 64, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]64
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 64, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]64
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 64, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]65
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 65, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]65
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 65, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]65
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 65, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]66
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 66, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]66
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 66, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]66
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 66, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]67
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 67, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]67
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 67, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]67
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 67, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "68", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.176515481143658`*^48",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 68, "]=", 3.1765154811436585*^+48],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "68", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.17651548114928683`*^48",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 68, "]=", 3.1765154811492863*^+48],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "68", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["11.2496612864026634`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 68, "]=", 11.249661286402663],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]69
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 69, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]69
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 69, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]69
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 69, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]70
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 70, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]70
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 70, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]70
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 70, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]71
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 71, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]71
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 71, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]71
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 71, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]72
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 72, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]72
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 72, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]72
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 72, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]73
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 73, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]73
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 73, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]73
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 73, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "74", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.17294430030141683`*^54",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 74, "]=", 8.1729443003014175*^+54],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "74", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.17294430033435403`*^54",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 74, "]=", 8.1729443003343541*^+54],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "74", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["10.4823210912911912`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 74, "]=", 10.48232109129119],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]75
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 75, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]75
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 75, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]75
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 75, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]76
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 76, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]76
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 76, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]76
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 76, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]77
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 77, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]77
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 77, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]77
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 77, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]78
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 78, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]78
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 78, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]78
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 78, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]79
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 79, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]79
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 79, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]79
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 79, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "80", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.1486812779702813`*^61",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 80, "]=", 3.1486812779702813*^+61],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "80", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.14868127799914532`*^61",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 80, "]=", 3.1486812779991453*^+61],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "80", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["10.539642183570641`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 80, "]=", 10.539642183570642],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]81
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 81, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]81
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 81, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]81
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 81, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]82
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 82, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]82
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 82, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]82
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 82, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]83
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 83, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]83
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 83, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]83
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 83, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]84
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 84, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]84
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 84, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]84
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 84, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]85
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 85, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]85
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 85, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]85
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 85, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "86", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.76234343889216056`*^68",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 86, "]=", 1.7623434388921606*^+68],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "86", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.76234343893588878`*^68",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 86, "]=", 1.7623434389358889*^+68],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "86", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["10.3592371723128096`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 86, "]=", 10.35923717231281],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]87
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 87, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]87
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 87, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]87
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 87, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]88
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 88, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]88
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 88, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]88
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 88, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]89
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 89, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]89
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 89, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]89
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 89, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]90
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 90, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]90
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 90, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]90
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 90, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]91
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 91, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]91
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 91, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]91
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 91, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "92", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.39630148735044269`*^75",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 92, "]=", 1.3963014873504426*^+75],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "92", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.39630148745488957`*^75",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 92, "]=", 1.3963014874548896*^+75],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "92", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.98110421451605134`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 92, "]=", 9.9811042145160513],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]93
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 93, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]93
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 93, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]93
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 93, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]94
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 94, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]94
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 94, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]94
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 94, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]95
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 95, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]95
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 95, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]95
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 95, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]96
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 96, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]96
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 96, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]96
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 96, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]97
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 97, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]97
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 97, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]97
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 97, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "98", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.53101315227012912`*^82",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 98, "]=", 1.531013152270129*^+82],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "98", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.53101315257497283`*^82",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 98, "]=", 1.5310131525749728*^+82],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "98", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.51592253655219622`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 98, "]=", 9.5159225365521962],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]99
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 99, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]99
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 99, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]99
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 99, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]100
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 100, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]100
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 100, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]100
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 100, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]101
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 101, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]101
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 101, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]101
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 101, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]102
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 102, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]102
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 102, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]102
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 102, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]103
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 103, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]103
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 103, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]103
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 103, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "104", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.27757956435274788`*^89",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 104, "]=", 2.277579564352748*^+89],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "104", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.27757956515195392`*^89",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 104, "]=", 2.2775795651519545*^+89],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "104", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.09734096272069336`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 104, "]=", 9.0973409627206934],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]105
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 105, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]105
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 105, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]105
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 105, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]106
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 106, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]106
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 106, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]106
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 106, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]107
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 107, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]107
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 107, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]107
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 107, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]108
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 108, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]108
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 108, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]108
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 108, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]109
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 109, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]109
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 109, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]109
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 109, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "110", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.51688658905414719`*^96",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 110, "]=", 4.5168865890541468*^+96],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "110", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.51688658839194623`*^96",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 110, "]=", 4.5168865883919471*^+96],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "110", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.17901103995272649`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 110, "]=", 9.1790110399527265],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]111
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 111, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]111
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 111, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]111
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 111, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]112
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 112, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]112
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 112, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]112
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 112, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]113
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 113, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]113
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 113, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]113
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 113, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]114
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 114, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]114
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 114, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]114
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 114, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]115
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 115, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]115
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 115, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]115
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 115, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "116", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.17566060672972949`*^104",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 116, "]=", 1.1756606067297294*^+104],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "116", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.17566060126540761`*^104",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 116, "]=", 1.1756606012654076*^+104],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "116", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.26246373304455516`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 116, "]=", 8.2624637330445552],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]117
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 117, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]117
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 117, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]117
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 117, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]118
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 118, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]118
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 118, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]118
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 118, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]119
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 119, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]119
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 119, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]119
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 119, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]120
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 120, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]120
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 120, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]120
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 120, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]121
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 121, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]121
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 121, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]121
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 121, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "122", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.96013061818217426`*^111",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 122, "]=", 3.9601306181821735*^+111],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "122", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.96013051553837556`*^111",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 122, "]=", 3.9601305155383754*^+111],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "122", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.98866728627609745`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 122, "]=", 6.9886672862760975],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]123
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 123, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]123
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 123, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]123
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 123, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]124
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 124, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]124
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 124, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]124
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 124, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]125
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 125, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]125
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 125, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]125
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 125, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]126
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 126, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]126
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 126, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]126
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 126, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]127
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 127, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]127
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 127, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]127
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 127, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "128", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.7046198814819256`*^119",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 128, "]=", 1.7046198814819255*^+119],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "128", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.70461969980442118`*^119",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 128, "]=", 1.7046196998044211*^+119],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "128", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.74069884456804402`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 128, "]=", 6.740698844568044],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]129
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 129, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]129
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 129, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]129
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 129, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]130
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 130, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]130
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 130, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]130
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 130, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]131
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 131, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]131
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 131, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]131
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 131, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]132
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 132, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]132
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 132, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]132
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 132, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]133
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 133, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]133
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 133, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]133
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 133, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "134", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.26949272488439746`*^126",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 134, "]=", 9.2694927248843963*^+126],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "134", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.269489232742254`*^126",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 134, "]=", 9.2694892327422556*^+126],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "134", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.45690808751307088`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 134, "]=", 5.4569080875130709],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]135
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 135, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]135
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 135, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]135
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 135, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]136
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 136, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]136
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 136, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]136
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 136, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]137
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 137, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]137
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 137, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]137
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 137, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]138
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 138, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]138
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 138, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]138
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 138, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]139
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 139, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]139
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 139, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]139
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 139, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "140", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.30173172117175006`*^134",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 140, "]=", 6.3017317211717506*^+134],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "140", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.30172413949025411`*^134",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 140, "]=", 6.3017241394902554*^+134],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "140", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.12023446414215754`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 140, "]=", 5.1202344641421575],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]141
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 141, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]141
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 141, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]141
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 141, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]142
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 142, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]142
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 142, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]142
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 142, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]143
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 143, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]143
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 143, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]143
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 143, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]144
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 144, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]144
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 144, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]144
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 144, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]145
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 145, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]145
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 145, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]145
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 145, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "146", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.30509028872736898`*^142",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 146, "]=", 5.3050902887273697*^+142],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "146", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.30507152902095402`*^142",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 146, "]=", 5.3050715290209542*^+142],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "146", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.7267739624994931`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 146, "]=", 4.7267739624994931],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]147
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 147, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]147
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 147, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]147
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 147, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]148
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 148, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]148
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 148, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]148
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 148, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]149
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 149, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]149
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 149, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]149
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 149, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]150
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 150, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]150
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 150, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]150
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 150, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]151
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 151, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]151
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 151, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]151
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 151, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "152", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.48212299531088476`*^150",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 152, "]=", 5.4821229953108861*^+150],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "152", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.48207031040692971`*^150",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 152, "]=", 5.4820703104069309*^+150],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "152", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.27831380733331911`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 152, "]=", 4.2783138073333191],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]153
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 153, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]153
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 153, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]153
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 153, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]154
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 154, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]154
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 154, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]154
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 154, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]155
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 155, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]155
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 155, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]155
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 155, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]156
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 156, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]156
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 156, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]156
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 156, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]157
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 157, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]157
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 157, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]157
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 157, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "158", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.89799908947824214`*^158",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 158, "]=", 6.8979990894782429*^+158],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "158", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.89783329188953509`*^158",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 158, "]=", 6.897833291889533*^+158],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "158", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.78042178993544553`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 158, "]=", 3.7804217899354455],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]159
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 159, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]159
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 159, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]159
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 159, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]160
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 160, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]160
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 160, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]160
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 160, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]161
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 161, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]161
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 161, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]161
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 161, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]162
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 162, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]162
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 162, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]162
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 162, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]163
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 163, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]163
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 163, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]163
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 163, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "164", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.04900665633644574`*^167",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 164, "]=", 1.0490066563364456*^+167],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "164", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.04894962751677578`*^167",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 164, "]=", 1.0489496275167757*^+167],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "164", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.24390561694957568`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 164, "]=", 4.2439056169495757],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]165
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 165, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]165
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 165, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]165
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 165, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]166
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 166, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]166
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 166, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]166
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 166, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]167
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 167, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]167
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 167, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]167
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 167, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]168
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 168, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]168
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 168, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]168
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 168, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]169
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 169, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]169
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 169, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]169
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 169, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "170", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.91475109388169055`*^175",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 170, "]=", 1.9147510938816902*^+175],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "170", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.91454803059115796`*^175",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 170, "]=", 1.914548030591158*^+175],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "170", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.69236858058468442`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 170, "]=", 3.6923685805846844],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]171
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 171, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]171
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 171, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]171
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 171, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]172
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 172, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]172
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 172, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]172
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 172, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]173
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 173, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]173
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 173, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]173
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 173, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]174
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 174, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]174
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 174, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]174
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 174, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]175
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 175, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]175
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 175, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]175
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 175, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "176", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.16793715097306805`*^183",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 3, ",", 176, "]=", 4.1679371509730683*^+183],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "176", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.1673036511534871`*^183",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 3, ",", 176, "]=", 4.1673036511534871*^+183],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "176", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.19825350446626543`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 3, ",", 176, "]=", 3.1982535044662654],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]177
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 177, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]177
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 177, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]177
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 177, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]178
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 178, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]178
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 178, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]178
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 178, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]179
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 179, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]179
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 179, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]179
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 179, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]180
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 3, ",", 180, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]180
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 3, ",", 180, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]","\[InvisibleSpace]180
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 3, ",", 180, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    \("   "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 4, ",", 3, "]=", 1.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "formexact[", 5, ",", 4, ",", 3, "]=", 1.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "3", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 1]]}],
      SequenceForm[ "exactdigits[", 5, ",", 4, ",", 3, "]=", 
        DirectedInfinity[ 1]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 4, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "9", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["13.9999999999999991`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 4, ",", 9, "]=", 14.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "9", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["13.9999999999999991`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "formexact[", 5, ",", 4, ",", 9, "]=", 14.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "9", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 1]]}],
      SequenceForm[ "exactdigits[", 5, ",", 4, ",", 9, "]=", 
        DirectedInfinity[ 1]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]10
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 10, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]11
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 11, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]11
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 11, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]11
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 11, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]12
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 12, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]12
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 12, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]12
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 12, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]13
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 13, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]13
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 13, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]13
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 13, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]14
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 14, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]14
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 14, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]14
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 14, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "15", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5839.16666666666639`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 4, ",", 15, "]=", 5839.1666666666661],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "15", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5839.16666666666728`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 15, "]=", 5839.166666666667],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "15", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["15.0411998265592465`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 15, "]=", 15.041199826559247],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]16
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 16, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]16
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 16, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]16
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 16, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]17
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 17, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]17
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 17, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]17
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 17, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]18
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 18, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]18
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 18, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]18
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 18, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]19
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 19, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]19
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 19, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]19
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 19, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]20
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 20, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]20
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 20, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]20
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 20, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "21", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.76031411111111069`*^7",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 4, ",", 21, "]=", 17603141.111111104],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "21", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.76031411111111113`*^7",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 21, "]=", 17603141.111111112],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "21", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["15.1278098829274938`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 21, "]=", 15.127809882927494],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]22
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 22, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]22
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 22, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]22
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 22, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]23
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 23, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]23
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 23, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]23
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 23, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]24
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 24, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]24
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 24, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]24
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 24, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]25
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 25, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]25
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 25, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]25
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 25, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]26
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 26, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]26
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 26, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]26
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 26, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "27", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.17112741679166765`*^11",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 4, ",", 27, "]=", 217112741679.16675],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "27", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.17112741679166676`*^11",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 27, "]=", 217112741679.16666],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "27", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["15.0383286802400562`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 27, "]=", 15.038328680240056],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]28
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 28, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]28
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 28, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]28
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 28, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]29
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 29, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]29
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 29, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]29
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 29, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]30
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 30, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]30
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 30, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]30
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 30, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]31
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 31, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]31
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 31, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]31
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 31, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]32
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 32, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]32
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 32, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]32
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 32, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "33", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.01557083587039898`*^15",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 4, ",", 33, "]=", 8015570835870400.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "33", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.01557083587037588`*^15",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 33, "]=", 8015570835870375.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "33", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["13.6020599913279616`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 33, "]=", 13.602059991327963],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]34
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 34, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]34
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 34, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]34
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 34, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]35
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 35, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]35
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 35, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]35
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 35, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]36
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 36, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]36
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 36, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]36
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 36, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]37
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 37, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]37
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 37, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]37
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 37, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]38
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 38, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]38
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 38, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]38
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 38, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "39", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.26438493534447182`*^20",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 39, "]=", 7.2643849353444721*^+20],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "39", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.26438493534441942`*^20",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 39, "]=", 7.2643849353444196*^+20],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "39", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["13.2804300823843579`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 39, "]=", 13.280430082384358],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]40
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 40, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]40
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 40, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]40
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 40, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]41
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 41, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]41
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 41, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]41
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 41, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]42
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 42, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]42
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 42, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]42
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 42, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]43
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 43, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]43
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 43, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]43
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 43, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]44
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 44, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]44
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 44, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]44
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 44, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "45", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.4087821705113706`*^26",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 45, "]=", 1.4087821705113706*^+26],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "45", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.40878217051134368`*^26",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 45, "]=", 1.4087821705113434*^+26],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "45", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["13.5663230604702178`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 45, "]=", 13.566323060470218],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]46
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 46, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]46
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 46, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]46
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 46, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]47
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 47, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]47
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 47, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]47
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 47, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]48
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 48, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]48
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 48, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]48
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 48, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]49
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 49, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]49
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 49, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]49
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 49, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]50
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 50, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]50
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 50, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]50
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 50, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "51", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.28570961427890928`*^31",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 51, "]=", 5.2857096142789091*^+31],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "51", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.28570961427858776`*^31",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 51, "]=", 5.2857096142785876*^+31],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "51", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.4927420136968048`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 51, "]=", 12.492742013696805],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]52
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 52, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]52
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 52, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]52
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 52, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]53
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 53, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]53
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 53, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]53
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 53, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]54
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 54, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]54
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 54, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]54
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 54, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]55
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 55, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]55
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 55, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]55
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 55, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]56
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 56, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]56
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 56, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]56
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 56, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "57", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.55202152744059551`*^37",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 57, "]=", 3.5520215274405959*^+37],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "57", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.55202152744007637`*^37",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 57, "]=", 3.5520215274400769*^+37],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "57", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.284842619769869`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 57, "]=", 12.284842619769869],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]58
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 58, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]58
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 58, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]58
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 58, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]59
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 59, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]59
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 59, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]59
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 59, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]60
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 60, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]60
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 60, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]60
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 60, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]61
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 61, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]61
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 61, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]61
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 61, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]62
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 62, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]62
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 62, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]62
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 62, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "63", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.02239922141977057`*^43",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 63, "]=", 4.0223992214197711*^+43],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "63", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.02239922141886374`*^43",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 63, "]=", 4.022399221418864*^+43],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "63", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.0423149295818987`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 63, "]=", 12.042314929581899],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]64
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 64, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]64
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 64, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]64
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 64, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]65
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 65, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]65
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 65, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]65
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 65, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]66
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 66, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]66
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 66, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]66
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 66, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]67
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 67, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]67
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 67, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]67
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 67, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]68
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 68, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]68
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 68, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]68
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 68, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "69", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.3059856066443487`*^49",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 69, "]=", 7.3059856066443487*^+49],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "69", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.30598560664335838`*^49",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 69, "]=", 7.305985606643359*^+49],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "69", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.0045175893318045`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 69, "]=", 12.004517589331805],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]70
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 70, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]70
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 70, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]70
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 70, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]71
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 71, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]71
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 71, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]71
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 71, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]72
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 72, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]72
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 72, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]72
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 72, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]73
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 73, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]73
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 73, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]73
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 73, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]74
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 74, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]74
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 74, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]74
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 74, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "75", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.04323607508273186`*^56",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 75, "]=", 2.043236075082732*^+56],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "75", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.0432360750835885`*^56",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 75, "]=", 2.0432360750835883*^+56],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "75", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.0673670718664216`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 75, "]=", 12.067367071866421],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]76
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 76, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]76
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 76, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]76
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 76, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]77
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 77, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]77
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 77, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]77
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 77, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]78
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 78, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]78
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 78, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]78
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 78, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]79
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 79, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]79
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 79, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]79
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 79, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]80
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 80, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]80
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 80, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]80
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 80, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "81", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.50143945058327688`*^62",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 81, "]=", 8.5014394505832781*^+62],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "81", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.50143945059769201`*^62",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 81, "]=", 8.5014394505976922*^+62],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "81", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["10.8412136775455403`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 81, "]=", 10.841213677545539],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]82
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 82, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]82
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 82, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]82
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 82, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]83
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 83, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]83
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 83, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]83
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 83, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]84
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 84, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]84
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 84, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]84
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 84, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]85
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 85, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]85
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 85, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]85
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 85, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]86
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 86, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]86
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 86, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]86
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 86, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "87", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.11079597290271614`*^69",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 87, "]=", 5.1107959729027162*^+69],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "87", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.11079597291407772`*^69",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 87, "]=", 5.1107959729140773*^+69],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "87", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["10.9445774885879876`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 87, "]=", 10.944577488587989],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]88
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 88, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]88
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 88, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]88
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 88, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]89
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 89, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]89
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 89, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]89
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 89, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]90
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 90, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]90
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 90, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]90
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 90, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]91
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 91, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]91
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 91, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]91
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 91, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]92
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 92, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]92
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 92, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]92
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 92, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "93", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.32853461115718296`*^76",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 93, "]=", 4.3285346111571833*^+76],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "93", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.32853461111015569`*^76",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 93, "]=", 4.3285346111101572*^+76],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "93", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["10.3276612428834235`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 93, "]=", 10.327661242883423],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]94
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 94, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]94
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 94, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]94
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 94, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]95
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 95, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]95
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 95, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]95
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 95, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]96
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 96, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]96
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 96, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]96
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 96, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]97
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 97, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]97
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 97, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]97
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 97, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]98
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 98, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]98
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 98, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]98
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 98, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "99", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.05234340400477854`*^83",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 99, "]=", 5.0523434040047796*^+83],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "99", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.05234340349741017`*^83",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 99, "]=", 5.0523434034974107*^+83],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "99", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.29467612120963337`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 99, "]=", 9.2946761212096334],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]100
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 100, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]100
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 100, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]100
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 100, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]101
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 101, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]101
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 101, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]101
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 101, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]102
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 102, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]102
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 102, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]102
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 102, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]103
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 103, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]103
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 103, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]103
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 103, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]104
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 104, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]104
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 104, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]104
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 104, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "105", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.97152848192934992`*^90",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 105, "]=", 7.9715284819293493*^+90],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "105", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.97152847803184094`*^90",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 105, "]=", 7.9715284780318409*^+90],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "105", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.40921294561761101`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 105, "]=", 8.409212945617611],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]106
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 106, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]106
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 106, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]106
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 106, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]107
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 107, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]107
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 107, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]107
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 107, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]108
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 108, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]108
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 108, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]108
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 108, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]109
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 109, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]109
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 109, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]109
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 109, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]110
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 110, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]110
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 110, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]110
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 110, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "111", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.67124804062905703`*^98",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 111, "]=", 1.671248040629057*^+98],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "111", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.67124803770502055`*^98",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 111, "]=", 1.6712480377050204*^+98],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "111", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.53401719325208318`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 111, "]=", 8.5340171932520832],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]112
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 112, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]112
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 112, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]112
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 112, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]113
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 113, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]113
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 113, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]113
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 113, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]114
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 114, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]114
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 114, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]114
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 114, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]115
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 115, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]115
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 115, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]115
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 115, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]116
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 116, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]116
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 116, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]116
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 116, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "117", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.58507636680013863`*^105",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 117, "]=", 4.5850763668001381*^+105],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "117", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.5850763449350893`*^105",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 117, "]=", 4.5850763449350895*^+105],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "117", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.66024955178957611`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 117, "]=", 7.6602495517895761],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]118
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 118, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]118
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 118, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]118
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 118, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]119
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 119, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]119
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 119, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]119
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 119, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]120
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 120, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]120
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 120, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]120
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 120, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]121
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 121, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]121
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 121, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]121
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 121, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]122
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 122, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]122
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 122, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]122
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 122, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "123", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.6236535258526108`*^113",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 123, "]=", 1.6236535258526111*^+113],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "123", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.62365351137073403`*^113",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 123, "]=", 1.6236535113707341*^+113],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "123", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.83917514753088084`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 123, "]=", 7.8391751475308808],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]124
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 124, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]124
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 124, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]124
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 124, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]125
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 125, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]125
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 125, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]125
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 125, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]126
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 126, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]126
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 126, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]126
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 126, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]127
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 127, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]127
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 127, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]127
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 127, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]128
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 128, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]128
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 128, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]128
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 128, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "129", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.32986473283687267`*^120",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 129, "]=", 7.3298647328368745*^+120],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "129", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.32986470915901211`*^120",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 129, "]=", 7.3298647091590115*^+120],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "129", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.6256574970366131`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 129, "]=", 7.6256574970366131],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]130
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 130, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]130
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 130, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]130
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 130, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]131
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 131, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]131
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 131, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]131
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 131, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]132
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 132, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]132
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 132, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]132
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 132, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]133
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 133, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]133
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 133, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]133
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 133, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]134
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 134, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]134
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 134, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]134
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 134, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "135", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.1712698876084655`*^128",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 135, "]=", 4.1712698876084648*^+128],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "135", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.17127015473401385`*^128",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 135, "]=", 4.1712701547340149*^+128],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "135", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.57328457049622727`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 135, "]=", 6.5732845704962273],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]136
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 136, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]136
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 136, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]136
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 136, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]137
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 137, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]137
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 137, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]137
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 137, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]138
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 138, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]138
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 138, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]138
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 138, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]139
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 139, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]139
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 139, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]139
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 139, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]140
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 140, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]140
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 140, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]140
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 140, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "141", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.96180923654925809`*^136",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 141, "]=", 2.9618092365492579*^+136],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "141", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.96181034556041922`*^136",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 141, "]=", 2.96181034556042*^+136],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "141", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.95506408267544884`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 141, "]=", 5.9550640826754488],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]142
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 142, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]142
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 142, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]142
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 142, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]143
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 143, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]143
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 143, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]143
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 143, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]144
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 144, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]144
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 144, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]144
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 144, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]145
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 145, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]145
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 145, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]145
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 145, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]146
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 146, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]146
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 146, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]146
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 146, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "147", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.5994812174976789`*^144",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 147, "]=", 2.5994812174976787*^+144],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "147", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.59948504922026746`*^144",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 147, "]=", 2.5994850492202676*^+144],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "147", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.41660594073695733`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 147, "]=", 5.4166059407369573],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]148
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 148, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]148
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 148, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]148
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 148, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]149
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 149, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]149
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 149, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]149
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 149, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]150
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 150, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]150
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 150, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]150
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 150, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]151
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 151, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]151
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 151, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]151
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 151, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]152
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 152, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]152
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 152, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]152
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 152, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "153", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.79584232842950308`*^152",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 153, "]=", 2.7958423284295036*^+152],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "153", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.7958558583075348`*^152",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 153, "]=", 2.7958558583075346*^+152],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "153", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.86870611845918688`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 153, "]=", 4.8687061184591869],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]154
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 154, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]154
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 154, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]154
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 154, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]155
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 155, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]155
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 155, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]155
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 155, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]156
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 156, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]156
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 156, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]156
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 156, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]157
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 157, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]157
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 157, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]157
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 157, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]158
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 158, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]158
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 158, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]158
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 158, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "159", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.655800093832819`*^160",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 159, "]=", 3.6558000938328185*^+160],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "159", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.6558516447014524`*^160",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 159, "]=", 3.6558516447014523*^+160],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "159", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.28776401244275007`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 159, "]=", 4.2877640124427501],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]160
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 160, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]160
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 160, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]160
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 160, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]161
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 161, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]161
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 161, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]161
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 161, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]162
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 162, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]162
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 162, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]162
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 162, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]163
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 163, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]163
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 163, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]163
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 163, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]164
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 164, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]164
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 164, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]164
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 164, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "165", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.76900806714114811`*^168",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 165, "]=", 5.7690080671411478*^+168],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "165", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.76922295134226459`*^168",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 165, "]=", 5.7692229513422664*^+168],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "165", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.66779551386767366`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 165, "]=", 3.6677955138676737],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]166
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 166, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]166
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 166, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]166
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 166, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]167
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 167, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]167
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 167, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]167
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 167, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]168
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 168, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]168
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 168, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]168
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 168, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]169
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 169, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]169
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 169, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]169
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 169, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]170
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 170, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]170
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 170, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]170
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 170, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "171", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.09119526838485425`*^177",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 171, "]=", 1.0911952683848542*^+177],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "171", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.09129237743695984`*^177",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 171, "]=", 1.09129237743696*^+177],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "171", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.01274028506225022`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 171, "]=", 4.0127402850622502],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]172
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 172, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]172
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 172, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]172
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 172, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]173
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 173, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]173
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 173, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]173
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 173, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]174
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 174, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]174
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 174, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]174
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 174, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]175
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 175, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]175
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 175, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]175
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 175, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]176
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 176, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]176
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 176, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]176
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 176, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "177", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.45825064580892327`*^185",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 4, ",", 177, "]=", 2.4582506458089234*^+185],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "177", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.45870915418055702`*^185",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 4, ",", 177, "]=", 2.4587091541805573*^+185],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "177", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.33865273039489807`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 4, ",", 177, "]=", 3.3386527303948981],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]178
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 178, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]178
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 178, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]178
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 178, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]179
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 179, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]179
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 179, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]179
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 179, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]180
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 4, ",", 180, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]180
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 4, ",", 180, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]4
        \[InvisibleSpace]","\[InvisibleSpace]180
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 4, ",", 180, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    \("   "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]0
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 0, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]1
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 1, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]2
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 2, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]3
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 3, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 5, ",", 4, "]=", 1.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "formexact[", 5, ",", 5, ",", 4, "]=", 1.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "4", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 1]]}],
      SequenceForm[ "exactdigits[", 5, ",", 5, ",", 4, "]=", 
        DirectedInfinity[ 1]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 5, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]6
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 6, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]7
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 7, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]8
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 8, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]9
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 9, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "10", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["35.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 5, ",", 10, "]=", 35.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "10", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["35.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "formexact[", 5, ",", 5, ",", 10, "]=", 35.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "10", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 1]]}],
      SequenceForm[ "exactdigits[", 5, ",", 5, ",", 10, "]=", 
        DirectedInfinity[ 1]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]11
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 11, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]11
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 11, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]11
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 11, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]12
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 12, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]12
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 12, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]12
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 12, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]13
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 13, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]13
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 13, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]13
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 13, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]14
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 14, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]14
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 14, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]14
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 14, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]15
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 15, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]15
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 15, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]15
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 15, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "16", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["23356.66666666667`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 5, ",", 16, "]=", 23356.666666666668],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "16", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["23356.66666666667`",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 16, "]=", 23356.666666666668],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "16", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 1]]}],
      SequenceForm[ "exactdigits[", 5, ",", 5, ",", 16, "]=", 
        DirectedInfinity[ 1]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]17
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 17, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]17
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 17, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]17
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 17, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]18
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 18, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]18
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 18, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]18
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 18, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]19
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 19, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]19
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 19, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]19
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 19, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]20
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 20, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]20
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 20, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]20
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 20, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]21
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 21, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]21
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 21, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]21
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 21, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "22", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.68172761111111057`*^7",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 5, ",", 22, "]=", 96817276.111111104],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "22", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.68172761111111057`*^7",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 22, "]=", 96817276.111111104],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "22", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        InterpretationBox["\[Infinity]",
          DirectedInfinity[ 1]]}],
      SequenceForm[ "exactdigits[", 5, ",", 5, ",", 22, "]=", 
        DirectedInfinity[ 1]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]23
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 23, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]23
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 23, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]23
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 23, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]24
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 24, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]24
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 24, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]24
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 24, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]25
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 25, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]25
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 25, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]25
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 25, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]26
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 26, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]26
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 26, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]26
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 26, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]27
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 27, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]27
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 27, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]27
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 27, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "28", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.51978919175416704`*^12",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 5, ",", 28, "]=", 1519789191754.167],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "28", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.51978919175416677`*^12",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 28, "]=", 1519789191754.1667],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "28", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["15.612359947967775`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 28, "]=", 15.612359947967775],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]29
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 29, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]29
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 29, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]29
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 29, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]30
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 30, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]30
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 30, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]30
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 30, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]31
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 31, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]31
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 31, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]31
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 31, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]32
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 32, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]32
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 32, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]32
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 32, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]33
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 33, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]33
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 33, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]33
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 33, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "34", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.81323521048981728`*^16",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ "form[", 5, ",", 5, ",", 34, "]=", 68132352104898176.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "34", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.81323521048981994`*^16",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 34, "]=", 68132352104898192.0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "34", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["14.795880017344074`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 34, "]=", 14.795880017344075],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]35
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 35, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]35
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 35, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]35
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 35, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]36
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 36, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]36
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 36, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]36
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 36, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]37
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 37, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]37
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 37, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]37
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 37, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]38
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 38, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]38
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 38, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]38
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 38, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]39
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 39, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]39
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 39, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]39
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 39, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "40", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.26438493534435814`*^21",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 40, "]=", 7.2643849353443588*^+21],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "40", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.2643849353444212`*^21",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 40, "]=", 7.2643849353444207*^+21],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "40", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["13.2085480750782324`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 40, "]=", 13.208548075078232],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]41
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 41, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]41
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 41, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]41
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 41, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]42
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 42, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]42
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 42, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]42
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 42, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]43
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 43, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]43
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 43, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]43
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 43, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]44
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 44, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]44
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 44, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]44
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 44, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]45
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 45, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]45
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 45, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]45
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 45, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "46", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.62009949608798597`*^27",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 46, "]=", 1.6200994960879858*^+27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "46", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.62009949608804504`*^27",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 46, "]=", 1.6200994960880449*^+27],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "46", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["13.2284217048531127`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 46, "]=", 13.228421704853112],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]47
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 47, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]47
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 47, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]47
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 47, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]48
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 48, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]48
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 48, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]48
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 48, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]49
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 49, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]49
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 49, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]49
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 49, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]50
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 50, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]50
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 50, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]50
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 50, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]51
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 51, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]51
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 51, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]51
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 51, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "52", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.87142249856155729`*^32",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 52, "]=", 6.8714224985615565*^+32],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "52", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.87142249856216302`*^32",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 52, "]=", 6.8714224985621632*^+32],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "52", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.2170081513174055`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 52, "]=", 12.217008151317405],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]53
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 53, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]53
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 53, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]53
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 53, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]54
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 54, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]54
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 54, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]54
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 54, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]55
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 55, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]55
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 55, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]55
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 55, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]56
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 56, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]56
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 56, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]56
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 56, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]57
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 57, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]57
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 57, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]57
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 57, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "58", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.15043121478752485`*^38",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 58, "]=", 5.1504312147875258*^+38],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "58", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.15043121478811194`*^38",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 58, "]=", 5.1504312147881121*^+38],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "58", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["12.2318586082792424`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 58, "]=", 12.231858608279243],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]59
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 59, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]59
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 59, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]59
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 59, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]60
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 60, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]60
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 60, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]60
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 60, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]61
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 61, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]61
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 61, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]61
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 61, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]62
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 62, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]62
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 62, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]62
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 62, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]63
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 63, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]63
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 63, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]63
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 63, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "64", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.4358387542713924`*^44",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 64, "]=", 6.4358387542713929*^+44],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "64", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.43583875427018181`*^44",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 64, "]=", 6.4358387542701823*^+44],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "64", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["11.9169970620181331`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 64, "]=", 11.916997062018133],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]65
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 65, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]65
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 65, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]65
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 65, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]66
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 66, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]66
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 66, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]66
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 66, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]67
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 67, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]67
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 67, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]67
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 67, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]68
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 68, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]68
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 68, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]68
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 68, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]69
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 69, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]69
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 69, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]69
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 69, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "70", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.27854748116521754`*^51",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 70, "]=", 1.2785474811652174*^+51],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "70", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.27854748116258765`*^51",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 70, "]=", 1.2785474811625877*^+51],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "70", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["11.5800919049545858`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 70, "]=", 11.580091904954585],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]71
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 71, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]71
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 71, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]71
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 71, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]72
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 72, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]72
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 72, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]72
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 72, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]73
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 73, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]73
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 73, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]73
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 73, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]74
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 74, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]74
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 74, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]74
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 74, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]75
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 75, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]75
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 75, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]75
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 75, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "76", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.88214854269569542`*^57",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 76, "]=", 3.8821485426956955*^+57],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "76", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.88214854265881825`*^57",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 76, "]=", 3.8821485426588178*^+57],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "76", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["10.4332353877576133`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 76, "]=", 10.433235387757613],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]77
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 77, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]77
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 77, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]77
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 77, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]78
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 78, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]78
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 78, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]78
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 78, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]79
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 79, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]79
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 79, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]79
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 79, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]80
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 80, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]80
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 80, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]80
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 80, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]81
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 81, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]81
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 81, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]81
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 81, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "82", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.74279508743045923`*^64",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 82, "]=", 1.7427950874304596*^+64],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "82", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.7427950873725269`*^64",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 82, "]=", 1.7427950873725271*^+64],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "82", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["10.2370780040537079`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 82, "]=", 10.237078004053707],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]83
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 83, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]83
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 83, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]83
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 83, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]84
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 84, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]84
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 84, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]84
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 84, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]85
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 85, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]85
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 85, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]85
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 85, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]86
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 86, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]86
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 86, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]86
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 86, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]87
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 87, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]87
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 87, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]87
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 87, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "88", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.12437511415237634`*^71",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 88, "]=", 1.1243751141523762*^+71],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "88", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.12437511404109735`*^71",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 88, "]=", 1.1243751140410971*^+71],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "88", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.95358663975339652`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 88, "]=", 9.9535866397533965],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]89
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 89, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]89
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 89, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]89
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 89, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]90
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 90, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]90
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 90, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]90
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 90, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]91
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 91, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]91
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 91, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]91
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 91, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]92
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 92, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]92
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 92, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]92
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 92, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]93
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 93, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]93
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 93, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]93
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 93, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "94", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.01720563388341433`*^78",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 94, "]=", 1.0172056338834144*^+78],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "94", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.017205633610887`*^78",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 94, "]=", 1.0172056336108871*^+78],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "94", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.564590096938133`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 94, "]=", 9.564590096938133],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]95
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 95, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]95
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 95, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]95
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 95, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]96
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 96, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]96
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 96, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]96
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 96, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]97
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 97, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]97
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 97, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]97
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 97, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]98
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 98, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]98
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 98, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]98
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 98, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]99
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 99, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]99
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 99, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]99
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 99, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "100", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.26308585175704579`*^85",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 100, "]=", 1.263085851757046*^+85],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "100", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.26308585087435276`*^85",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 100, "]=", 1.2630858508743527*^+85],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "100", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.05419015627920487`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 100, "]=", 9.0541901562792049],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]101
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 101, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]101
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 101, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]101
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 101, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]102
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 102, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]102
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 102, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]102
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 102, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]103
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 103, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]103
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 103, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]103
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 103, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]104
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 104, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]104
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 104, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]104
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 104, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]105
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 105, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]105
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 105, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]105
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 105, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "106", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.11245505055418769`*^92",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 106, "]=", 2.1124550505541876*^+92],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "106", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.11245504667843775`*^92",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 106, "]=", 2.1124550466784376*^+92],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "106", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["8.41164424789403142`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 106, "]=", 8.4116442478940314],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]107
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 107, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]107
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 107, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]107
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 107, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]108
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 108, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]108
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 108, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]108
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 108, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]109
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 109, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]109
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 109, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]109
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 109, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]110
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 110, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]110
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 110, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]110
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 110, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]111
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 111, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]111
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 111, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]111
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 111, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "112", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.67949452851388425`*^99",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 112, "]=", 4.6794945285138841*^+99],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "112", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.67949450557405555`*^99",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 112, "]=", 4.6794945055740563*^+99],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "112", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.63940984536620248`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 112, "]=", 7.6394098453662025],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]113
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 113, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]113
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 113, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]113
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 113, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]114
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 114, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]114
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 114, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]114
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 114, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]115
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 115, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]115
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 115, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]115
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 115, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]116
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 116, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]116
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 116, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]116
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 116, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]117
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 117, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]117
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 117, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]117
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 117, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "118", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.3525975394152998`*^107",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 118, "]=", 1.3525975394153001*^+107],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "118", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.35259752175585168`*^107",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 118, "]=", 1.3525975217558516*^+107],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "118", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["7.75302286361166181`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 118, "]=", 7.7530228636116618],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]119
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 119, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]119
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 119, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]119
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 119, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]120
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 120, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]120
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 120, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]120
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 120, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]121
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 121, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]121
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 121, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]121
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 121, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]122
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 122, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]122
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 122, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]122
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 122, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]123
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 123, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]123
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 123, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]123
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 123, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "124", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.03332605431124768`*^114",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 124, "]=", 5.0333260543112483*^+114],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "124", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.03332588524927704`*^114",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 124, "]=", 5.0333258852492761*^+114],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "124", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.7719540692062452`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 124, "]=", 6.7719540692062452],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]125
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 125, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]125
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 125, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]125
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 125, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]126
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 126, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]126
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 126, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]126
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 126, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]127
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 127, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]127
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 127, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]127
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 127, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]128
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 128, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]128
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 128, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]128
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 128, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]129
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 129, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]129
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 129, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]129
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 129, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "130", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.38220622420695082`*^122",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 130, "]=", 2.382206224206951*^+122],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "130", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.382206030476679`*^122",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 130, "]=", 2.3822060304766788*^+122],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "130", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.71280251136711569`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 130, "]=", 6.7128025113671157],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]131
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 131, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]131
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 131, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]131
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 131, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]132
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 132, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]132
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 132, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]132
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 132, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]133
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 133, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]133
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 133, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]133
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 133, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]134
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 134, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]134
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 134, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]134
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 134, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]135
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 135, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]135
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 135, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]135
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 135, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "136", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.41823210999350663`*^130",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 136, "]=", 1.4182321099935066*^+130],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "136", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.41823185260956474`*^130",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 136, "]=", 1.4182318526095652*^+130],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "136", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.58941855292570721`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 136, "]=", 6.5894185529257072],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]137
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 137, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]137
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 137, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]137
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 137, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]138
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 138, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]138
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 138, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]138
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 138, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]139
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 139, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]139
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 139, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]139
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 139, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]140
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 140, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]140
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 140, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]140
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 140, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]141
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 141, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]141
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 141, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]141
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 141, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "142", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.05144305446071206`*^138",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 142, "]=", 1.0514430544607121*^+138],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "142", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.05144267267394897`*^138",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 142, "]=", 1.051442672673949*^+138],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "142", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.41817913301889575`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 142, "]=", 6.4181791330188958],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]143
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 143, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]143
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 143, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]143
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 143, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]144
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 144, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]144
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 144, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]144
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 144, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]145
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 145, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]145
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 145, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]145
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 145, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]146
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 146, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]146
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 146, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]146
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 146, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]147
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 147, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]147
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 147, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]147
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 147, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "148", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.61810053165828549`*^145",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 148, "]=", 9.6181005316582891*^+145],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "148", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["9.6180946821149913`*^145",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 148, "]=", 9.6180946821149907*^+145],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "148", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.2328780400213759`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 148, "]=", 5.2328780400213759],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]149
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 149, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]149
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 149, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]149
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 149, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]150
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 150, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]150
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 150, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]150
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 150, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]151
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 151, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]151
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 151, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]151
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 151, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]152
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 152, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]152
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 152, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]152
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 152, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]153
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 153, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]153
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 153, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]153
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 153, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "154", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.07640517866914176`*^154",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 154, "]=", 1.0764051786691419*^+154],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "154", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.07640450544840104`*^154",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 154, "]=", 1.076404505448401*^+154],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "154", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["6.17184251248565374`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 154, "]=", 6.1718425124856537],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]155
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 155, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]155
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 155, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]155
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 155, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]156
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 156, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]156
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 156, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]156
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 156, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]157
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 157, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]157
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 157, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]157
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 157, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]158
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 158, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]158
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 158, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]158
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 158, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]159
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 159, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]159
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 159, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]159
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 159, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "160", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.46233911264104188`*^162",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 160, "]=", 1.4623391126410419*^+162],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "160", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.46234065788058087`*^162",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 160, "]=", 1.462340657880581*^+162],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "160", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["5.81100418780110317`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 160, "]=", 5.8110041878011032],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]161
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 161, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]161
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 161, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]161
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 161, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]162
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 162, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]162
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 162, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]162
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 162, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]163
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 163, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]163
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 163, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]163
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 163, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]164
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 164, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]164
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 164, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]164
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 164, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]165
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 165, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]165
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 165, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]165
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 165, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "166", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.39420203666094`*^170",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 166, "]=", 2.3942020366609406*^+170],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "166", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["2.39422752480704081`*^170",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 166, "]=", 2.3942275248070406*^+170],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "166", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.59366175212761618`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 166, "]=", 4.5936617521276162],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]167
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 167, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]167
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 167, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]167
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 167, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]168
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 168, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]168
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 168, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]168
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 168, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]169
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 169, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]169
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 169, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]169
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 169, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]170
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 170, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]170
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 170, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]170
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 170, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]171
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 171, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]171
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 171, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]171
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 171, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "172", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.69231038815339651`*^178",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 172, "]=", 4.6923103881533955*^+178],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "172", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["4.69255722297892852`*^178",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 172, "]=", 4.6925572229789286*^+178],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "172", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.60759356639798056`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 172, "]=", 3.6075935663979806],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]173
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 173, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]173
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 173, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]173
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 173, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]174
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 174, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]174
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 174, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]174
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 174, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]175
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 175, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]175
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 175, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]175
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 175, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]176
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 176, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]176
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 176, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]176
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 176, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]177
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 177, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]177
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 177, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]177
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 177, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("form["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "178", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.09388719091854769`*^187",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "form[", 5, ",", 5, ",", 178, "]=", 1.0938871909185475*^+187],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("formexact["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "178", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["1.09412557361034812`*^187",
          StyleBoxAutoDelete->True,
          PrintPrecision->16]}],
      SequenceForm[ 
      "formexact[", 5, ",", 5, ",", 178, "]=", 1.094125573610348*^+187],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      \("exactdigits["\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", 
        \(","\), "\[InvisibleSpace]", "5", "\[InvisibleSpace]", \(","\), 
        "\[InvisibleSpace]", "178", "\[InvisibleSpace]", \("]="\), 
        "\[InvisibleSpace]", 
        StyleBox["3.62272528051082076`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}],
      SequenceForm[ 
      "exactdigits[", 5, ",", 5, ",", 178, "]=", 3.6227252805108208],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]179
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 179, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]179
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 179, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]179
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 179, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("form["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]180
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "form[", 5, ",", 5, ",", 180, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("formexact["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]180
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "formexact[", 5, ",", 5, ",", 180, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("abserror["\[InvisibleSpace]5\[InvisibleSpace]","\[InvisibleSpace]5
        \[InvisibleSpace]","\[InvisibleSpace]180
        \[InvisibleSpace]"]="\[InvisibleSpace]0\),
      SequenceForm[ "abserror[", 5, ",", 5, ",", 180, "]=", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    \("    "\)], "Print"],

Cell[BoxData[
    \({705.949999999999988`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MemoryInUse[]\)], "Input"],

Cell[BoxData[
    \(1371512\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
WindowSize->{590, 412},
WindowMargins->{{70, Automatic}, {Automatic, 78}},
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 1300, 22, 628, "Subsection"],

Cell[CellGroupData[{
Cell[3034, 75, 143, 4, 68, "Section"],

Cell[CellGroupData[{
Cell[3202, 83, 107, 3, 44, "Subsection"],
Cell[3312, 88, 62, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3411, 94, 122, 4, 44, "Subsection"],
Cell[3536, 100, 88, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[3649, 105, 142, 2, 43, "Input"],
Cell[3794, 109, 175, 3, 37, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4006, 117, 361, 6, 75, "Input"],
Cell[4370, 125, 326, 7, 38, "Print"],
Cell[4699, 134, 300, 6, 22, "Print"],
Cell[5002, 142, 326, 7, 38, "Print"],
Cell[5331, 151, 328, 7, 38, "Print"],
Cell[5662, 160, 302, 6, 22, "Print"],
Cell[5967, 168, 302, 6, 22, "Print"],
Cell[6272, 176, 37, 1, 22, "Print"],
Cell[6312, 179, 300, 6, 22, "Print"],
Cell[6615, 187, 300, 6, 22, "Print"],
Cell[6918, 195, 300, 6, 22, "Print"],
Cell[7221, 203, 300, 6, 22, "Print"],
Cell[7524, 211, 300, 6, 22, "Print"],
Cell[7827, 219, 300, 6, 22, "Print"],
Cell[8130, 227, 300, 6, 22, "Print"],
Cell[8433, 235, 37, 1, 22, "Print"],
Cell[8473, 238, 300, 6, 22, "Print"],
Cell[8776, 246, 300, 6, 22, "Print"],
Cell[9079, 254, 300, 6, 22, "Print"],
Cell[9382, 262, 300, 6, 22, "Print"],
Cell[9685, 270, 300, 6, 22, "Print"],
Cell[9988, 278, 300, 6, 22, "Print"],
Cell[10291, 286, 300, 6, 22, "Print"],
Cell[10594, 294, 300, 6, 22, "Print"],
Cell[10897, 302, 37, 1, 22, "Print"],
Cell[10937, 305, 300, 6, 22, "Print"],
Cell[11240, 313, 300, 6, 22, "Print"],
Cell[11543, 321, 300, 6, 22, "Print"],
Cell[11846, 329, 300, 6, 22, "Print"],
Cell[12149, 337, 300, 6, 22, "Print"],
Cell[12452, 345, 300, 6, 22, "Print"],
Cell[12755, 353, 300, 6, 22, "Print"],
Cell[13058, 361, 300, 6, 22, "Print"],
Cell[13361, 369, 300, 6, 22, "Print"],
Cell[13664, 377, 37, 1, 22, "Print"],
Cell[13704, 380, 300, 6, 22, "Print"],
Cell[14007, 388, 300, 6, 22, "Print"],
Cell[14310, 396, 300, 6, 22, "Print"],
Cell[14613, 404, 300, 6, 22, "Print"],
Cell[14916, 412, 300, 6, 22, "Print"],
Cell[15219, 420, 300, 6, 22, "Print"],
Cell[15522, 428, 300, 6, 22, "Print"],
Cell[15825, 436, 300, 6, 22, "Print"],
Cell[16128, 444, 300, 6, 22, "Print"],
Cell[16431, 452, 302, 6, 22, "Print"],
Cell[16736, 460, 37, 1, 22, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16810, 466, 161, 2, 43, "Input"],
Cell[16974, 470, 243, 5, 22, "Print"],
Cell[17220, 477, 243, 5, 22, "Print"],
Cell[17466, 484, 243, 5, 22, "Print"],
Cell[17712, 491, 243, 5, 22, "Print"],
Cell[17958, 498, 243, 5, 22, "Print"],
Cell[18204, 505, 243, 5, 22, "Print"],
Cell[18450, 512, 243, 5, 22, "Print"],
Cell[18696, 519, 243, 5, 22, "Print"],
Cell[18942, 526, 243, 5, 22, "Print"],
Cell[19188, 533, 243, 5, 22, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[19480, 544, 131, 3, 44, "Subsection"],
Cell[19614, 549, 142, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[19781, 555, 336, 6, 91, "Input"],
Cell[20120, 563, 314, 7, 22, "Print"],
Cell[20437, 572, 314, 7, 22, "Print"],
Cell[20754, 581, 314, 7, 22, "Print"],
Cell[21071, 590, 314, 7, 22, "Print"],
Cell[21388, 599, 314, 7, 22, "Print"],
Cell[21705, 608, 314, 7, 22, "Print"],
Cell[22022, 617, 340, 8, 38, "Print"],
Cell[22365, 627, 314, 7, 22, "Print"],
Cell[22682, 636, 314, 7, 22, "Print"],
Cell[22999, 645, 314, 7, 22, "Print"],
Cell[23316, 654, 316, 7, 22, "Print"],
Cell[23635, 663, 38, 1, 22, "Print"],
Cell[23676, 666, 314, 7, 22, "Print"],
Cell[23993, 675, 314, 7, 22, "Print"],
Cell[24310, 684, 314, 7, 22, "Print"],
Cell[24627, 693, 314, 7, 22, "Print"],
Cell[24944, 702, 314, 7, 22, "Print"],
Cell[25261, 711, 314, 7, 22, "Print"],
Cell[25578, 720, 314, 7, 22, "Print"],
Cell[25895, 729, 340, 8, 38, "Print"],
Cell[26238, 739, 314, 7, 22, "Print"],
Cell[26555, 748, 314, 7, 22, "Print"],
Cell[26872, 757, 316, 7, 22, "Print"],
Cell[27191, 766, 38, 1, 22, "Print"],
Cell[27232, 769, 314, 7, 22, "Print"],
Cell[27549, 778, 314, 7, 22, "Print"],
Cell[27866, 787, 314, 7, 22, "Print"],
Cell[28183, 796, 314, 7, 22, "Print"],
Cell[28500, 805, 314, 7, 22, "Print"],
Cell[28817, 814, 314, 7, 22, "Print"],
Cell[29134, 823, 314, 7, 22, "Print"],
Cell[29451, 832, 314, 7, 22, "Print"],
Cell[29768, 841, 342, 8, 38, "Print"],
Cell[30113, 851, 314, 7, 22, "Print"],
Cell[30430, 860, 316, 7, 22, "Print"],
Cell[30749, 869, 38, 1, 22, "Print"],
Cell[30790, 872, 314, 7, 22, "Print"],
Cell[31107, 881, 314, 7, 22, "Print"],
Cell[31424, 890, 314, 7, 22, "Print"],
Cell[31741, 899, 314, 7, 22, "Print"],
Cell[32058, 908, 314, 7, 22, "Print"],
Cell[32375, 917, 314, 7, 22, "Print"],
Cell[32692, 926, 314, 7, 22, "Print"],
Cell[33009, 935, 314, 7, 22, "Print"],
Cell[33326, 944, 314, 7, 22, "Print"],
Cell[33643, 953, 316, 7, 22, "Print"],
Cell[33962, 962, 316, 7, 22, "Print"],
Cell[34281, 971, 38, 1, 22, "Print"],
Cell[34322, 974, 314, 7, 22, "Print"],
Cell[34639, 983, 314, 7, 22, "Print"],
Cell[34956, 992, 314, 7, 22, "Print"],
Cell[35273, 1001, 314, 7, 22, "Print"],
Cell[35590, 1010, 314, 7, 22, "Print"],
Cell[35907, 1019, 314, 7, 22, "Print"],
Cell[36224, 1028, 314, 7, 22, "Print"],
Cell[36541, 1037, 314, 7, 22, "Print"],
Cell[36858, 1046, 314, 7, 22, "Print"],
Cell[37175, 1055, 314, 7, 22, "Print"],
Cell[37492, 1064, 318, 7, 22, "Print"],
Cell[37813, 1073, 38, 1, 22, "Print"],
Cell[37854, 1076, 70, 1, 26, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[37973, 1083, 69, 0, 28, "Subsection"],
Cell[38045, 1085, 138, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[38208, 1091, 46, 1, 27, "Input"],
Cell[38257, 1094, 40, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38334, 1100, 120, 4, 42, "Input"],
Cell[38457, 1106, 38, 1, 22, "Print"],
Cell[38498, 1109, 298, 6, 22, "Print"],
Cell[38799, 1117, 308, 6, 22, "Print"],
Cell[39110, 1125, 39, 1, 22, "Print"],
Cell[39152, 1128, 298, 6, 22, "Print"],
Cell[39453, 1136, 308, 6, 22, "Print"],
Cell[39764, 1144, 39, 1, 22, "Print"],
Cell[39806, 1147, 298, 6, 22, "Print"],
Cell[40107, 1155, 308, 6, 22, "Print"],
Cell[40418, 1163, 39, 1, 22, "Print"],
Cell[40460, 1166, 298, 6, 22, "Print"],
Cell[40761, 1174, 308, 6, 22, "Print"],
Cell[41072, 1182, 39, 1, 22, "Print"],
Cell[41114, 1185, 298, 6, 22, "Print"],
Cell[41415, 1193, 308, 6, 22, "Print"],
Cell[41726, 1201, 39, 1, 22, "Print"],
Cell[41768, 1204, 298, 6, 22, "Print"],
Cell[42069, 1212, 308, 6, 22, "Print"],
Cell[42380, 1220, 39, 1, 22, "Print"],
Cell[42422, 1223, 324, 7, 38, "Print"],
Cell[42749, 1232, 334, 7, 38, "Print"],
Cell[43086, 1241, 39, 1, 22, "Print"],
Cell[43128, 1244, 298, 6, 22, "Print"],
Cell[43429, 1252, 308, 6, 22, "Print"],
Cell[43740, 1260, 39, 1, 22, "Print"],
Cell[43782, 1263, 298, 6, 22, "Print"],
Cell[44083, 1271, 308, 6, 22, "Print"],
Cell[44394, 1279, 39, 1, 22, "Print"],
Cell[44436, 1282, 298, 6, 22, "Print"],
Cell[44737, 1290, 308, 6, 22, "Print"],
Cell[45048, 1298, 39, 1, 22, "Print"],
Cell[45090, 1301, 300, 6, 22, "Print"],
Cell[45393, 1309, 310, 6, 22, "Print"],
Cell[45706, 1317, 39, 1, 22, "Print"],
Cell[45748, 1320, 38, 1, 22, "Print"],
Cell[45789, 1323, 298, 6, 22, "Print"],
Cell[46090, 1331, 308, 6, 22, "Print"],
Cell[46401, 1339, 39, 1, 22, "Print"],
Cell[46443, 1342, 298, 6, 22, "Print"],
Cell[46744, 1350, 308, 6, 22, "Print"],
Cell[47055, 1358, 39, 1, 22, "Print"],
Cell[47097, 1361, 298, 6, 22, "Print"],
Cell[47398, 1369, 308, 6, 22, "Print"],
Cell[47709, 1377, 39, 1, 22, "Print"],
Cell[47751, 1380, 298, 6, 22, "Print"],
Cell[48052, 1388, 308, 6, 22, "Print"],
Cell[48363, 1396, 39, 1, 22, "Print"],
Cell[48405, 1399, 298, 6, 22, "Print"],
Cell[48706, 1407, 308, 6, 22, "Print"],
Cell[49017, 1415, 39, 1, 22, "Print"],
Cell[49059, 1418, 298, 6, 22, "Print"],
Cell[49360, 1426, 308, 6, 22, "Print"],
Cell[49671, 1434, 39, 1, 22, "Print"],
Cell[49713, 1437, 298, 6, 22, "Print"],
Cell[50014, 1445, 308, 6, 22, "Print"],
Cell[50325, 1453, 39, 1, 22, "Print"],
Cell[50367, 1456, 324, 7, 38, "Print"],
Cell[50694, 1465, 334, 7, 38, "Print"],
Cell[51031, 1474, 39, 1, 22, "Print"],
Cell[51073, 1477, 298, 6, 22, "Print"],
Cell[51374, 1485, 308, 6, 22, "Print"],
Cell[51685, 1493, 39, 1, 22, "Print"],
Cell[51727, 1496, 298, 6, 22, "Print"],
Cell[52028, 1504, 308, 6, 22, "Print"],
Cell[52339, 1512, 39, 1, 22, "Print"],
Cell[52381, 1515, 300, 6, 22, "Print"],
Cell[52684, 1523, 310, 6, 22, "Print"],
Cell[52997, 1531, 39, 1, 22, "Print"],
Cell[53039, 1534, 38, 1, 22, "Print"],
Cell[53080, 1537, 298, 6, 22, "Print"],
Cell[53381, 1545, 308, 6, 22, "Print"],
Cell[53692, 1553, 39, 1, 22, "Print"],
Cell[53734, 1556, 298, 6, 22, "Print"],
Cell[54035, 1564, 308, 6, 22, "Print"],
Cell[54346, 1572, 39, 1, 22, "Print"],
Cell[54388, 1575, 298, 6, 22, "Print"],
Cell[54689, 1583, 308, 6, 22, "Print"],
Cell[55000, 1591, 39, 1, 22, "Print"],
Cell[55042, 1594, 298, 6, 22, "Print"],
Cell[55343, 1602, 308, 6, 22, "Print"],
Cell[55654, 1610, 39, 1, 22, "Print"],
Cell[55696, 1613, 298, 6, 22, "Print"],
Cell[55997, 1621, 308, 6, 22, "Print"],
Cell[56308, 1629, 39, 1, 22, "Print"],
Cell[56350, 1632, 298, 6, 22, "Print"],
Cell[56651, 1640, 308, 6, 22, "Print"],
Cell[56962, 1648, 39, 1, 22, "Print"],
Cell[57004, 1651, 298, 6, 22, "Print"],
Cell[57305, 1659, 308, 6, 22, "Print"],
Cell[57616, 1667, 39, 1, 22, "Print"],
Cell[57658, 1670, 298, 6, 22, "Print"],
Cell[57959, 1678, 308, 6, 22, "Print"],
Cell[58270, 1686, 39, 1, 22, "Print"],
Cell[58312, 1689, 326, 7, 38, "Print"],
Cell[58641, 1698, 336, 7, 38, "Print"],
Cell[58980, 1707, 39, 1, 22, "Print"],
Cell[59022, 1710, 298, 6, 22, "Print"],
Cell[59323, 1718, 308, 6, 22, "Print"],
Cell[59634, 1726, 39, 1, 22, "Print"],
Cell[59676, 1729, 300, 6, 22, "Print"],
Cell[59979, 1737, 310, 6, 22, "Print"],
Cell[60292, 1745, 39, 1, 22, "Print"],
Cell[60334, 1748, 38, 1, 22, "Print"],
Cell[60375, 1751, 298, 6, 22, "Print"],
Cell[60676, 1759, 308, 6, 22, "Print"],
Cell[60987, 1767, 39, 1, 22, "Print"],
Cell[61029, 1770, 298, 6, 22, "Print"],
Cell[61330, 1778, 308, 6, 22, "Print"],
Cell[61641, 1786, 39, 1, 22, "Print"],
Cell[61683, 1789, 298, 6, 22, "Print"],
Cell[61984, 1797, 308, 6, 22, "Print"],
Cell[62295, 1805, 39, 1, 22, "Print"],
Cell[62337, 1808, 298, 6, 22, "Print"],
Cell[62638, 1816, 308, 6, 22, "Print"],
Cell[62949, 1824, 39, 1, 22, "Print"],
Cell[62991, 1827, 298, 6, 22, "Print"],
Cell[63292, 1835, 308, 6, 22, "Print"],
Cell[63603, 1843, 39, 1, 22, "Print"],
Cell[63645, 1846, 298, 6, 22, "Print"],
Cell[63946, 1854, 308, 6, 22, "Print"],
Cell[64257, 1862, 39, 1, 22, "Print"],
Cell[64299, 1865, 298, 6, 22, "Print"],
Cell[64600, 1873, 308, 6, 22, "Print"],
Cell[64911, 1881, 39, 1, 22, "Print"],
Cell[64953, 1884, 298, 6, 22, "Print"],
Cell[65254, 1892, 308, 6, 22, "Print"],
Cell[65565, 1900, 39, 1, 22, "Print"],
Cell[65607, 1903, 298, 6, 22, "Print"],
Cell[65908, 1911, 308, 6, 22, "Print"],
Cell[66219, 1919, 39, 1, 22, "Print"],
Cell[66261, 1922, 300, 6, 22, "Print"],
Cell[66564, 1930, 310, 6, 22, "Print"],
Cell[66877, 1938, 39, 1, 22, "Print"],
Cell[66919, 1941, 300, 6, 22, "Print"],
Cell[67222, 1949, 310, 6, 22, "Print"],
Cell[67535, 1957, 39, 1, 22, "Print"],
Cell[67577, 1960, 38, 1, 22, "Print"],
Cell[67618, 1963, 298, 6, 22, "Print"],
Cell[67919, 1971, 308, 6, 22, "Print"],
Cell[68230, 1979, 39, 1, 22, "Print"],
Cell[68272, 1982, 298, 6, 22, "Print"],
Cell[68573, 1990, 308, 6, 22, "Print"],
Cell[68884, 1998, 39, 1, 22, "Print"],
Cell[68926, 2001, 298, 6, 22, "Print"],
Cell[69227, 2009, 308, 6, 22, "Print"],
Cell[69538, 2017, 39, 1, 22, "Print"],
Cell[69580, 2020, 298, 6, 22, "Print"],
Cell[69881, 2028, 308, 6, 22, "Print"],
Cell[70192, 2036, 39, 1, 22, "Print"],
Cell[70234, 2039, 298, 6, 22, "Print"],
Cell[70535, 2047, 308, 6, 22, "Print"],
Cell[70846, 2055, 39, 1, 22, "Print"],
Cell[70888, 2058, 298, 6, 22, "Print"],
Cell[71189, 2066, 308, 6, 22, "Print"],
Cell[71500, 2074, 39, 1, 22, "Print"],
Cell[71542, 2077, 298, 6, 22, "Print"],
Cell[71843, 2085, 308, 6, 22, "Print"],
Cell[72154, 2093, 39, 1, 22, "Print"],
Cell[72196, 2096, 298, 6, 22, "Print"],
Cell[72497, 2104, 308, 6, 22, "Print"],
Cell[72808, 2112, 39, 1, 22, "Print"],
Cell[72850, 2115, 298, 6, 22, "Print"],
Cell[73151, 2123, 308, 6, 22, "Print"],
Cell[73462, 2131, 39, 1, 22, "Print"],
Cell[73504, 2134, 298, 6, 22, "Print"],
Cell[73805, 2142, 308, 6, 22, "Print"],
Cell[74116, 2150, 39, 1, 22, "Print"],
Cell[74158, 2153, 302, 6, 22, "Print"],
Cell[74463, 2161, 312, 6, 22, "Print"],
Cell[74778, 2169, 39, 1, 22, "Print"],
Cell[74820, 2172, 70, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[74927, 2178, 46, 1, 27, "Input"],
Cell[74976, 2181, 40, 1, 26, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[75077, 2189, 174, 4, 48, "Section"],

Cell[CellGroupData[{
Cell[75276, 2197, 107, 3, 44, "Subsection"],
Cell[75386, 2202, 62, 1, 27, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75485, 2208, 69, 0, 44, "Subsection"],
Cell[75557, 2210, 143, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[75725, 2216, 46, 1, 27, "Input"],
Cell[75774, 2219, 40, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75851, 2225, 128, 4, 42, "Input"],
Cell[75982, 2231, 38, 1, 22, "Print"],
Cell[76023, 2234, 475, 11, 22, "Print"],
Cell[76501, 2247, 485, 11, 22, "Print"],
Cell[76989, 2260, 118, 2, 22, "Message"],
Cell[77110, 2264, 128, 3, 22, "Message"],
Cell[77241, 2269, 498, 11, 22, "Print"],
Cell[77742, 2282, 39, 1, 22, "Print"],
Cell[77784, 2285, 298, 6, 22, "Print"],
Cell[78085, 2293, 308, 6, 22, "Print"],
Cell[78396, 2301, 306, 6, 22, "Print"],
Cell[78705, 2309, 39, 1, 22, "Print"],
Cell[78747, 2312, 298, 6, 22, "Print"],
Cell[79048, 2320, 308, 6, 22, "Print"],
Cell[79359, 2328, 306, 6, 22, "Print"],
Cell[79668, 2336, 39, 1, 22, "Print"],
Cell[79710, 2339, 298, 6, 22, "Print"],
Cell[80011, 2347, 308, 6, 22, "Print"],
Cell[80322, 2355, 306, 6, 22, "Print"],
Cell[80631, 2363, 39, 1, 22, "Print"],
Cell[80673, 2366, 298, 6, 22, "Print"],
Cell[80974, 2374, 308, 6, 22, "Print"],
Cell[81285, 2382, 306, 6, 22, "Print"],
Cell[81594, 2390, 39, 1, 22, "Print"],
Cell[81636, 2393, 298, 6, 22, "Print"],
Cell[81937, 2401, 308, 6, 22, "Print"],
Cell[82248, 2409, 306, 6, 22, "Print"],
Cell[82557, 2417, 39, 1, 22, "Print"],
Cell[82599, 2420, 509, 11, 22, "Print"],
Cell[83111, 2433, 526, 12, 22, "Print"],
Cell[83640, 2447, 498, 11, 22, "Print"],
Cell[84141, 2460, 39, 1, 22, "Print"],
Cell[84183, 2463, 298, 6, 22, "Print"],
Cell[84484, 2471, 308, 6, 22, "Print"],
Cell[84795, 2479, 306, 6, 22, "Print"],
Cell[85104, 2487, 39, 1, 22, "Print"],
Cell[85146, 2490, 298, 6, 22, "Print"],
Cell[85447, 2498, 308, 6, 22, "Print"],
Cell[85758, 2506, 306, 6, 22, "Print"],
Cell[86067, 2514, 39, 1, 22, "Print"],
Cell[86109, 2517, 298, 6, 22, "Print"],
Cell[86410, 2525, 308, 6, 22, "Print"],
Cell[86721, 2533, 306, 6, 22, "Print"],
Cell[87030, 2541, 39, 1, 22, "Print"],
Cell[87072, 2544, 300, 6, 22, "Print"],
Cell[87375, 2552, 310, 6, 22, "Print"],
Cell[87688, 2560, 308, 6, 22, "Print"],
Cell[87999, 2568, 39, 1, 22, "Print"],
Cell[88041, 2571, 300, 6, 22, "Print"],
Cell[88344, 2579, 310, 6, 22, "Print"],
Cell[88657, 2587, 308, 6, 22, "Print"],
Cell[88968, 2595, 39, 1, 22, "Print"],
Cell[89010, 2598, 509, 11, 22, "Print"],
Cell[89522, 2611, 526, 12, 22, "Print"],
Cell[90051, 2625, 529, 12, 22, "Print"],
Cell[90583, 2639, 39, 1, 22, "Print"],
Cell[90625, 2642, 300, 6, 22, "Print"],
Cell[90928, 2650, 310, 6, 22, "Print"],
Cell[91241, 2658, 308, 6, 22, "Print"],
Cell[91552, 2666, 39, 1, 22, "Print"],
Cell[91594, 2669, 300, 6, 22, "Print"],
Cell[91897, 2677, 310, 6, 22, "Print"],
Cell[92210, 2685, 308, 6, 22, "Print"],
Cell[92521, 2693, 39, 1, 22, "Print"],
Cell[92563, 2696, 300, 6, 22, "Print"],
Cell[92866, 2704, 310, 6, 22, "Print"],
Cell[93179, 2712, 308, 6, 22, "Print"],
Cell[93490, 2720, 39, 1, 22, "Print"],
Cell[93532, 2723, 300, 6, 22, "Print"],
Cell[93835, 2731, 310, 6, 22, "Print"],
Cell[94148, 2739, 308, 6, 22, "Print"],
Cell[94459, 2747, 39, 1, 22, "Print"],
Cell[94501, 2750, 300, 6, 22, "Print"],
Cell[94804, 2758, 310, 6, 22, "Print"],
Cell[95117, 2766, 308, 6, 22, "Print"],
Cell[95428, 2774, 39, 1, 22, "Print"],
Cell[95470, 2777, 509, 11, 22, "Print"],
Cell[95982, 2790, 526, 12, 22, "Print"],
Cell[96511, 2804, 528, 12, 22, "Print"],
Cell[97042, 2818, 39, 1, 22, "Print"],
Cell[97084, 2821, 300, 6, 22, "Print"],
Cell[97387, 2829, 310, 6, 22, "Print"],
Cell[97700, 2837, 308, 6, 22, "Print"],
Cell[98011, 2845, 39, 1, 22, "Print"],
Cell[98053, 2848, 300, 6, 22, "Print"],
Cell[98356, 2856, 310, 6, 22, "Print"],
Cell[98669, 2864, 308, 6, 22, "Print"],
Cell[98980, 2872, 39, 1, 22, "Print"],
Cell[99022, 2875, 300, 6, 22, "Print"],
Cell[99325, 2883, 310, 6, 22, "Print"],
Cell[99638, 2891, 308, 6, 22, "Print"],
Cell[99949, 2899, 39, 1, 22, "Print"],
Cell[99991, 2902, 300, 6, 22, "Print"],
Cell[100294, 2910, 310, 6, 22, "Print"],
Cell[100607, 2918, 308, 6, 22, "Print"],
Cell[100918, 2926, 39, 1, 22, "Print"],
Cell[100960, 2929, 300, 6, 22, "Print"],
Cell[101263, 2937, 310, 6, 22, "Print"],
Cell[101576, 2945, 308, 6, 22, "Print"],
Cell[101887, 2953, 39, 1, 22, "Print"],
Cell[101929, 2956, 511, 11, 24, "Print"],
Cell[102443, 2969, 529, 12, 24, "Print"],
Cell[102975, 2983, 528, 12, 22, "Print"],
Cell[103506, 2997, 39, 1, 22, "Print"],
Cell[103548, 3000, 300, 6, 22, "Print"],
Cell[103851, 3008, 310, 6, 22, "Print"],
Cell[104164, 3016, 308, 6, 22, "Print"],
Cell[104475, 3024, 39, 1, 22, "Print"],
Cell[104517, 3027, 300, 6, 22, "Print"],
Cell[104820, 3035, 310, 6, 22, "Print"],
Cell[105133, 3043, 308, 6, 22, "Print"],
Cell[105444, 3051, 39, 1, 22, "Print"],
Cell[105486, 3054, 300, 6, 22, "Print"],
Cell[105789, 3062, 310, 6, 22, "Print"],
Cell[106102, 3070, 308, 6, 22, "Print"],
Cell[106413, 3078, 39, 1, 22, "Print"],
Cell[106455, 3081, 300, 6, 22, "Print"],
Cell[106758, 3089, 310, 6, 22, "Print"],
Cell[107071, 3097, 308, 6, 22, "Print"],
Cell[107382, 3105, 39, 1, 22, "Print"],
Cell[107424, 3108, 300, 6, 22, "Print"],
Cell[107727, 3116, 310, 6, 22, "Print"],
Cell[108040, 3124, 308, 6, 22, "Print"],
Cell[108351, 3132, 39, 1, 22, "Print"],
Cell[108393, 3135, 513, 11, 24, "Print"],
Cell[108909, 3148, 530, 12, 24, "Print"],
Cell[109442, 3162, 529, 12, 22, "Print"],
Cell[109974, 3176, 39, 1, 22, "Print"],
Cell[110016, 3179, 300, 6, 22, "Print"],
Cell[110319, 3187, 310, 6, 22, "Print"],
Cell[110632, 3195, 308, 6, 22, "Print"],
Cell[110943, 3203, 39, 1, 22, "Print"],
Cell[110985, 3206, 300, 6, 22, "Print"],
Cell[111288, 3214, 310, 6, 22, "Print"],
Cell[111601, 3222, 308, 6, 22, "Print"],
Cell[111912, 3230, 39, 1, 22, "Print"],
Cell[111954, 3233, 300, 6, 22, "Print"],
Cell[112257, 3241, 310, 6, 22, "Print"],
Cell[112570, 3249, 308, 6, 22, "Print"],
Cell[112881, 3257, 39, 1, 22, "Print"],
Cell[112923, 3260, 300, 6, 22, "Print"],
Cell[113226, 3268, 310, 6, 22, "Print"],
Cell[113539, 3276, 308, 6, 22, "Print"],
Cell[113850, 3284, 39, 1, 22, "Print"],
Cell[113892, 3287, 300, 6, 22, "Print"],
Cell[114195, 3295, 310, 6, 22, "Print"],
Cell[114508, 3303, 308, 6, 22, "Print"],
Cell[114819, 3311, 39, 1, 22, "Print"],
Cell[114861, 3314, 514, 11, 24, "Print"],
Cell[115378, 3327, 531, 12, 24, "Print"],
Cell[115912, 3341, 528, 12, 22, "Print"],
Cell[116443, 3355, 39, 1, 22, "Print"],
Cell[116485, 3358, 300, 6, 22, "Print"],
Cell[116788, 3366, 310, 6, 22, "Print"],
Cell[117101, 3374, 308, 6, 22, "Print"],
Cell[117412, 3382, 39, 1, 22, "Print"],
Cell[117454, 3385, 300, 6, 22, "Print"],
Cell[117757, 3393, 310, 6, 22, "Print"],
Cell[118070, 3401, 308, 6, 22, "Print"],
Cell[118381, 3409, 39, 1, 22, "Print"],
Cell[118423, 3412, 300, 6, 22, "Print"],
Cell[118726, 3420, 310, 6, 22, "Print"],
Cell[119039, 3428, 308, 6, 22, "Print"],
Cell[119350, 3436, 39, 1, 22, "Print"],
Cell[119392, 3439, 300, 6, 22, "Print"],
Cell[119695, 3447, 310, 6, 22, "Print"],
Cell[120008, 3455, 308, 6, 22, "Print"],
Cell[120319, 3463, 39, 1, 22, "Print"],
Cell[120361, 3466, 300, 6, 22, "Print"],
Cell[120664, 3474, 310, 6, 22, "Print"],
Cell[120977, 3482, 308, 6, 22, "Print"],
Cell[121288, 3490, 39, 1, 22, "Print"],
Cell[121330, 3493, 525, 12, 24, "Print"],
Cell[121858, 3507, 535, 12, 24, "Print"],
Cell[122396, 3521, 528, 12, 22, "Print"],
Cell[122927, 3535, 39, 1, 22, "Print"],
Cell[122969, 3538, 300, 6, 22, "Print"],
Cell[123272, 3546, 310, 6, 22, "Print"],
Cell[123585, 3554, 308, 6, 22, "Print"],
Cell[123896, 3562, 39, 1, 22, "Print"],
Cell[123938, 3565, 300, 6, 22, "Print"],
Cell[124241, 3573, 310, 6, 22, "Print"],
Cell[124554, 3581, 308, 6, 22, "Print"],
Cell[124865, 3589, 39, 1, 22, "Print"],
Cell[124907, 3592, 300, 6, 22, "Print"],
Cell[125210, 3600, 310, 6, 22, "Print"],
Cell[125523, 3608, 308, 6, 22, "Print"],
Cell[125834, 3616, 39, 1, 22, "Print"],
Cell[125876, 3619, 300, 6, 22, "Print"],
Cell[126179, 3627, 310, 6, 22, "Print"],
Cell[126492, 3635, 308, 6, 22, "Print"],
Cell[126803, 3643, 39, 1, 22, "Print"],
Cell[126845, 3646, 300, 6, 22, "Print"],
Cell[127148, 3654, 310, 6, 22, "Print"],
Cell[127461, 3662, 308, 6, 22, "Print"],
Cell[127772, 3670, 39, 1, 22, "Print"],
Cell[127814, 3673, 525, 12, 24, "Print"],
Cell[128342, 3687, 535, 12, 24, "Print"],
Cell[128880, 3701, 529, 12, 22, "Print"],
Cell[129412, 3715, 39, 1, 22, "Print"],
Cell[129454, 3718, 300, 6, 22, "Print"],
Cell[129757, 3726, 310, 6, 22, "Print"],
Cell[130070, 3734, 308, 6, 22, "Print"],
Cell[130381, 3742, 39, 1, 22, "Print"],
Cell[130423, 3745, 300, 6, 22, "Print"],
Cell[130726, 3753, 310, 6, 22, "Print"],
Cell[131039, 3761, 308, 6, 22, "Print"],
Cell[131350, 3769, 39, 1, 22, "Print"],
Cell[131392, 3772, 300, 6, 22, "Print"],
Cell[131695, 3780, 310, 6, 22, "Print"],
Cell[132008, 3788, 308, 6, 22, "Print"],
Cell[132319, 3796, 39, 1, 22, "Print"],
Cell[132361, 3799, 300, 6, 22, "Print"],
Cell[132664, 3807, 310, 6, 22, "Print"],
Cell[132977, 3815, 308, 6, 22, "Print"],
Cell[133288, 3823, 39, 1, 22, "Print"],
Cell[133330, 3826, 300, 6, 22, "Print"],
Cell[133633, 3834, 310, 6, 22, "Print"],
Cell[133946, 3842, 308, 6, 22, "Print"],
Cell[134257, 3850, 39, 1, 22, "Print"],
Cell[134299, 3853, 525, 12, 24, "Print"],
Cell[134827, 3867, 535, 12, 24, "Print"],
Cell[135365, 3881, 528, 12, 22, "Print"],
Cell[135896, 3895, 39, 1, 22, "Print"],
Cell[135938, 3898, 300, 6, 22, "Print"],
Cell[136241, 3906, 310, 6, 22, "Print"],
Cell[136554, 3914, 308, 6, 22, "Print"],
Cell[136865, 3922, 39, 1, 22, "Print"],
Cell[136907, 3925, 300, 6, 22, "Print"],
Cell[137210, 3933, 310, 6, 22, "Print"],
Cell[137523, 3941, 308, 6, 22, "Print"],
Cell[137834, 3949, 39, 1, 22, "Print"],
Cell[137876, 3952, 300, 6, 22, "Print"],
Cell[138179, 3960, 310, 6, 22, "Print"],
Cell[138492, 3968, 308, 6, 22, "Print"],
Cell[138803, 3976, 39, 1, 22, "Print"],
Cell[138845, 3979, 300, 6, 22, "Print"],
Cell[139148, 3987, 310, 6, 22, "Print"],
Cell[139461, 3995, 308, 6, 22, "Print"],
Cell[139772, 4003, 39, 1, 22, "Print"],
Cell[139814, 4006, 300, 6, 22, "Print"],
Cell[140117, 4014, 310, 6, 22, "Print"],
Cell[140430, 4022, 308, 6, 22, "Print"],
Cell[140741, 4030, 39, 1, 22, "Print"],
Cell[140783, 4033, 524, 12, 24, "Print"],
Cell[141310, 4047, 535, 12, 24, "Print"],
Cell[141848, 4061, 529, 12, 22, "Print"],
Cell[142380, 4075, 39, 1, 22, "Print"],
Cell[142422, 4078, 300, 6, 22, "Print"],
Cell[142725, 4086, 310, 6, 22, "Print"],
Cell[143038, 4094, 308, 6, 22, "Print"],
Cell[143349, 4102, 39, 1, 22, "Print"],
Cell[143391, 4105, 300, 6, 22, "Print"],
Cell[143694, 4113, 310, 6, 22, "Print"],
Cell[144007, 4121, 308, 6, 22, "Print"],
Cell[144318, 4129, 39, 1, 22, "Print"],
Cell[144360, 4132, 300, 6, 22, "Print"],
Cell[144663, 4140, 310, 6, 22, "Print"],
Cell[144976, 4148, 308, 6, 22, "Print"],
Cell[145287, 4156, 39, 1, 22, "Print"],
Cell[145329, 4159, 300, 6, 22, "Print"],
Cell[145632, 4167, 310, 6, 22, "Print"],
Cell[145945, 4175, 308, 6, 22, "Print"],
Cell[146256, 4183, 39, 1, 22, "Print"],
Cell[146298, 4186, 300, 6, 22, "Print"],
Cell[146601, 4194, 310, 6, 22, "Print"],
Cell[146914, 4202, 308, 6, 22, "Print"],
Cell[147225, 4210, 39, 1, 22, "Print"],
Cell[147267, 4213, 525, 12, 24, "Print"],
Cell[147795, 4227, 535, 12, 24, "Print"],
Cell[148333, 4241, 529, 12, 22, "Print"],
Cell[148865, 4255, 39, 1, 22, "Print"],
Cell[148907, 4258, 300, 6, 22, "Print"],
Cell[149210, 4266, 310, 6, 22, "Print"],
Cell[149523, 4274, 308, 6, 22, "Print"],
Cell[149834, 4282, 39, 1, 22, "Print"],
Cell[149876, 4285, 300, 6, 22, "Print"],
Cell[150179, 4293, 310, 6, 22, "Print"],
Cell[150492, 4301, 308, 6, 22, "Print"],
Cell[150803, 4309, 39, 1, 22, "Print"],
Cell[150845, 4312, 300, 6, 22, "Print"],
Cell[151148, 4320, 310, 6, 22, "Print"],
Cell[151461, 4328, 308, 6, 22, "Print"],
Cell[151772, 4336, 39, 1, 22, "Print"],
Cell[151814, 4339, 300, 6, 22, "Print"],
Cell[152117, 4347, 310, 6, 22, "Print"],
Cell[152430, 4355, 308, 6, 22, "Print"],
Cell[152741, 4363, 39, 1, 22, "Print"],
Cell[152783, 4366, 300, 6, 22, "Print"],
Cell[153086, 4374, 310, 6, 22, "Print"],
Cell[153399, 4382, 308, 6, 22, "Print"],
Cell[153710, 4390, 39, 1, 22, "Print"],
Cell[153752, 4393, 525, 12, 24, "Print"],
Cell[154280, 4407, 535, 12, 24, "Print"],
Cell[154818, 4421, 529, 12, 22, "Print"],
Cell[155350, 4435, 39, 1, 22, "Print"],
Cell[155392, 4438, 300, 6, 22, "Print"],
Cell[155695, 4446, 310, 6, 22, "Print"],
Cell[156008, 4454, 308, 6, 22, "Print"],
Cell[156319, 4462, 39, 1, 22, "Print"],
Cell[156361, 4465, 300, 6, 22, "Print"],
Cell[156664, 4473, 310, 6, 22, "Print"],
Cell[156977, 4481, 308, 6, 22, "Print"],
Cell[157288, 4489, 39, 1, 22, "Print"],
Cell[157330, 4492, 300, 6, 22, "Print"],
Cell[157633, 4500, 310, 6, 22, "Print"],
Cell[157946, 4508, 308, 6, 22, "Print"],
Cell[158257, 4516, 39, 1, 22, "Print"],
Cell[158299, 4519, 300, 6, 22, "Print"],
Cell[158602, 4527, 310, 6, 22, "Print"],
Cell[158915, 4535, 308, 6, 22, "Print"],
Cell[159226, 4543, 39, 1, 22, "Print"],
Cell[159268, 4546, 300, 6, 22, "Print"],
Cell[159571, 4554, 310, 6, 22, "Print"],
Cell[159884, 4562, 308, 6, 22, "Print"],
Cell[160195, 4570, 39, 1, 22, "Print"],
Cell[160237, 4573, 525, 12, 24, "Print"],
Cell[160765, 4587, 535, 12, 24, "Print"],
Cell[161303, 4601, 529, 12, 22, "Print"],
Cell[161835, 4615, 39, 1, 22, "Print"],
Cell[161877, 4618, 300, 6, 22, "Print"],
Cell[162180, 4626, 310, 6, 22, "Print"],
Cell[162493, 4634, 308, 6, 22, "Print"],
Cell[162804, 4642, 39, 1, 22, "Print"],
Cell[162846, 4645, 300, 6, 22, "Print"],
Cell[163149, 4653, 310, 6, 22, "Print"],
Cell[163462, 4661, 308, 6, 22, "Print"],
Cell[163773, 4669, 39, 1, 22, "Print"],
Cell[163815, 4672, 300, 6, 22, "Print"],
Cell[164118, 4680, 310, 6, 22, "Print"],
Cell[164431, 4688, 308, 6, 22, "Print"],
Cell[164742, 4696, 39, 1, 22, "Print"],
Cell[164784, 4699, 300, 6, 22, "Print"],
Cell[165087, 4707, 310, 6, 22, "Print"],
Cell[165400, 4715, 308, 6, 22, "Print"],
Cell[165711, 4723, 39, 1, 22, "Print"],
Cell[165753, 4726, 300, 6, 22, "Print"],
Cell[166056, 4734, 310, 6, 22, "Print"],
Cell[166369, 4742, 308, 6, 22, "Print"],
Cell[166680, 4750, 39, 1, 22, "Print"],
Cell[166722, 4753, 525, 12, 24, "Print"],
Cell[167250, 4767, 535, 12, 24, "Print"],
Cell[167788, 4781, 529, 12, 22, "Print"],
Cell[168320, 4795, 39, 1, 22, "Print"],
Cell[168362, 4798, 300, 6, 22, "Print"],
Cell[168665, 4806, 310, 6, 22, "Print"],
Cell[168978, 4814, 308, 6, 22, "Print"],
Cell[169289, 4822, 39, 1, 22, "Print"],
Cell[169331, 4825, 300, 6, 22, "Print"],
Cell[169634, 4833, 310, 6, 22, "Print"],
Cell[169947, 4841, 308, 6, 22, "Print"],
Cell[170258, 4849, 39, 1, 22, "Print"],
Cell[170300, 4852, 300, 6, 22, "Print"],
Cell[170603, 4860, 310, 6, 22, "Print"],
Cell[170916, 4868, 308, 6, 22, "Print"],
Cell[171227, 4876, 39, 1, 22, "Print"],
Cell[171269, 4879, 300, 6, 22, "Print"],
Cell[171572, 4887, 310, 6, 22, "Print"],
Cell[171885, 4895, 308, 6, 22, "Print"],
Cell[172196, 4903, 39, 1, 22, "Print"],
Cell[172238, 4906, 300, 6, 22, "Print"],
Cell[172541, 4914, 310, 6, 22, "Print"],
Cell[172854, 4922, 308, 6, 22, "Print"],
Cell[173165, 4930, 39, 1, 22, "Print"],
Cell[173207, 4933, 525, 12, 24, "Print"],
Cell[173735, 4947, 535, 12, 24, "Print"],
Cell[174273, 4961, 529, 12, 22, "Print"],
Cell[174805, 4975, 39, 1, 22, "Print"],
Cell[174847, 4978, 300, 6, 22, "Print"],
Cell[175150, 4986, 310, 6, 22, "Print"],
Cell[175463, 4994, 308, 6, 22, "Print"],
Cell[175774, 5002, 39, 1, 22, "Print"],
Cell[175816, 5005, 300, 6, 22, "Print"],
Cell[176119, 5013, 310, 6, 22, "Print"],
Cell[176432, 5021, 308, 6, 22, "Print"],
Cell[176743, 5029, 39, 1, 22, "Print"],
Cell[176785, 5032, 300, 6, 22, "Print"],
Cell[177088, 5040, 310, 6, 22, "Print"],
Cell[177401, 5048, 308, 6, 22, "Print"],
Cell[177712, 5056, 39, 1, 22, "Print"],
Cell[177754, 5059, 300, 6, 22, "Print"],
Cell[178057, 5067, 310, 6, 22, "Print"],
Cell[178370, 5075, 308, 6, 22, "Print"],
Cell[178681, 5083, 39, 1, 22, "Print"],
Cell[178723, 5086, 300, 6, 22, "Print"],
Cell[179026, 5094, 310, 6, 22, "Print"],
Cell[179339, 5102, 308, 6, 22, "Print"],
Cell[179650, 5110, 39, 1, 22, "Print"],
Cell[179692, 5113, 525, 12, 24, "Print"],
Cell[180220, 5127, 535, 12, 24, "Print"],
Cell[180758, 5141, 529, 12, 22, "Print"],
Cell[181290, 5155, 39, 1, 22, "Print"],
Cell[181332, 5158, 300, 6, 22, "Print"],
Cell[181635, 5166, 310, 6, 22, "Print"],
Cell[181948, 5174, 308, 6, 22, "Print"],
Cell[182259, 5182, 39, 1, 22, "Print"],
Cell[182301, 5185, 300, 6, 22, "Print"],
Cell[182604, 5193, 310, 6, 22, "Print"],
Cell[182917, 5201, 308, 6, 22, "Print"],
Cell[183228, 5209, 39, 1, 22, "Print"],
Cell[183270, 5212, 300, 6, 22, "Print"],
Cell[183573, 5220, 310, 6, 22, "Print"],
Cell[183886, 5228, 308, 6, 22, "Print"],
Cell[184197, 5236, 39, 1, 22, "Print"],
Cell[184239, 5239, 302, 6, 22, "Print"],
Cell[184544, 5247, 312, 6, 22, "Print"],
Cell[184859, 5255, 310, 6, 22, "Print"],
Cell[185172, 5263, 39, 1, 22, "Print"],
Cell[185214, 5266, 302, 6, 22, "Print"],
Cell[185519, 5274, 312, 6, 22, "Print"],
Cell[185834, 5282, 310, 6, 22, "Print"],
Cell[186147, 5290, 39, 1, 22, "Print"],
Cell[186189, 5293, 527, 12, 24, "Print"],
Cell[186719, 5307, 537, 12, 24, "Print"],
Cell[187259, 5321, 531, 12, 22, "Print"],
Cell[187793, 5335, 39, 1, 22, "Print"],
Cell[187835, 5338, 302, 6, 22, "Print"],
Cell[188140, 5346, 312, 6, 22, "Print"],
Cell[188455, 5354, 310, 6, 22, "Print"],
Cell[188768, 5362, 39, 1, 22, "Print"],
Cell[188810, 5365, 302, 6, 22, "Print"],
Cell[189115, 5373, 312, 6, 22, "Print"],
Cell[189430, 5381, 310, 6, 22, "Print"],
Cell[189743, 5389, 39, 1, 22, "Print"],
Cell[189785, 5392, 302, 6, 22, "Print"],
Cell[190090, 5400, 312, 6, 22, "Print"],
Cell[190405, 5408, 310, 6, 22, "Print"],
Cell[190718, 5416, 39, 1, 22, "Print"],
Cell[190760, 5419, 302, 6, 22, "Print"],
Cell[191065, 5427, 312, 6, 22, "Print"],
Cell[191380, 5435, 310, 6, 22, "Print"],
Cell[191693, 5443, 39, 1, 22, "Print"],
Cell[191735, 5446, 302, 6, 22, "Print"],
Cell[192040, 5454, 312, 6, 22, "Print"],
Cell[192355, 5462, 310, 6, 22, "Print"],
Cell[192668, 5470, 39, 1, 22, "Print"],
Cell[192710, 5473, 527, 12, 24, "Print"],
Cell[193240, 5487, 537, 12, 24, "Print"],
Cell[193780, 5501, 531, 12, 22, "Print"],
Cell[194314, 5515, 39, 1, 22, "Print"],
Cell[194356, 5518, 302, 6, 22, "Print"],
Cell[194661, 5526, 312, 6, 22, "Print"],
Cell[194976, 5534, 310, 6, 22, "Print"],
Cell[195289, 5542, 39, 1, 22, "Print"],
Cell[195331, 5545, 302, 6, 22, "Print"],
Cell[195636, 5553, 312, 6, 22, "Print"],
Cell[195951, 5561, 310, 6, 22, "Print"],
Cell[196264, 5569, 39, 1, 22, "Print"],
Cell[196306, 5572, 302, 6, 22, "Print"],
Cell[196611, 5580, 312, 6, 22, "Print"],
Cell[196926, 5588, 310, 6, 22, "Print"],
Cell[197239, 5596, 39, 1, 22, "Print"],
Cell[197281, 5599, 302, 6, 22, "Print"],
Cell[197586, 5607, 312, 6, 22, "Print"],
Cell[197901, 5615, 310, 6, 22, "Print"],
Cell[198214, 5623, 39, 1, 22, "Print"],
Cell[198256, 5626, 302, 6, 22, "Print"],
Cell[198561, 5634, 312, 6, 22, "Print"],
Cell[198876, 5642, 310, 6, 22, "Print"],
Cell[199189, 5650, 39, 1, 22, "Print"],
Cell[199231, 5653, 529, 12, 24, "Print"],
Cell[199763, 5667, 539, 12, 24, "Print"],
Cell[200305, 5681, 531, 12, 22, "Print"],
Cell[200839, 5695, 39, 1, 22, "Print"],
Cell[200881, 5698, 302, 6, 22, "Print"],
Cell[201186, 5706, 312, 6, 22, "Print"],
Cell[201501, 5714, 310, 6, 22, "Print"],
Cell[201814, 5722, 39, 1, 22, "Print"],
Cell[201856, 5725, 302, 6, 22, "Print"],
Cell[202161, 5733, 312, 6, 22, "Print"],
Cell[202476, 5741, 310, 6, 22, "Print"],
Cell[202789, 5749, 39, 1, 22, "Print"],
Cell[202831, 5752, 302, 6, 22, "Print"],
Cell[203136, 5760, 312, 6, 22, "Print"],
Cell[203451, 5768, 310, 6, 22, "Print"],
Cell[203764, 5776, 39, 1, 22, "Print"],
Cell[203806, 5779, 302, 6, 22, "Print"],
Cell[204111, 5787, 312, 6, 22, "Print"],
Cell[204426, 5795, 310, 6, 22, "Print"],
Cell[204739, 5803, 39, 1, 22, "Print"],
Cell[204781, 5806, 302, 6, 22, "Print"],
Cell[205086, 5814, 312, 6, 22, "Print"],
Cell[205401, 5822, 310, 6, 22, "Print"],
Cell[205714, 5830, 39, 1, 22, "Print"],
Cell[205756, 5833, 529, 12, 24, "Print"],
Cell[206288, 5847, 539, 12, 24, "Print"],
Cell[206830, 5861, 531, 12, 22, "Print"],
Cell[207364, 5875, 39, 1, 22, "Print"],
Cell[207406, 5878, 302, 6, 22, "Print"],
Cell[207711, 5886, 312, 6, 22, "Print"],
Cell[208026, 5894, 310, 6, 22, "Print"],
Cell[208339, 5902, 39, 1, 22, "Print"],
Cell[208381, 5905, 302, 6, 22, "Print"],
Cell[208686, 5913, 312, 6, 22, "Print"],
Cell[209001, 5921, 310, 6, 22, "Print"],
Cell[209314, 5929, 39, 1, 22, "Print"],
Cell[209356, 5932, 302, 6, 22, "Print"],
Cell[209661, 5940, 312, 6, 22, "Print"],
Cell[209976, 5948, 310, 6, 22, "Print"],
Cell[210289, 5956, 39, 1, 22, "Print"],
Cell[210331, 5959, 302, 6, 22, "Print"],
Cell[210636, 5967, 312, 6, 22, "Print"],
Cell[210951, 5975, 310, 6, 22, "Print"],
Cell[211264, 5983, 39, 1, 22, "Print"],
Cell[211306, 5986, 302, 6, 22, "Print"],
Cell[211611, 5994, 312, 6, 22, "Print"],
Cell[211926, 6002, 310, 6, 22, "Print"],
Cell[212239, 6010, 39, 1, 22, "Print"],
Cell[212281, 6013, 528, 12, 24, "Print"],
Cell[212812, 6027, 538, 12, 24, "Print"],
Cell[213353, 6041, 531, 12, 22, "Print"],
Cell[213887, 6055, 39, 1, 22, "Print"],
Cell[213929, 6058, 302, 6, 22, "Print"],
Cell[214234, 6066, 312, 6, 22, "Print"],
Cell[214549, 6074, 310, 6, 22, "Print"],
Cell[214862, 6082, 39, 1, 22, "Print"],
Cell[214904, 6085, 302, 6, 22, "Print"],
Cell[215209, 6093, 312, 6, 22, "Print"],
Cell[215524, 6101, 310, 6, 22, "Print"],
Cell[215837, 6109, 39, 1, 22, "Print"],
Cell[215879, 6112, 302, 6, 22, "Print"],
Cell[216184, 6120, 312, 6, 22, "Print"],
Cell[216499, 6128, 310, 6, 22, "Print"],
Cell[216812, 6136, 39, 1, 22, "Print"],
Cell[216854, 6139, 302, 6, 22, "Print"],
Cell[217159, 6147, 312, 6, 22, "Print"],
Cell[217474, 6155, 310, 6, 22, "Print"],
Cell[217787, 6163, 39, 1, 22, "Print"],
Cell[217829, 6166, 302, 6, 22, "Print"],
Cell[218134, 6174, 312, 6, 22, "Print"],
Cell[218449, 6182, 310, 6, 22, "Print"],
Cell[218762, 6190, 39, 1, 22, "Print"],
Cell[218804, 6193, 529, 12, 24, "Print"],
Cell[219336, 6207, 538, 12, 24, "Print"],
Cell[219877, 6221, 531, 12, 22, "Print"],
Cell[220411, 6235, 39, 1, 22, "Print"],
Cell[220453, 6238, 302, 6, 22, "Print"],
Cell[220758, 6246, 312, 6, 22, "Print"],
Cell[221073, 6254, 310, 6, 22, "Print"],
Cell[221386, 6262, 39, 1, 22, "Print"],
Cell[221428, 6265, 302, 6, 22, "Print"],
Cell[221733, 6273, 312, 6, 22, "Print"],
Cell[222048, 6281, 310, 6, 22, "Print"],
Cell[222361, 6289, 39, 1, 22, "Print"],
Cell[222403, 6292, 302, 6, 22, "Print"],
Cell[222708, 6300, 312, 6, 22, "Print"],
Cell[223023, 6308, 310, 6, 22, "Print"],
Cell[223336, 6316, 39, 1, 22, "Print"],
Cell[223378, 6319, 302, 6, 22, "Print"],
Cell[223683, 6327, 312, 6, 22, "Print"],
Cell[223998, 6335, 310, 6, 22, "Print"],
Cell[224311, 6343, 39, 1, 22, "Print"],
Cell[224353, 6346, 302, 6, 22, "Print"],
Cell[224658, 6354, 312, 6, 22, "Print"],
Cell[224973, 6362, 310, 6, 22, "Print"],
Cell[225286, 6370, 39, 1, 22, "Print"],
Cell[225328, 6373, 529, 12, 24, "Print"],
Cell[225860, 6387, 538, 12, 24, "Print"],
Cell[226401, 6401, 531, 12, 22, "Print"],
Cell[226935, 6415, 39, 1, 22, "Print"],
Cell[226977, 6418, 302, 6, 22, "Print"],
Cell[227282, 6426, 312, 6, 22, "Print"],
Cell[227597, 6434, 310, 6, 22, "Print"],
Cell[227910, 6442, 39, 1, 22, "Print"],
Cell[227952, 6445, 302, 6, 22, "Print"],
Cell[228257, 6453, 312, 6, 22, "Print"],
Cell[228572, 6461, 310, 6, 22, "Print"],
Cell[228885, 6469, 39, 1, 22, "Print"],
Cell[228927, 6472, 302, 6, 22, "Print"],
Cell[229232, 6480, 312, 6, 22, "Print"],
Cell[229547, 6488, 310, 6, 22, "Print"],
Cell[229860, 6496, 39, 1, 22, "Print"],
Cell[229902, 6499, 302, 6, 22, "Print"],
Cell[230207, 6507, 312, 6, 22, "Print"],
Cell[230522, 6515, 310, 6, 22, "Print"],
Cell[230835, 6523, 39, 1, 22, "Print"],
Cell[230877, 6526, 302, 6, 22, "Print"],
Cell[231182, 6534, 312, 6, 22, "Print"],
Cell[231497, 6542, 310, 6, 22, "Print"],
Cell[231810, 6550, 39, 1, 22, "Print"],
Cell[231852, 6553, 529, 12, 24, "Print"],
Cell[232384, 6567, 539, 12, 24, "Print"],
Cell[232926, 6581, 530, 12, 22, "Print"],
Cell[233459, 6595, 39, 1, 22, "Print"],
Cell[233501, 6598, 302, 6, 22, "Print"],
Cell[233806, 6606, 312, 6, 22, "Print"],
Cell[234121, 6614, 310, 6, 22, "Print"],
Cell[234434, 6622, 39, 1, 22, "Print"],
Cell[234476, 6625, 302, 6, 22, "Print"],
Cell[234781, 6633, 312, 6, 22, "Print"],
Cell[235096, 6641, 310, 6, 22, "Print"],
Cell[235409, 6649, 39, 1, 22, "Print"],
Cell[235451, 6652, 302, 6, 22, "Print"],
Cell[235756, 6660, 312, 6, 22, "Print"],
Cell[236071, 6668, 310, 6, 22, "Print"],
Cell[236384, 6676, 39, 1, 22, "Print"],
Cell[236426, 6679, 302, 6, 22, "Print"],
Cell[236731, 6687, 312, 6, 22, "Print"],
Cell[237046, 6695, 310, 6, 22, "Print"],
Cell[237359, 6703, 39, 1, 22, "Print"],
Cell[237401, 6706, 302, 6, 22, "Print"],
Cell[237706, 6714, 312, 6, 22, "Print"],
Cell[238021, 6722, 310, 6, 22, "Print"],
Cell[238334, 6730, 39, 1, 22, "Print"],
Cell[238376, 6733, 529, 12, 24, "Print"],
Cell[238908, 6747, 539, 12, 24, "Print"],
Cell[239450, 6761, 531, 12, 22, "Print"],
Cell[239984, 6775, 39, 1, 22, "Print"],
Cell[240026, 6778, 302, 6, 22, "Print"],
Cell[240331, 6786, 312, 6, 22, "Print"],
Cell[240646, 6794, 310, 6, 22, "Print"],
Cell[240959, 6802, 39, 1, 22, "Print"],
Cell[241001, 6805, 302, 6, 22, "Print"],
Cell[241306, 6813, 312, 6, 22, "Print"],
Cell[241621, 6821, 310, 6, 22, "Print"],
Cell[241934, 6829, 39, 1, 22, "Print"],
Cell[241976, 6832, 302, 6, 22, "Print"],
Cell[242281, 6840, 312, 6, 22, "Print"],
Cell[242596, 6848, 310, 6, 22, "Print"],
Cell[242909, 6856, 39, 1, 22, "Print"],
Cell[242951, 6859, 302, 6, 22, "Print"],
Cell[243256, 6867, 312, 6, 22, "Print"],
Cell[243571, 6875, 310, 6, 22, "Print"],
Cell[243884, 6883, 39, 1, 22, "Print"],
Cell[243926, 6886, 302, 6, 22, "Print"],
Cell[244231, 6894, 312, 6, 22, "Print"],
Cell[244546, 6902, 310, 6, 22, "Print"],
Cell[244859, 6910, 39, 1, 22, "Print"],
Cell[244901, 6913, 529, 12, 24, "Print"],
Cell[245433, 6927, 539, 12, 24, "Print"],
Cell[245975, 6941, 531, 12, 22, "Print"],
Cell[246509, 6955, 39, 1, 22, "Print"],
Cell[246551, 6958, 302, 6, 22, "Print"],
Cell[246856, 6966, 312, 6, 22, "Print"],
Cell[247171, 6974, 310, 6, 22, "Print"],
Cell[247484, 6982, 39, 1, 22, "Print"],
Cell[247526, 6985, 302, 6, 22, "Print"],
Cell[247831, 6993, 312, 6, 22, "Print"],
Cell[248146, 7001, 310, 6, 22, "Print"],
Cell[248459, 7009, 39, 1, 22, "Print"],
Cell[248501, 7012, 302, 6, 22, "Print"],
Cell[248806, 7020, 312, 6, 22, "Print"],
Cell[249121, 7028, 310, 6, 22, "Print"],
Cell[249434, 7036, 39, 1, 22, "Print"],
Cell[249476, 7039, 302, 6, 22, "Print"],
Cell[249781, 7047, 312, 6, 22, "Print"],
Cell[250096, 7055, 310, 6, 22, "Print"],
Cell[250409, 7063, 39, 1, 22, "Print"],
Cell[250451, 7066, 302, 6, 22, "Print"],
Cell[250756, 7074, 312, 6, 22, "Print"],
Cell[251071, 7082, 310, 6, 22, "Print"],
Cell[251384, 7090, 39, 1, 22, "Print"],
Cell[251426, 7093, 529, 12, 24, "Print"],
Cell[251958, 7107, 539, 12, 24, "Print"],
Cell[252500, 7121, 531, 12, 22, "Print"],
Cell[253034, 7135, 39, 1, 22, "Print"],
Cell[253076, 7138, 302, 6, 22, "Print"],
Cell[253381, 7146, 312, 6, 22, "Print"],
Cell[253696, 7154, 310, 6, 22, "Print"],
Cell[254009, 7162, 39, 1, 22, "Print"],
Cell[254051, 7165, 302, 6, 22, "Print"],
Cell[254356, 7173, 312, 6, 22, "Print"],
Cell[254671, 7181, 310, 6, 22, "Print"],
Cell[254984, 7189, 39, 1, 22, "Print"],
Cell[255026, 7192, 302, 6, 22, "Print"],
Cell[255331, 7200, 312, 6, 22, "Print"],
Cell[255646, 7208, 310, 6, 22, "Print"],
Cell[255959, 7216, 39, 1, 22, "Print"],
Cell[256001, 7219, 302, 6, 22, "Print"],
Cell[256306, 7227, 312, 6, 22, "Print"],
Cell[256621, 7235, 310, 6, 22, "Print"],
Cell[256934, 7243, 39, 1, 22, "Print"],
Cell[256976, 7246, 302, 6, 22, "Print"],
Cell[257281, 7254, 312, 6, 22, "Print"],
Cell[257596, 7262, 310, 6, 22, "Print"],
Cell[257909, 7270, 39, 1, 22, "Print"],
Cell[257951, 7273, 529, 12, 24, "Print"],
Cell[258483, 7287, 539, 12, 24, "Print"],
Cell[259025, 7301, 531, 12, 22, "Print"],
Cell[259559, 7315, 39, 1, 22, "Print"],
Cell[259601, 7318, 302, 6, 22, "Print"],
Cell[259906, 7326, 312, 6, 22, "Print"],
Cell[260221, 7334, 310, 6, 22, "Print"],
Cell[260534, 7342, 39, 1, 22, "Print"],
Cell[260576, 7345, 302, 6, 22, "Print"],
Cell[260881, 7353, 312, 6, 22, "Print"],
Cell[261196, 7361, 310, 6, 22, "Print"],
Cell[261509, 7369, 39, 1, 22, "Print"],
Cell[261551, 7372, 302, 6, 22, "Print"],
Cell[261856, 7380, 312, 6, 22, "Print"],
Cell[262171, 7388, 310, 6, 22, "Print"],
Cell[262484, 7396, 39, 1, 22, "Print"],
Cell[262526, 7399, 302, 6, 22, "Print"],
Cell[262831, 7407, 312, 6, 22, "Print"],
Cell[263146, 7415, 310, 6, 22, "Print"],
Cell[263459, 7423, 39, 1, 22, "Print"],
Cell[263501, 7426, 302, 6, 22, "Print"],
Cell[263806, 7434, 312, 6, 22, "Print"],
Cell[264121, 7442, 310, 6, 22, "Print"],
Cell[264434, 7450, 39, 1, 22, "Print"],
Cell[264476, 7453, 529, 12, 24, "Print"],
Cell[265008, 7467, 538, 12, 24, "Print"],
Cell[265549, 7481, 530, 12, 22, "Print"],
Cell[266082, 7495, 39, 1, 22, "Print"],
Cell[266124, 7498, 302, 6, 22, "Print"],
Cell[266429, 7506, 312, 6, 22, "Print"],
Cell[266744, 7514, 310, 6, 22, "Print"],
Cell[267057, 7522, 39, 1, 22, "Print"],
Cell[267099, 7525, 302, 6, 22, "Print"],
Cell[267404, 7533, 312, 6, 22, "Print"],
Cell[267719, 7541, 310, 6, 22, "Print"],
Cell[268032, 7549, 39, 1, 22, "Print"],
Cell[268074, 7552, 302, 6, 22, "Print"],
Cell[268379, 7560, 312, 6, 22, "Print"],
Cell[268694, 7568, 310, 6, 22, "Print"],
Cell[269007, 7576, 39, 1, 22, "Print"],
Cell[269049, 7579, 302, 6, 22, "Print"],
Cell[269354, 7587, 312, 6, 22, "Print"],
Cell[269669, 7595, 310, 6, 22, "Print"],
Cell[269982, 7603, 39, 1, 22, "Print"],
Cell[270024, 7606, 302, 6, 22, "Print"],
Cell[270329, 7614, 312, 6, 22, "Print"],
Cell[270644, 7622, 310, 6, 22, "Print"],
Cell[270957, 7630, 39, 1, 22, "Print"],
Cell[270999, 7633, 529, 12, 24, "Print"],
Cell[271531, 7647, 539, 12, 24, "Print"],
Cell[272073, 7661, 531, 12, 22, "Print"],
Cell[272607, 7675, 39, 1, 22, "Print"],
Cell[272649, 7678, 38, 1, 22, "Print"],
Cell[272690, 7681, 298, 6, 22, "Print"],
Cell[272991, 7689, 308, 6, 22, "Print"],
Cell[273302, 7697, 306, 6, 22, "Print"],
Cell[273611, 7705, 39, 1, 22, "Print"],
Cell[273653, 7708, 475, 11, 22, "Print"],
Cell[274131, 7721, 485, 11, 22, "Print"],
Cell[274619, 7734, 118, 2, 22, "Message"],
Cell[274740, 7738, 128, 3, 22, "Message"],
Cell[274871, 7743, 498, 11, 22, "Print"],
Cell[275372, 7756, 39, 1, 22, "Print"],
Cell[275414, 7759, 298, 6, 22, "Print"],
Cell[275715, 7767, 308, 6, 22, "Print"],
Cell[276026, 7775, 306, 6, 22, "Print"],
Cell[276335, 7783, 39, 1, 22, "Print"],
Cell[276377, 7786, 298, 6, 22, "Print"],
Cell[276678, 7794, 308, 6, 22, "Print"],
Cell[276989, 7802, 306, 6, 22, "Print"],
Cell[277298, 7810, 39, 1, 22, "Print"],
Cell[277340, 7813, 298, 6, 22, "Print"],
Cell[277641, 7821, 308, 6, 22, "Print"],
Cell[277952, 7829, 306, 6, 22, "Print"],
Cell[278261, 7837, 39, 1, 22, "Print"],
Cell[278303, 7840, 298, 6, 22, "Print"],
Cell[278604, 7848, 308, 6, 22, "Print"],
Cell[278915, 7856, 306, 6, 22, "Print"],
Cell[279224, 7864, 39, 1, 22, "Print"],
Cell[279266, 7867, 298, 6, 22, "Print"],
Cell[279567, 7875, 308, 6, 22, "Print"],
Cell[279878, 7883, 306, 6, 22, "Print"],
Cell[280187, 7891, 39, 1, 22, "Print"],
Cell[280229, 7894, 507, 11, 22, "Print"],
Cell[280739, 7907, 524, 12, 22, "Print"],
Cell[281266, 7921, 498, 11, 22, "Print"],
Cell[281767, 7934, 39, 1, 22, "Print"],
Cell[281809, 7937, 298, 6, 22, "Print"],
Cell[282110, 7945, 308, 6, 22, "Print"],
Cell[282421, 7953, 306, 6, 22, "Print"],
Cell[282730, 7961, 39, 1, 22, "Print"],
Cell[282772, 7964, 298, 6, 22, "Print"],
Cell[283073, 7972, 308, 6, 22, "Print"],
Cell[283384, 7980, 306, 6, 22, "Print"],
Cell[283693, 7988, 39, 1, 22, "Print"],
Cell[283735, 7991, 300, 6, 22, "Print"],
Cell[284038, 7999, 310, 6, 22, "Print"],
Cell[284351, 8007, 308, 6, 22, "Print"],
Cell[284662, 8015, 39, 1, 22, "Print"],
Cell[284704, 8018, 300, 6, 22, "Print"],
Cell[285007, 8026, 310, 6, 22, "Print"],
Cell[285320, 8034, 308, 6, 22, "Print"],
Cell[285631, 8042, 39, 1, 22, "Print"],
Cell[285673, 8045, 300, 6, 22, "Print"],
Cell[285976, 8053, 310, 6, 22, "Print"],
Cell[286289, 8061, 308, 6, 22, "Print"],
Cell[286600, 8069, 39, 1, 22, "Print"],
Cell[286642, 8072, 509, 11, 22, "Print"],
Cell[287154, 8085, 526, 12, 22, "Print"],
Cell[287683, 8099, 500, 11, 22, "Print"],
Cell[288186, 8112, 39, 1, 22, "Print"],
Cell[288228, 8115, 300, 6, 22, "Print"],
Cell[288531, 8123, 310, 6, 22, "Print"],
Cell[288844, 8131, 308, 6, 22, "Print"],
Cell[289155, 8139, 39, 1, 22, "Print"],
Cell[289197, 8142, 300, 6, 22, "Print"],
Cell[289500, 8150, 310, 6, 22, "Print"],
Cell[289813, 8158, 308, 6, 22, "Print"],
Cell[290124, 8166, 39, 1, 22, "Print"],
Cell[290166, 8169, 300, 6, 22, "Print"],
Cell[290469, 8177, 310, 6, 22, "Print"],
Cell[290782, 8185, 308, 6, 22, "Print"],
Cell[291093, 8193, 39, 1, 22, "Print"],
Cell[291135, 8196, 300, 6, 22, "Print"],
Cell[291438, 8204, 310, 6, 22, "Print"],
Cell[291751, 8212, 308, 6, 22, "Print"],
Cell[292062, 8220, 39, 1, 22, "Print"],
Cell[292104, 8223, 300, 6, 22, "Print"],
Cell[292407, 8231, 310, 6, 22, "Print"],
Cell[292720, 8239, 308, 6, 22, "Print"],
Cell[293031, 8247, 39, 1, 22, "Print"],
Cell[293073, 8250, 509, 11, 22, "Print"],
Cell[293585, 8263, 526, 12, 22, "Print"],
Cell[294114, 8277, 500, 11, 22, "Print"],
Cell[294617, 8290, 39, 1, 22, "Print"],
Cell[294659, 8293, 300, 6, 22, "Print"],
Cell[294962, 8301, 310, 6, 22, "Print"],
Cell[295275, 8309, 308, 6, 22, "Print"],
Cell[295586, 8317, 39, 1, 22, "Print"],
Cell[295628, 8320, 300, 6, 22, "Print"],
Cell[295931, 8328, 310, 6, 22, "Print"],
Cell[296244, 8336, 308, 6, 22, "Print"],
Cell[296555, 8344, 39, 1, 22, "Print"],
Cell[296597, 8347, 300, 6, 22, "Print"],
Cell[296900, 8355, 310, 6, 22, "Print"],
Cell[297213, 8363, 308, 6, 22, "Print"],
Cell[297524, 8371, 39, 1, 22, "Print"],
Cell[297566, 8374, 300, 6, 22, "Print"],
Cell[297869, 8382, 310, 6, 22, "Print"],
Cell[298182, 8390, 308, 6, 22, "Print"],
Cell[298493, 8398, 39, 1, 22, "Print"],
Cell[298535, 8401, 300, 6, 22, "Print"],
Cell[298838, 8409, 310, 6, 22, "Print"],
Cell[299151, 8417, 308, 6, 22, "Print"],
Cell[299462, 8425, 39, 1, 22, "Print"],
Cell[299504, 8428, 512, 11, 24, "Print"],
Cell[300019, 8441, 528, 12, 24, "Print"],
Cell[300550, 8455, 529, 12, 22, "Print"],
Cell[301082, 8469, 39, 1, 22, "Print"],
Cell[301124, 8472, 300, 6, 22, "Print"],
Cell[301427, 8480, 310, 6, 22, "Print"],
Cell[301740, 8488, 308, 6, 22, "Print"],
Cell[302051, 8496, 39, 1, 22, "Print"],
Cell[302093, 8499, 300, 6, 22, "Print"],
Cell[302396, 8507, 310, 6, 22, "Print"],
Cell[302709, 8515, 308, 6, 22, "Print"],
Cell[303020, 8523, 39, 1, 22, "Print"],
Cell[303062, 8526, 300, 6, 22, "Print"],
Cell[303365, 8534, 310, 6, 22, "Print"],
Cell[303678, 8542, 308, 6, 22, "Print"],
Cell[303989, 8550, 39, 1, 22, "Print"],
Cell[304031, 8553, 300, 6, 22, "Print"],
Cell[304334, 8561, 310, 6, 22, "Print"],
Cell[304647, 8569, 308, 6, 22, "Print"],
Cell[304958, 8577, 39, 1, 22, "Print"],
Cell[305000, 8580, 300, 6, 22, "Print"],
Cell[305303, 8588, 310, 6, 22, "Print"],
Cell[305616, 8596, 308, 6, 22, "Print"],
Cell[305927, 8604, 39, 1, 22, "Print"],
Cell[305969, 8607, 513, 11, 24, "Print"],
Cell[306485, 8620, 530, 12, 24, "Print"],
Cell[307018, 8634, 529, 12, 22, "Print"],
Cell[307550, 8648, 39, 1, 22, "Print"],
Cell[307592, 8651, 300, 6, 22, "Print"],
Cell[307895, 8659, 310, 6, 22, "Print"],
Cell[308208, 8667, 308, 6, 22, "Print"],
Cell[308519, 8675, 39, 1, 22, "Print"],
Cell[308561, 8678, 300, 6, 22, "Print"],
Cell[308864, 8686, 310, 6, 22, "Print"],
Cell[309177, 8694, 308, 6, 22, "Print"],
Cell[309488, 8702, 39, 1, 22, "Print"],
Cell[309530, 8705, 300, 6, 22, "Print"],
Cell[309833, 8713, 310, 6, 22, "Print"],
Cell[310146, 8721, 308, 6, 22, "Print"],
Cell[310457, 8729, 39, 1, 22, "Print"],
Cell[310499, 8732, 300, 6, 22, "Print"],
Cell[310802, 8740, 310, 6, 22, "Print"],
Cell[311115, 8748, 308, 6, 22, "Print"],
Cell[311426, 8756, 39, 1, 22, "Print"],
Cell[311468, 8759, 300, 6, 22, "Print"],
Cell[311771, 8767, 310, 6, 22, "Print"],
Cell[312084, 8775, 308, 6, 22, "Print"],
Cell[312395, 8783, 39, 1, 22, "Print"],
Cell[312437, 8786, 525, 12, 24, "Print"],
Cell[312965, 8800, 535, 12, 24, "Print"],
Cell[313503, 8814, 529, 12, 22, "Print"],
Cell[314035, 8828, 39, 1, 22, "Print"],
Cell[314077, 8831, 300, 6, 22, "Print"],
Cell[314380, 8839, 310, 6, 22, "Print"],
Cell[314693, 8847, 308, 6, 22, "Print"],
Cell[315004, 8855, 39, 1, 22, "Print"],
Cell[315046, 8858, 300, 6, 22, "Print"],
Cell[315349, 8866, 310, 6, 22, "Print"],
Cell[315662, 8874, 308, 6, 22, "Print"],
Cell[315973, 8882, 39, 1, 22, "Print"],
Cell[316015, 8885, 300, 6, 22, "Print"],
Cell[316318, 8893, 310, 6, 22, "Print"],
Cell[316631, 8901, 308, 6, 22, "Print"],
Cell[316942, 8909, 39, 1, 22, "Print"],
Cell[316984, 8912, 300, 6, 22, "Print"],
Cell[317287, 8920, 310, 6, 22, "Print"],
Cell[317600, 8928, 308, 6, 22, "Print"],
Cell[317911, 8936, 39, 1, 22, "Print"],
Cell[317953, 8939, 300, 6, 22, "Print"],
Cell[318256, 8947, 310, 6, 22, "Print"],
Cell[318569, 8955, 308, 6, 22, "Print"],
Cell[318880, 8963, 39, 1, 22, "Print"],
Cell[318922, 8966, 525, 12, 24, "Print"],
Cell[319450, 8980, 535, 12, 24, "Print"],
Cell[319988, 8994, 529, 12, 22, "Print"],
Cell[320520, 9008, 39, 1, 22, "Print"],
Cell[320562, 9011, 300, 6, 22, "Print"],
Cell[320865, 9019, 310, 6, 22, "Print"],
Cell[321178, 9027, 308, 6, 22, "Print"],
Cell[321489, 9035, 39, 1, 22, "Print"],
Cell[321531, 9038, 300, 6, 22, "Print"],
Cell[321834, 9046, 310, 6, 22, "Print"],
Cell[322147, 9054, 308, 6, 22, "Print"],
Cell[322458, 9062, 39, 1, 22, "Print"],
Cell[322500, 9065, 300, 6, 22, "Print"],
Cell[322803, 9073, 310, 6, 22, "Print"],
Cell[323116, 9081, 308, 6, 22, "Print"],
Cell[323427, 9089, 39, 1, 22, "Print"],
Cell[323469, 9092, 300, 6, 22, "Print"],
Cell[323772, 9100, 310, 6, 22, "Print"],
Cell[324085, 9108, 308, 6, 22, "Print"],
Cell[324396, 9116, 39, 1, 22, "Print"],
Cell[324438, 9119, 300, 6, 22, "Print"],
Cell[324741, 9127, 310, 6, 22, "Print"],
Cell[325054, 9135, 308, 6, 22, "Print"],
Cell[325365, 9143, 39, 1, 22, "Print"],
Cell[325407, 9146, 525, 12, 24, "Print"],
Cell[325935, 9160, 534, 12, 24, "Print"],
Cell[326472, 9174, 528, 12, 22, "Print"],
Cell[327003, 9188, 39, 1, 22, "Print"],
Cell[327045, 9191, 300, 6, 22, "Print"],
Cell[327348, 9199, 310, 6, 22, "Print"],
Cell[327661, 9207, 308, 6, 22, "Print"],
Cell[327972, 9215, 39, 1, 22, "Print"],
Cell[328014, 9218, 300, 6, 22, "Print"],
Cell[328317, 9226, 310, 6, 22, "Print"],
Cell[328630, 9234, 308, 6, 22, "Print"],
Cell[328941, 9242, 39, 1, 22, "Print"],
Cell[328983, 9245, 300, 6, 22, "Print"],
Cell[329286, 9253, 310, 6, 22, "Print"],
Cell[329599, 9261, 308, 6, 22, "Print"],
Cell[329910, 9269, 39, 1, 22, "Print"],
Cell[329952, 9272, 300, 6, 22, "Print"],
Cell[330255, 9280, 310, 6, 22, "Print"],
Cell[330568, 9288, 308, 6, 22, "Print"],
Cell[330879, 9296, 39, 1, 22, "Print"],
Cell[330921, 9299, 300, 6, 22, "Print"],
Cell[331224, 9307, 310, 6, 22, "Print"],
Cell[331537, 9315, 308, 6, 22, "Print"],
Cell[331848, 9323, 39, 1, 22, "Print"],
Cell[331890, 9326, 524, 12, 24, "Print"],
Cell[332417, 9340, 535, 12, 24, "Print"],
Cell[332955, 9354, 529, 12, 22, "Print"],
Cell[333487, 9368, 39, 1, 22, "Print"],
Cell[333529, 9371, 300, 6, 22, "Print"],
Cell[333832, 9379, 310, 6, 22, "Print"],
Cell[334145, 9387, 308, 6, 22, "Print"],
Cell[334456, 9395, 39, 1, 22, "Print"],
Cell[334498, 9398, 300, 6, 22, "Print"],
Cell[334801, 9406, 310, 6, 22, "Print"],
Cell[335114, 9414, 308, 6, 22, "Print"],
Cell[335425, 9422, 39, 1, 22, "Print"],
Cell[335467, 9425, 300, 6, 22, "Print"],
Cell[335770, 9433, 310, 6, 22, "Print"],
Cell[336083, 9441, 308, 6, 22, "Print"],
Cell[336394, 9449, 39, 1, 22, "Print"],
Cell[336436, 9452, 300, 6, 22, "Print"],
Cell[336739, 9460, 310, 6, 22, "Print"],
Cell[337052, 9468, 308, 6, 22, "Print"],
Cell[337363, 9476, 39, 1, 22, "Print"],
Cell[337405, 9479, 300, 6, 22, "Print"],
Cell[337708, 9487, 310, 6, 22, "Print"],
Cell[338021, 9495, 308, 6, 22, "Print"],
Cell[338332, 9503, 39, 1, 22, "Print"],
Cell[338374, 9506, 525, 12, 24, "Print"],
Cell[338902, 9520, 535, 12, 24, "Print"],
Cell[339440, 9534, 529, 12, 22, "Print"],
Cell[339972, 9548, 39, 1, 22, "Print"],
Cell[340014, 9551, 300, 6, 22, "Print"],
Cell[340317, 9559, 310, 6, 22, "Print"],
Cell[340630, 9567, 308, 6, 22, "Print"],
Cell[340941, 9575, 39, 1, 22, "Print"],
Cell[340983, 9578, 300, 6, 22, "Print"],
Cell[341286, 9586, 310, 6, 22, "Print"],
Cell[341599, 9594, 308, 6, 22, "Print"],
Cell[341910, 9602, 39, 1, 22, "Print"],
Cell[341952, 9605, 300, 6, 22, "Print"],
Cell[342255, 9613, 310, 6, 22, "Print"],
Cell[342568, 9621, 308, 6, 22, "Print"],
Cell[342879, 9629, 39, 1, 22, "Print"],
Cell[342921, 9632, 300, 6, 22, "Print"],
Cell[343224, 9640, 310, 6, 22, "Print"],
Cell[343537, 9648, 308, 6, 22, "Print"],
Cell[343848, 9656, 39, 1, 22, "Print"],
Cell[343890, 9659, 300, 6, 22, "Print"],
Cell[344193, 9667, 310, 6, 22, "Print"],
Cell[344506, 9675, 308, 6, 22, "Print"],
Cell[344817, 9683, 39, 1, 22, "Print"],
Cell[344859, 9686, 525, 12, 24, "Print"],
Cell[345387, 9700, 535, 12, 24, "Print"],
Cell[345925, 9714, 529, 12, 22, "Print"],
Cell[346457, 9728, 39, 1, 22, "Print"],
Cell[346499, 9731, 300, 6, 22, "Print"],
Cell[346802, 9739, 310, 6, 22, "Print"],
Cell[347115, 9747, 308, 6, 22, "Print"],
Cell[347426, 9755, 39, 1, 22, "Print"],
Cell[347468, 9758, 300, 6, 22, "Print"],
Cell[347771, 9766, 310, 6, 22, "Print"],
Cell[348084, 9774, 308, 6, 22, "Print"],
Cell[348395, 9782, 39, 1, 22, "Print"],
Cell[348437, 9785, 300, 6, 22, "Print"],
Cell[348740, 9793, 310, 6, 22, "Print"],
Cell[349053, 9801, 308, 6, 22, "Print"],
Cell[349364, 9809, 39, 1, 22, "Print"],
Cell[349406, 9812, 300, 6, 22, "Print"],
Cell[349709, 9820, 310, 6, 22, "Print"],
Cell[350022, 9828, 308, 6, 22, "Print"],
Cell[350333, 9836, 39, 1, 22, "Print"],
Cell[350375, 9839, 300, 6, 22, "Print"],
Cell[350678, 9847, 310, 6, 22, "Print"],
Cell[350991, 9855, 308, 6, 22, "Print"],
Cell[351302, 9863, 39, 1, 22, "Print"],
Cell[351344, 9866, 525, 12, 24, "Print"],
Cell[351872, 9880, 535, 12, 24, "Print"],
Cell[352410, 9894, 528, 12, 22, "Print"],
Cell[352941, 9908, 39, 1, 22, "Print"],
Cell[352983, 9911, 300, 6, 22, "Print"],
Cell[353286, 9919, 310, 6, 22, "Print"],
Cell[353599, 9927, 308, 6, 22, "Print"],
Cell[353910, 9935, 39, 1, 22, "Print"],
Cell[353952, 9938, 300, 6, 22, "Print"],
Cell[354255, 9946, 310, 6, 22, "Print"],
Cell[354568, 9954, 308, 6, 22, "Print"],
Cell[354879, 9962, 39, 1, 22, "Print"],
Cell[354921, 9965, 300, 6, 22, "Print"],
Cell[355224, 9973, 310, 6, 22, "Print"],
Cell[355537, 9981, 308, 6, 22, "Print"],
Cell[355848, 9989, 39, 1, 22, "Print"],
Cell[355890, 9992, 300, 6, 22, "Print"],
Cell[356193, 10000, 310, 6, 22, "Print"],
Cell[356506, 10008, 308, 6, 22, "Print"],
Cell[356817, 10016, 39, 1, 22, "Print"],
Cell[356859, 10019, 300, 6, 22, "Print"],
Cell[357162, 10027, 310, 6, 22, "Print"],
Cell[357475, 10035, 308, 6, 22, "Print"],
Cell[357786, 10043, 39, 1, 22, "Print"],
Cell[357828, 10046, 525, 12, 24, "Print"],
Cell[358356, 10060, 535, 12, 24, "Print"],
Cell[358894, 10074, 529, 12, 22, "Print"],
Cell[359426, 10088, 39, 1, 22, "Print"],
Cell[359468, 10091, 300, 6, 22, "Print"],
Cell[359771, 10099, 310, 6, 22, "Print"],
Cell[360084, 10107, 308, 6, 22, "Print"],
Cell[360395, 10115, 39, 1, 22, "Print"],
Cell[360437, 10118, 300, 6, 22, "Print"],
Cell[360740, 10126, 310, 6, 22, "Print"],
Cell[361053, 10134, 308, 6, 22, "Print"],
Cell[361364, 10142, 39, 1, 22, "Print"],
Cell[361406, 10145, 300, 6, 22, "Print"],
Cell[361709, 10153, 310, 6, 22, "Print"],
Cell[362022, 10161, 308, 6, 22, "Print"],
Cell[362333, 10169, 39, 1, 22, "Print"],
Cell[362375, 10172, 300, 6, 22, "Print"],
Cell[362678, 10180, 310, 6, 22, "Print"],
Cell[362991, 10188, 308, 6, 22, "Print"],
Cell[363302, 10196, 39, 1, 22, "Print"],
Cell[363344, 10199, 300, 6, 22, "Print"],
Cell[363647, 10207, 310, 6, 22, "Print"],
Cell[363960, 10215, 308, 6, 22, "Print"],
Cell[364271, 10223, 39, 1, 22, "Print"],
Cell[364313, 10226, 525, 12, 24, "Print"],
Cell[364841, 10240, 535, 12, 24, "Print"],
Cell[365379, 10254, 529, 12, 22, "Print"],
Cell[365911, 10268, 39, 1, 22, "Print"],
Cell[365953, 10271, 300, 6, 22, "Print"],
Cell[366256, 10279, 310, 6, 22, "Print"],
Cell[366569, 10287, 308, 6, 22, "Print"],
Cell[366880, 10295, 39, 1, 22, "Print"],
Cell[366922, 10298, 300, 6, 22, "Print"],
Cell[367225, 10306, 310, 6, 22, "Print"],
Cell[367538, 10314, 308, 6, 22, "Print"],
Cell[367849, 10322, 39, 1, 22, "Print"],
Cell[367891, 10325, 300, 6, 22, "Print"],
Cell[368194, 10333, 310, 6, 22, "Print"],
Cell[368507, 10341, 308, 6, 22, "Print"],
Cell[368818, 10349, 39, 1, 22, "Print"],
Cell[368860, 10352, 300, 6, 22, "Print"],
Cell[369163, 10360, 310, 6, 22, "Print"],
Cell[369476, 10368, 308, 6, 22, "Print"],
Cell[369787, 10376, 39, 1, 22, "Print"],
Cell[369829, 10379, 300, 6, 22, "Print"],
Cell[370132, 10387, 310, 6, 22, "Print"],
Cell[370445, 10395, 308, 6, 22, "Print"],
Cell[370756, 10403, 39, 1, 22, "Print"],
Cell[370798, 10406, 525, 12, 24, "Print"],
Cell[371326, 10420, 535, 12, 24, "Print"],
Cell[371864, 10434, 529, 12, 22, "Print"],
Cell[372396, 10448, 39, 1, 22, "Print"],
Cell[372438, 10451, 300, 6, 22, "Print"],
Cell[372741, 10459, 310, 6, 22, "Print"],
Cell[373054, 10467, 308, 6, 22, "Print"],
Cell[373365, 10475, 39, 1, 22, "Print"],
Cell[373407, 10478, 300, 6, 22, "Print"],
Cell[373710, 10486, 310, 6, 22, "Print"],
Cell[374023, 10494, 308, 6, 22, "Print"],
Cell[374334, 10502, 39, 1, 22, "Print"],
Cell[374376, 10505, 300, 6, 22, "Print"],
Cell[374679, 10513, 310, 6, 22, "Print"],
Cell[374992, 10521, 308, 6, 22, "Print"],
Cell[375303, 10529, 39, 1, 22, "Print"],
Cell[375345, 10532, 300, 6, 22, "Print"],
Cell[375648, 10540, 310, 6, 22, "Print"],
Cell[375961, 10548, 308, 6, 22, "Print"],
Cell[376272, 10556, 39, 1, 22, "Print"],
Cell[376314, 10559, 300, 6, 22, "Print"],
Cell[376617, 10567, 310, 6, 22, "Print"],
Cell[376930, 10575, 308, 6, 22, "Print"],
Cell[377241, 10583, 39, 1, 22, "Print"],
Cell[377283, 10586, 525, 12, 24, "Print"],
Cell[377811, 10600, 534, 12, 24, "Print"],
Cell[378348, 10614, 529, 12, 22, "Print"],
Cell[378880, 10628, 39, 1, 22, "Print"],
Cell[378922, 10631, 300, 6, 22, "Print"],
Cell[379225, 10639, 310, 6, 22, "Print"],
Cell[379538, 10647, 308, 6, 22, "Print"],
Cell[379849, 10655, 39, 1, 22, "Print"],
Cell[379891, 10658, 300, 6, 22, "Print"],
Cell[380194, 10666, 310, 6, 22, "Print"],
Cell[380507, 10674, 308, 6, 22, "Print"],
Cell[380818, 10682, 39, 1, 22, "Print"],
Cell[380860, 10685, 302, 6, 22, "Print"],
Cell[381165, 10693, 312, 6, 22, "Print"],
Cell[381480, 10701, 310, 6, 22, "Print"],
Cell[381793, 10709, 39, 1, 22, "Print"],
Cell[381835, 10712, 302, 6, 22, "Print"],
Cell[382140, 10720, 312, 6, 22, "Print"],
Cell[382455, 10728, 310, 6, 22, "Print"],
Cell[382768, 10736, 39, 1, 22, "Print"],
Cell[382810, 10739, 302, 6, 22, "Print"],
Cell[383115, 10747, 312, 6, 22, "Print"],
Cell[383430, 10755, 310, 6, 22, "Print"],
Cell[383743, 10763, 39, 1, 22, "Print"],
Cell[383785, 10766, 527, 12, 24, "Print"],
Cell[384315, 10780, 537, 12, 24, "Print"],
Cell[384855, 10794, 528, 12, 22, "Print"],
Cell[385386, 10808, 39, 1, 22, "Print"],
Cell[385428, 10811, 302, 6, 22, "Print"],
Cell[385733, 10819, 312, 6, 22, "Print"],
Cell[386048, 10827, 310, 6, 22, "Print"],
Cell[386361, 10835, 39, 1, 22, "Print"],
Cell[386403, 10838, 302, 6, 22, "Print"],
Cell[386708, 10846, 312, 6, 22, "Print"],
Cell[387023, 10854, 310, 6, 22, "Print"],
Cell[387336, 10862, 39, 1, 22, "Print"],
Cell[387378, 10865, 302, 6, 22, "Print"],
Cell[387683, 10873, 312, 6, 22, "Print"],
Cell[387998, 10881, 310, 6, 22, "Print"],
Cell[388311, 10889, 39, 1, 22, "Print"],
Cell[388353, 10892, 302, 6, 22, "Print"],
Cell[388658, 10900, 312, 6, 22, "Print"],
Cell[388973, 10908, 310, 6, 22, "Print"],
Cell[389286, 10916, 39, 1, 22, "Print"],
Cell[389328, 10919, 302, 6, 22, "Print"],
Cell[389633, 10927, 312, 6, 22, "Print"],
Cell[389948, 10935, 310, 6, 22, "Print"],
Cell[390261, 10943, 39, 1, 22, "Print"],
Cell[390303, 10946, 527, 12, 24, "Print"],
Cell[390833, 10960, 537, 12, 24, "Print"],
Cell[391373, 10974, 531, 12, 22, "Print"],
Cell[391907, 10988, 39, 1, 22, "Print"],
Cell[391949, 10991, 302, 6, 22, "Print"],
Cell[392254, 10999, 312, 6, 22, "Print"],
Cell[392569, 11007, 310, 6, 22, "Print"],
Cell[392882, 11015, 39, 1, 22, "Print"],
Cell[392924, 11018, 302, 6, 22, "Print"],
Cell[393229, 11026, 312, 6, 22, "Print"],
Cell[393544, 11034, 310, 6, 22, "Print"],
Cell[393857, 11042, 39, 1, 22, "Print"],
Cell[393899, 11045, 302, 6, 22, "Print"],
Cell[394204, 11053, 312, 6, 22, "Print"],
Cell[394519, 11061, 310, 6, 22, "Print"],
Cell[394832, 11069, 39, 1, 22, "Print"],
Cell[394874, 11072, 302, 6, 22, "Print"],
Cell[395179, 11080, 312, 6, 22, "Print"],
Cell[395494, 11088, 310, 6, 22, "Print"],
Cell[395807, 11096, 39, 1, 22, "Print"],
Cell[395849, 11099, 302, 6, 22, "Print"],
Cell[396154, 11107, 312, 6, 22, "Print"],
Cell[396469, 11115, 310, 6, 22, "Print"],
Cell[396782, 11123, 39, 1, 22, "Print"],
Cell[396824, 11126, 529, 12, 24, "Print"],
Cell[397356, 11140, 539, 12, 24, "Print"],
Cell[397898, 11154, 531, 12, 22, "Print"],
Cell[398432, 11168, 39, 1, 22, "Print"],
Cell[398474, 11171, 302, 6, 22, "Print"],
Cell[398779, 11179, 312, 6, 22, "Print"],
Cell[399094, 11187, 310, 6, 22, "Print"],
Cell[399407, 11195, 39, 1, 22, "Print"],
Cell[399449, 11198, 302, 6, 22, "Print"],
Cell[399754, 11206, 312, 6, 22, "Print"],
Cell[400069, 11214, 310, 6, 22, "Print"],
Cell[400382, 11222, 39, 1, 22, "Print"],
Cell[400424, 11225, 302, 6, 22, "Print"],
Cell[400729, 11233, 312, 6, 22, "Print"],
Cell[401044, 11241, 310, 6, 22, "Print"],
Cell[401357, 11249, 39, 1, 22, "Print"],
Cell[401399, 11252, 302, 6, 22, "Print"],
Cell[401704, 11260, 312, 6, 22, "Print"],
Cell[402019, 11268, 310, 6, 22, "Print"],
Cell[402332, 11276, 39, 1, 22, "Print"],
Cell[402374, 11279, 302, 6, 22, "Print"],
Cell[402679, 11287, 312, 6, 22, "Print"],
Cell[402994, 11295, 310, 6, 22, "Print"],
Cell[403307, 11303, 39, 1, 22, "Print"],
Cell[403349, 11306, 529, 12, 24, "Print"],
Cell[403881, 11320, 539, 12, 24, "Print"],
Cell[404423, 11334, 531, 12, 22, "Print"],
Cell[404957, 11348, 39, 1, 22, "Print"],
Cell[404999, 11351, 302, 6, 22, "Print"],
Cell[405304, 11359, 312, 6, 22, "Print"],
Cell[405619, 11367, 310, 6, 22, "Print"],
Cell[405932, 11375, 39, 1, 22, "Print"],
Cell[405974, 11378, 302, 6, 22, "Print"],
Cell[406279, 11386, 312, 6, 22, "Print"],
Cell[406594, 11394, 310, 6, 22, "Print"],
Cell[406907, 11402, 39, 1, 22, "Print"],
Cell[406949, 11405, 302, 6, 22, "Print"],
Cell[407254, 11413, 312, 6, 22, "Print"],
Cell[407569, 11421, 310, 6, 22, "Print"],
Cell[407882, 11429, 39, 1, 22, "Print"],
Cell[407924, 11432, 302, 6, 22, "Print"],
Cell[408229, 11440, 312, 6, 22, "Print"],
Cell[408544, 11448, 310, 6, 22, "Print"],
Cell[408857, 11456, 39, 1, 22, "Print"],
Cell[408899, 11459, 302, 6, 22, "Print"],
Cell[409204, 11467, 312, 6, 22, "Print"],
Cell[409519, 11475, 310, 6, 22, "Print"],
Cell[409832, 11483, 39, 1, 22, "Print"],
Cell[409874, 11486, 529, 12, 24, "Print"],
Cell[410406, 11500, 538, 12, 24, "Print"],
Cell[410947, 11514, 531, 12, 22, "Print"],
Cell[411481, 11528, 39, 1, 22, "Print"],
Cell[411523, 11531, 302, 6, 22, "Print"],
Cell[411828, 11539, 312, 6, 22, "Print"],
Cell[412143, 11547, 310, 6, 22, "Print"],
Cell[412456, 11555, 39, 1, 22, "Print"],
Cell[412498, 11558, 302, 6, 22, "Print"],
Cell[412803, 11566, 312, 6, 22, "Print"],
Cell[413118, 11574, 310, 6, 22, "Print"],
Cell[413431, 11582, 39, 1, 22, "Print"],
Cell[413473, 11585, 302, 6, 22, "Print"],
Cell[413778, 11593, 312, 6, 22, "Print"],
Cell[414093, 11601, 310, 6, 22, "Print"],
Cell[414406, 11609, 39, 1, 22, "Print"],
Cell[414448, 11612, 302, 6, 22, "Print"],
Cell[414753, 11620, 312, 6, 22, "Print"],
Cell[415068, 11628, 310, 6, 22, "Print"],
Cell[415381, 11636, 39, 1, 22, "Print"],
Cell[415423, 11639, 302, 6, 22, "Print"],
Cell[415728, 11647, 312, 6, 22, "Print"],
Cell[416043, 11655, 310, 6, 22, "Print"],
Cell[416356, 11663, 39, 1, 22, "Print"],
Cell[416398, 11666, 528, 12, 24, "Print"],
Cell[416929, 11680, 539, 12, 24, "Print"],
Cell[417471, 11694, 530, 12, 22, "Print"],
Cell[418004, 11708, 39, 1, 22, "Print"],
Cell[418046, 11711, 302, 6, 22, "Print"],
Cell[418351, 11719, 312, 6, 22, "Print"],
Cell[418666, 11727, 310, 6, 22, "Print"],
Cell[418979, 11735, 39, 1, 22, "Print"],
Cell[419021, 11738, 302, 6, 22, "Print"],
Cell[419326, 11746, 312, 6, 22, "Print"],
Cell[419641, 11754, 310, 6, 22, "Print"],
Cell[419954, 11762, 39, 1, 22, "Print"],
Cell[419996, 11765, 302, 6, 22, "Print"],
Cell[420301, 11773, 312, 6, 22, "Print"],
Cell[420616, 11781, 310, 6, 22, "Print"],
Cell[420929, 11789, 39, 1, 22, "Print"],
Cell[420971, 11792, 302, 6, 22, "Print"],
Cell[421276, 11800, 312, 6, 22, "Print"],
Cell[421591, 11808, 310, 6, 22, "Print"],
Cell[421904, 11816, 39, 1, 22, "Print"],
Cell[421946, 11819, 302, 6, 22, "Print"],
Cell[422251, 11827, 312, 6, 22, "Print"],
Cell[422566, 11835, 310, 6, 22, "Print"],
Cell[422879, 11843, 39, 1, 22, "Print"],
Cell[422921, 11846, 529, 12, 24, "Print"],
Cell[423453, 11860, 539, 12, 24, "Print"],
Cell[423995, 11874, 531, 12, 22, "Print"],
Cell[424529, 11888, 39, 1, 22, "Print"],
Cell[424571, 11891, 302, 6, 22, "Print"],
Cell[424876, 11899, 312, 6, 22, "Print"],
Cell[425191, 11907, 310, 6, 22, "Print"],
Cell[425504, 11915, 39, 1, 22, "Print"],
Cell[425546, 11918, 302, 6, 22, "Print"],
Cell[425851, 11926, 312, 6, 22, "Print"],
Cell[426166, 11934, 310, 6, 22, "Print"],
Cell[426479, 11942, 39, 1, 22, "Print"],
Cell[426521, 11945, 302, 6, 22, "Print"],
Cell[426826, 11953, 312, 6, 22, "Print"],
Cell[427141, 11961, 310, 6, 22, "Print"],
Cell[427454, 11969, 39, 1, 22, "Print"],
Cell[427496, 11972, 302, 6, 22, "Print"],
Cell[427801, 11980, 312, 6, 22, "Print"],
Cell[428116, 11988, 310, 6, 22, "Print"],
Cell[428429, 11996, 39, 1, 22, "Print"],
Cell[428471, 11999, 302, 6, 22, "Print"],
Cell[428776, 12007, 312, 6, 22, "Print"],
Cell[429091, 12015, 310, 6, 22, "Print"],
Cell[429404, 12023, 39, 1, 22, "Print"],
Cell[429446, 12026, 529, 12, 24, "Print"],
Cell[429978, 12040, 538, 12, 24, "Print"],
Cell[430519, 12054, 531, 12, 22, "Print"],
Cell[431053, 12068, 39, 1, 22, "Print"],
Cell[431095, 12071, 302, 6, 22, "Print"],
Cell[431400, 12079, 312, 6, 22, "Print"],
Cell[431715, 12087, 310, 6, 22, "Print"],
Cell[432028, 12095, 39, 1, 22, "Print"],
Cell[432070, 12098, 302, 6, 22, "Print"],
Cell[432375, 12106, 312, 6, 22, "Print"],
Cell[432690, 12114, 310, 6, 22, "Print"],
Cell[433003, 12122, 39, 1, 22, "Print"],
Cell[433045, 12125, 302, 6, 22, "Print"],
Cell[433350, 12133, 312, 6, 22, "Print"],
Cell[433665, 12141, 310, 6, 22, "Print"],
Cell[433978, 12149, 39, 1, 22, "Print"],
Cell[434020, 12152, 302, 6, 22, "Print"],
Cell[434325, 12160, 312, 6, 22, "Print"],
Cell[434640, 12168, 310, 6, 22, "Print"],
Cell[434953, 12176, 39, 1, 22, "Print"],
Cell[434995, 12179, 302, 6, 22, "Print"],
Cell[435300, 12187, 312, 6, 22, "Print"],
Cell[435615, 12195, 310, 6, 22, "Print"],
Cell[435928, 12203, 39, 1, 22, "Print"],
Cell[435970, 12206, 529, 12, 24, "Print"],
Cell[436502, 12220, 538, 12, 24, "Print"],
Cell[437043, 12234, 531, 12, 22, "Print"],
Cell[437577, 12248, 39, 1, 22, "Print"],
Cell[437619, 12251, 302, 6, 22, "Print"],
Cell[437924, 12259, 312, 6, 22, "Print"],
Cell[438239, 12267, 310, 6, 22, "Print"],
Cell[438552, 12275, 39, 1, 22, "Print"],
Cell[438594, 12278, 302, 6, 22, "Print"],
Cell[438899, 12286, 312, 6, 22, "Print"],
Cell[439214, 12294, 310, 6, 22, "Print"],
Cell[439527, 12302, 39, 1, 22, "Print"],
Cell[439569, 12305, 302, 6, 22, "Print"],
Cell[439874, 12313, 312, 6, 22, "Print"],
Cell[440189, 12321, 310, 6, 22, "Print"],
Cell[440502, 12329, 39, 1, 22, "Print"],
Cell[440544, 12332, 302, 6, 22, "Print"],
Cell[440849, 12340, 312, 6, 22, "Print"],
Cell[441164, 12348, 310, 6, 22, "Print"],
Cell[441477, 12356, 39, 1, 22, "Print"],
Cell[441519, 12359, 302, 6, 22, "Print"],
Cell[441824, 12367, 312, 6, 22, "Print"],
Cell[442139, 12375, 310, 6, 22, "Print"],
Cell[442452, 12383, 39, 1, 22, "Print"],
Cell[442494, 12386, 529, 12, 24, "Print"],
Cell[443026, 12400, 539, 12, 24, "Print"],
Cell[443568, 12414, 530, 12, 22, "Print"],
Cell[444101, 12428, 39, 1, 22, "Print"],
Cell[444143, 12431, 302, 6, 22, "Print"],
Cell[444448, 12439, 312, 6, 22, "Print"],
Cell[444763, 12447, 310, 6, 22, "Print"],
Cell[445076, 12455, 39, 1, 22, "Print"],
Cell[445118, 12458, 302, 6, 22, "Print"],
Cell[445423, 12466, 312, 6, 22, "Print"],
Cell[445738, 12474, 310, 6, 22, "Print"],
Cell[446051, 12482, 39, 1, 22, "Print"],
Cell[446093, 12485, 302, 6, 22, "Print"],
Cell[446398, 12493, 312, 6, 22, "Print"],
Cell[446713, 12501, 310, 6, 22, "Print"],
Cell[447026, 12509, 39, 1, 22, "Print"],
Cell[447068, 12512, 302, 6, 22, "Print"],
Cell[447373, 12520, 312, 6, 22, "Print"],
Cell[447688, 12528, 310, 6, 22, "Print"],
Cell[448001, 12536, 39, 1, 22, "Print"],
Cell[448043, 12539, 302, 6, 22, "Print"],
Cell[448348, 12547, 312, 6, 22, "Print"],
Cell[448663, 12555, 310, 6, 22, "Print"],
Cell[448976, 12563, 39, 1, 22, "Print"],
Cell[449018, 12566, 529, 12, 24, "Print"],
Cell[449550, 12580, 539, 12, 24, "Print"],
Cell[450092, 12594, 531, 12, 22, "Print"],
Cell[450626, 12608, 39, 1, 22, "Print"],
Cell[450668, 12611, 302, 6, 22, "Print"],
Cell[450973, 12619, 312, 6, 22, "Print"],
Cell[451288, 12627, 310, 6, 22, "Print"],
Cell[451601, 12635, 39, 1, 22, "Print"],
Cell[451643, 12638, 302, 6, 22, "Print"],
Cell[451948, 12646, 312, 6, 22, "Print"],
Cell[452263, 12654, 310, 6, 22, "Print"],
Cell[452576, 12662, 39, 1, 22, "Print"],
Cell[452618, 12665, 302, 6, 22, "Print"],
Cell[452923, 12673, 312, 6, 22, "Print"],
Cell[453238, 12681, 310, 6, 22, "Print"],
Cell[453551, 12689, 39, 1, 22, "Print"],
Cell[453593, 12692, 302, 6, 22, "Print"],
Cell[453898, 12700, 312, 6, 22, "Print"],
Cell[454213, 12708, 310, 6, 22, "Print"],
Cell[454526, 12716, 39, 1, 22, "Print"],
Cell[454568, 12719, 302, 6, 22, "Print"],
Cell[454873, 12727, 312, 6, 22, "Print"],
Cell[455188, 12735, 310, 6, 22, "Print"],
Cell[455501, 12743, 39, 1, 22, "Print"],
Cell[455543, 12746, 529, 12, 24, "Print"],
Cell[456075, 12760, 539, 12, 24, "Print"],
Cell[456617, 12774, 530, 12, 22, "Print"],
Cell[457150, 12788, 39, 1, 22, "Print"],
Cell[457192, 12791, 302, 6, 22, "Print"],
Cell[457497, 12799, 312, 6, 22, "Print"],
Cell[457812, 12807, 310, 6, 22, "Print"],
Cell[458125, 12815, 39, 1, 22, "Print"],
Cell[458167, 12818, 302, 6, 22, "Print"],
Cell[458472, 12826, 312, 6, 22, "Print"],
Cell[458787, 12834, 310, 6, 22, "Print"],
Cell[459100, 12842, 39, 1, 22, "Print"],
Cell[459142, 12845, 302, 6, 22, "Print"],
Cell[459447, 12853, 312, 6, 22, "Print"],
Cell[459762, 12861, 310, 6, 22, "Print"],
Cell[460075, 12869, 39, 1, 22, "Print"],
Cell[460117, 12872, 302, 6, 22, "Print"],
Cell[460422, 12880, 312, 6, 22, "Print"],
Cell[460737, 12888, 310, 6, 22, "Print"],
Cell[461050, 12896, 39, 1, 22, "Print"],
Cell[461092, 12899, 302, 6, 22, "Print"],
Cell[461397, 12907, 312, 6, 22, "Print"],
Cell[461712, 12915, 310, 6, 22, "Print"],
Cell[462025, 12923, 39, 1, 22, "Print"],
Cell[462067, 12926, 529, 12, 24, "Print"],
Cell[462599, 12940, 539, 12, 24, "Print"],
Cell[463141, 12954, 531, 12, 22, "Print"],
Cell[463675, 12968, 39, 1, 22, "Print"],
Cell[463717, 12971, 302, 6, 22, "Print"],
Cell[464022, 12979, 312, 6, 22, "Print"],
Cell[464337, 12987, 310, 6, 22, "Print"],
Cell[464650, 12995, 39, 1, 22, "Print"],
Cell[464692, 12998, 302, 6, 22, "Print"],
Cell[464997, 13006, 312, 6, 22, "Print"],
Cell[465312, 13014, 310, 6, 22, "Print"],
Cell[465625, 13022, 39, 1, 22, "Print"],
Cell[465667, 13025, 302, 6, 22, "Print"],
Cell[465972, 13033, 312, 6, 22, "Print"],
Cell[466287, 13041, 310, 6, 22, "Print"],
Cell[466600, 13049, 39, 1, 22, "Print"],
Cell[466642, 13052, 302, 6, 22, "Print"],
Cell[466947, 13060, 312, 6, 22, "Print"],
Cell[467262, 13068, 310, 6, 22, "Print"],
Cell[467575, 13076, 39, 1, 22, "Print"],
Cell[467617, 13079, 302, 6, 22, "Print"],
Cell[467922, 13087, 312, 6, 22, "Print"],
Cell[468237, 13095, 310, 6, 22, "Print"],
Cell[468550, 13103, 39, 1, 22, "Print"],
Cell[468592, 13106, 38, 1, 22, "Print"],
Cell[468633, 13109, 298, 6, 22, "Print"],
Cell[468934, 13117, 308, 6, 22, "Print"],
Cell[469245, 13125, 306, 6, 22, "Print"],
Cell[469554, 13133, 39, 1, 22, "Print"],
Cell[469596, 13136, 298, 6, 22, "Print"],
Cell[469897, 13144, 308, 6, 22, "Print"],
Cell[470208, 13152, 306, 6, 22, "Print"],
Cell[470517, 13160, 39, 1, 22, "Print"],
Cell[470559, 13163, 475, 11, 22, "Print"],
Cell[471037, 13176, 485, 11, 22, "Print"],
Cell[471525, 13189, 118, 2, 22, "Message"],
Cell[471646, 13193, 169, 3, 37, "Message"],
Cell[471818, 13198, 128, 3, 22, "Message"],
Cell[471949, 13203, 157, 3, 37, "Message"],
Cell[472109, 13208, 498, 11, 22, "Print"],
Cell[472610, 13221, 39, 1, 22, "Print"],
Cell[472652, 13224, 298, 6, 22, "Print"],
Cell[472953, 13232, 308, 6, 22, "Print"],
Cell[473264, 13240, 306, 6, 22, "Print"],
Cell[473573, 13248, 39, 1, 22, "Print"],
Cell[473615, 13251, 298, 6, 22, "Print"],
Cell[473916, 13259, 308, 6, 22, "Print"],
Cell[474227, 13267, 306, 6, 22, "Print"],
Cell[474536, 13275, 39, 1, 22, "Print"],
Cell[474578, 13278, 298, 6, 22, "Print"],
Cell[474879, 13286, 308, 6, 22, "Print"],
Cell[475190, 13294, 306, 6, 22, "Print"],
Cell[475499, 13302, 39, 1, 22, "Print"],
Cell[475541, 13305, 298, 6, 22, "Print"],
Cell[475842, 13313, 308, 6, 22, "Print"],
Cell[476153, 13321, 306, 6, 22, "Print"],
Cell[476462, 13329, 39, 1, 22, "Print"],
Cell[476504, 13332, 298, 6, 22, "Print"],
Cell[476805, 13340, 308, 6, 22, "Print"],
Cell[477116, 13348, 306, 6, 22, "Print"],
Cell[477425, 13356, 39, 1, 22, "Print"],
Cell[477467, 13359, 506, 11, 22, "Print"],
Cell[477976, 13372, 523, 12, 22, "Print"],
Cell[478502, 13386, 498, 11, 22, "Print"],
Cell[479003, 13399, 39, 1, 22, "Print"],
Cell[479045, 13402, 298, 6, 22, "Print"],
Cell[479346, 13410, 308, 6, 22, "Print"],
Cell[479657, 13418, 306, 6, 22, "Print"],
Cell[479966, 13426, 39, 1, 22, "Print"],
Cell[480008, 13429, 300, 6, 22, "Print"],
Cell[480311, 13437, 310, 6, 22, "Print"],
Cell[480624, 13445, 308, 6, 22, "Print"],
Cell[480935, 13453, 39, 1, 22, "Print"],
Cell[480977, 13456, 300, 6, 22, "Print"],
Cell[481280, 13464, 310, 6, 22, "Print"],
Cell[481593, 13472, 308, 6, 22, "Print"],
Cell[481904, 13480, 39, 1, 22, "Print"],
Cell[481946, 13483, 300, 6, 22, "Print"],
Cell[482249, 13491, 310, 6, 22, "Print"],
Cell[482562, 13499, 308, 6, 22, "Print"],
Cell[482873, 13507, 39, 1, 22, "Print"],
Cell[482915, 13510, 300, 6, 22, "Print"],
Cell[483218, 13518, 310, 6, 22, "Print"],
Cell[483531, 13526, 308, 6, 22, "Print"],
Cell[483842, 13534, 39, 1, 22, "Print"],
Cell[483884, 13537, 508, 11, 22, "Print"],
Cell[484395, 13550, 526, 12, 22, "Print"],
Cell[484924, 13564, 528, 12, 22, "Print"],
Cell[485455, 13578, 39, 1, 22, "Print"],
Cell[485497, 13581, 300, 6, 22, "Print"],
Cell[485800, 13589, 310, 6, 22, "Print"],
Cell[486113, 13597, 308, 6, 22, "Print"],
Cell[486424, 13605, 39, 1, 22, "Print"],
Cell[486466, 13608, 300, 6, 22, "Print"],
Cell[486769, 13616, 310, 6, 22, "Print"],
Cell[487082, 13624, 308, 6, 22, "Print"],
Cell[487393, 13632, 39, 1, 22, "Print"],
Cell[487435, 13635, 300, 6, 22, "Print"],
Cell[487738, 13643, 310, 6, 22, "Print"],
Cell[488051, 13651, 308, 6, 22, "Print"],
Cell[488362, 13659, 39, 1, 22, "Print"],
Cell[488404, 13662, 300, 6, 22, "Print"],
Cell[488707, 13670, 310, 6, 22, "Print"],
Cell[489020, 13678, 308, 6, 22, "Print"],
Cell[489331, 13686, 39, 1, 22, "Print"],
Cell[489373, 13689, 300, 6, 22, "Print"],
Cell[489676, 13697, 310, 6, 22, "Print"],
Cell[489989, 13705, 308, 6, 22, "Print"],
Cell[490300, 13713, 39, 1, 22, "Print"],
Cell[490342, 13716, 511, 11, 24, "Print"],
Cell[490856, 13729, 528, 12, 24, "Print"],
Cell[491387, 13743, 529, 12, 22, "Print"],
Cell[491919, 13757, 39, 1, 22, "Print"],
Cell[491961, 13760, 300, 6, 22, "Print"],
Cell[492264, 13768, 310, 6, 22, "Print"],
Cell[492577, 13776, 308, 6, 22, "Print"],
Cell[492888, 13784, 39, 1, 22, "Print"],
Cell[492930, 13787, 300, 6, 22, "Print"],
Cell[493233, 13795, 310, 6, 22, "Print"],
Cell[493546, 13803, 308, 6, 22, "Print"],
Cell[493857, 13811, 39, 1, 22, "Print"],
Cell[493899, 13814, 300, 6, 22, "Print"],
Cell[494202, 13822, 310, 6, 22, "Print"],
Cell[494515, 13830, 308, 6, 22, "Print"],
Cell[494826, 13838, 39, 1, 22, "Print"],
Cell[494868, 13841, 300, 6, 22, "Print"],
Cell[495171, 13849, 310, 6, 22, "Print"],
Cell[495484, 13857, 308, 6, 22, "Print"],
Cell[495795, 13865, 39, 1, 22, "Print"],
Cell[495837, 13868, 300, 6, 22, "Print"],
Cell[496140, 13876, 310, 6, 22, "Print"],
Cell[496453, 13884, 308, 6, 22, "Print"],
Cell[496764, 13892, 39, 1, 22, "Print"],
Cell[496806, 13895, 513, 11, 24, "Print"],
Cell[497322, 13908, 530, 12, 24, "Print"],
Cell[497855, 13922, 500, 11, 22, "Print"],
Cell[498358, 13935, 39, 1, 22, "Print"],
Cell[498400, 13938, 300, 6, 22, "Print"],
Cell[498703, 13946, 310, 6, 22, "Print"],
Cell[499016, 13954, 308, 6, 22, "Print"],
Cell[499327, 13962, 39, 1, 22, "Print"],
Cell[499369, 13965, 300, 6, 22, "Print"],
Cell[499672, 13973, 310, 6, 22, "Print"],
Cell[499985, 13981, 308, 6, 22, "Print"],
Cell[500296, 13989, 39, 1, 22, "Print"],
Cell[500338, 13992, 300, 6, 22, "Print"],
Cell[500641, 14000, 310, 6, 22, "Print"],
Cell[500954, 14008, 308, 6, 22, "Print"],
Cell[501265, 14016, 39, 1, 22, "Print"],
Cell[501307, 14019, 300, 6, 22, "Print"],
Cell[501610, 14027, 310, 6, 22, "Print"],
Cell[501923, 14035, 308, 6, 22, "Print"],
Cell[502234, 14043, 39, 1, 22, "Print"],
Cell[502276, 14046, 300, 6, 22, "Print"],
Cell[502579, 14054, 310, 6, 22, "Print"],
Cell[502892, 14062, 308, 6, 22, "Print"],
Cell[503203, 14070, 39, 1, 22, "Print"],
Cell[503245, 14073, 512, 11, 24, "Print"],
Cell[503760, 14086, 530, 12, 24, "Print"],
Cell[504293, 14100, 529, 12, 22, "Print"],
Cell[504825, 14114, 39, 1, 22, "Print"],
Cell[504867, 14117, 300, 6, 22, "Print"],
Cell[505170, 14125, 310, 6, 22, "Print"],
Cell[505483, 14133, 308, 6, 22, "Print"],
Cell[505794, 14141, 39, 1, 22, "Print"],
Cell[505836, 14144, 300, 6, 22, "Print"],
Cell[506139, 14152, 310, 6, 22, "Print"],
Cell[506452, 14160, 308, 6, 22, "Print"],
Cell[506763, 14168, 39, 1, 22, "Print"],
Cell[506805, 14171, 300, 6, 22, "Print"],
Cell[507108, 14179, 310, 6, 22, "Print"],
Cell[507421, 14187, 308, 6, 22, "Print"],
Cell[507732, 14195, 39, 1, 22, "Print"],
Cell[507774, 14198, 300, 6, 22, "Print"],
Cell[508077, 14206, 310, 6, 22, "Print"],
Cell[508390, 14214, 308, 6, 22, "Print"],
Cell[508701, 14222, 39, 1, 22, "Print"],
Cell[508743, 14225, 300, 6, 22, "Print"],
Cell[509046, 14233, 310, 6, 22, "Print"],
Cell[509359, 14241, 308, 6, 22, "Print"],
Cell[509670, 14249, 39, 1, 22, "Print"],
Cell[509712, 14252, 525, 12, 24, "Print"],
Cell[510240, 14266, 535, 12, 24, "Print"],
Cell[510778, 14280, 529, 12, 22, "Print"],
Cell[511310, 14294, 39, 1, 22, "Print"],
Cell[511352, 14297, 300, 6, 22, "Print"],
Cell[511655, 14305, 310, 6, 22, "Print"],
Cell[511968, 14313, 308, 6, 22, "Print"],
Cell[512279, 14321, 39, 1, 22, "Print"],
Cell[512321, 14324, 300, 6, 22, "Print"],
Cell[512624, 14332, 310, 6, 22, "Print"],
Cell[512937, 14340, 308, 6, 22, "Print"],
Cell[513248, 14348, 39, 1, 22, "Print"],
Cell[513290, 14351, 300, 6, 22, "Print"],
Cell[513593, 14359, 310, 6, 22, "Print"],
Cell[513906, 14367, 308, 6, 22, "Print"],
Cell[514217, 14375, 39, 1, 22, "Print"],
Cell[514259, 14378, 300, 6, 22, "Print"],
Cell[514562, 14386, 310, 6, 22, "Print"],
Cell[514875, 14394, 308, 6, 22, "Print"],
Cell[515186, 14402, 39, 1, 22, "Print"],
Cell[515228, 14405, 300, 6, 22, "Print"],
Cell[515531, 14413, 310, 6, 22, "Print"],
Cell[515844, 14421, 308, 6, 22, "Print"],
Cell[516155, 14429, 39, 1, 22, "Print"],
Cell[516197, 14432, 525, 12, 24, "Print"],
Cell[516725, 14446, 534, 12, 24, "Print"],
Cell[517262, 14460, 529, 12, 22, "Print"],
Cell[517794, 14474, 39, 1, 22, "Print"],
Cell[517836, 14477, 300, 6, 22, "Print"],
Cell[518139, 14485, 310, 6, 22, "Print"],
Cell[518452, 14493, 308, 6, 22, "Print"],
Cell[518763, 14501, 39, 1, 22, "Print"],
Cell[518805, 14504, 300, 6, 22, "Print"],
Cell[519108, 14512, 310, 6, 22, "Print"],
Cell[519421, 14520, 308, 6, 22, "Print"],
Cell[519732, 14528, 39, 1, 22, "Print"],
Cell[519774, 14531, 300, 6, 22, "Print"],
Cell[520077, 14539, 310, 6, 22, "Print"],
Cell[520390, 14547, 308, 6, 22, "Print"],
Cell[520701, 14555, 39, 1, 22, "Print"],
Cell[520743, 14558, 300, 6, 22, "Print"],
Cell[521046, 14566, 310, 6, 22, "Print"],
Cell[521359, 14574, 308, 6, 22, "Print"],
Cell[521670, 14582, 39, 1, 22, "Print"],
Cell[521712, 14585, 300, 6, 22, "Print"],
Cell[522015, 14593, 310, 6, 22, "Print"],
Cell[522328, 14601, 308, 6, 22, "Print"],
Cell[522639, 14609, 39, 1, 22, "Print"],
Cell[522681, 14612, 525, 12, 24, "Print"],
Cell[523209, 14626, 535, 12, 24, "Print"],
Cell[523747, 14640, 529, 12, 22, "Print"],
Cell[524279, 14654, 39, 1, 22, "Print"],
Cell[524321, 14657, 300, 6, 22, "Print"],
Cell[524624, 14665, 310, 6, 22, "Print"],
Cell[524937, 14673, 308, 6, 22, "Print"],
Cell[525248, 14681, 39, 1, 22, "Print"],
Cell[525290, 14684, 300, 6, 22, "Print"],
Cell[525593, 14692, 310, 6, 22, "Print"],
Cell[525906, 14700, 308, 6, 22, "Print"],
Cell[526217, 14708, 39, 1, 22, "Print"],
Cell[526259, 14711, 300, 6, 22, "Print"],
Cell[526562, 14719, 310, 6, 22, "Print"],
Cell[526875, 14727, 308, 6, 22, "Print"],
Cell[527186, 14735, 39, 1, 22, "Print"],
Cell[527228, 14738, 300, 6, 22, "Print"],
Cell[527531, 14746, 310, 6, 22, "Print"],
Cell[527844, 14754, 308, 6, 22, "Print"],
Cell[528155, 14762, 39, 1, 22, "Print"],
Cell[528197, 14765, 300, 6, 22, "Print"],
Cell[528500, 14773, 310, 6, 22, "Print"],
Cell[528813, 14781, 308, 6, 22, "Print"],
Cell[529124, 14789, 39, 1, 22, "Print"],
Cell[529166, 14792, 525, 12, 24, "Print"],
Cell[529694, 14806, 534, 12, 24, "Print"],
Cell[530231, 14820, 529, 12, 22, "Print"],
Cell[530763, 14834, 39, 1, 22, "Print"],
Cell[530805, 14837, 300, 6, 22, "Print"],
Cell[531108, 14845, 310, 6, 22, "Print"],
Cell[531421, 14853, 308, 6, 22, "Print"],
Cell[531732, 14861, 39, 1, 22, "Print"],
Cell[531774, 14864, 300, 6, 22, "Print"],
Cell[532077, 14872, 310, 6, 22, "Print"],
Cell[532390, 14880, 308, 6, 22, "Print"],
Cell[532701, 14888, 39, 1, 22, "Print"],
Cell[532743, 14891, 300, 6, 22, "Print"],
Cell[533046, 14899, 310, 6, 22, "Print"],
Cell[533359, 14907, 308, 6, 22, "Print"],
Cell[533670, 14915, 39, 1, 22, "Print"],
Cell[533712, 14918, 300, 6, 22, "Print"],
Cell[534015, 14926, 310, 6, 22, "Print"],
Cell[534328, 14934, 308, 6, 22, "Print"],
Cell[534639, 14942, 39, 1, 22, "Print"],
Cell[534681, 14945, 300, 6, 22, "Print"],
Cell[534984, 14953, 310, 6, 22, "Print"],
Cell[535297, 14961, 308, 6, 22, "Print"],
Cell[535608, 14969, 39, 1, 22, "Print"],
Cell[535650, 14972, 525, 12, 24, "Print"],
Cell[536178, 14986, 534, 12, 24, "Print"],
Cell[536715, 15000, 529, 12, 22, "Print"],
Cell[537247, 15014, 39, 1, 22, "Print"],
Cell[537289, 15017, 300, 6, 22, "Print"],
Cell[537592, 15025, 310, 6, 22, "Print"],
Cell[537905, 15033, 308, 6, 22, "Print"],
Cell[538216, 15041, 39, 1, 22, "Print"],
Cell[538258, 15044, 300, 6, 22, "Print"],
Cell[538561, 15052, 310, 6, 22, "Print"],
Cell[538874, 15060, 308, 6, 22, "Print"],
Cell[539185, 15068, 39, 1, 22, "Print"],
Cell[539227, 15071, 300, 6, 22, "Print"],
Cell[539530, 15079, 310, 6, 22, "Print"],
Cell[539843, 15087, 308, 6, 22, "Print"],
Cell[540154, 15095, 39, 1, 22, "Print"],
Cell[540196, 15098, 300, 6, 22, "Print"],
Cell[540499, 15106, 310, 6, 22, "Print"],
Cell[540812, 15114, 308, 6, 22, "Print"],
Cell[541123, 15122, 39, 1, 22, "Print"],
Cell[541165, 15125, 300, 6, 22, "Print"],
Cell[541468, 15133, 310, 6, 22, "Print"],
Cell[541781, 15141, 308, 6, 22, "Print"],
Cell[542092, 15149, 39, 1, 22, "Print"],
Cell[542134, 15152, 523, 12, 24, "Print"],
Cell[542660, 15166, 535, 12, 24, "Print"],
Cell[543198, 15180, 529, 12, 22, "Print"],
Cell[543730, 15194, 39, 1, 22, "Print"],
Cell[543772, 15197, 300, 6, 22, "Print"],
Cell[544075, 15205, 310, 6, 22, "Print"],
Cell[544388, 15213, 308, 6, 22, "Print"],
Cell[544699, 15221, 39, 1, 22, "Print"],
Cell[544741, 15224, 300, 6, 22, "Print"],
Cell[545044, 15232, 310, 6, 22, "Print"],
Cell[545357, 15240, 308, 6, 22, "Print"],
Cell[545668, 15248, 39, 1, 22, "Print"],
Cell[545710, 15251, 300, 6, 22, "Print"],
Cell[546013, 15259, 310, 6, 22, "Print"],
Cell[546326, 15267, 308, 6, 22, "Print"],
Cell[546637, 15275, 39, 1, 22, "Print"],
Cell[546679, 15278, 300, 6, 22, "Print"],
Cell[546982, 15286, 310, 6, 22, "Print"],
Cell[547295, 15294, 308, 6, 22, "Print"],
Cell[547606, 15302, 39, 1, 22, "Print"],
Cell[547648, 15305, 300, 6, 22, "Print"],
Cell[547951, 15313, 310, 6, 22, "Print"],
Cell[548264, 15321, 308, 6, 22, "Print"],
Cell[548575, 15329, 39, 1, 22, "Print"],
Cell[548617, 15332, 525, 12, 24, "Print"],
Cell[549145, 15346, 535, 12, 24, "Print"],
Cell[549683, 15360, 528, 12, 22, "Print"],
Cell[550214, 15374, 39, 1, 22, "Print"],
Cell[550256, 15377, 300, 6, 22, "Print"],
Cell[550559, 15385, 310, 6, 22, "Print"],
Cell[550872, 15393, 308, 6, 22, "Print"],
Cell[551183, 15401, 39, 1, 22, "Print"],
Cell[551225, 15404, 300, 6, 22, "Print"],
Cell[551528, 15412, 310, 6, 22, "Print"],
Cell[551841, 15420, 308, 6, 22, "Print"],
Cell[552152, 15428, 39, 1, 22, "Print"],
Cell[552194, 15431, 300, 6, 22, "Print"],
Cell[552497, 15439, 310, 6, 22, "Print"],
Cell[552810, 15447, 308, 6, 22, "Print"],
Cell[553121, 15455, 39, 1, 22, "Print"],
Cell[553163, 15458, 300, 6, 22, "Print"],
Cell[553466, 15466, 310, 6, 22, "Print"],
Cell[553779, 15474, 308, 6, 22, "Print"],
Cell[554090, 15482, 39, 1, 22, "Print"],
Cell[554132, 15485, 300, 6, 22, "Print"],
Cell[554435, 15493, 310, 6, 22, "Print"],
Cell[554748, 15501, 308, 6, 22, "Print"],
Cell[555059, 15509, 39, 1, 22, "Print"],
Cell[555101, 15512, 524, 12, 24, "Print"],
Cell[555628, 15526, 535, 12, 24, "Print"],
Cell[556166, 15540, 528, 12, 22, "Print"],
Cell[556697, 15554, 39, 1, 22, "Print"],
Cell[556739, 15557, 300, 6, 22, "Print"],
Cell[557042, 15565, 310, 6, 22, "Print"],
Cell[557355, 15573, 308, 6, 22, "Print"],
Cell[557666, 15581, 39, 1, 22, "Print"],
Cell[557708, 15584, 300, 6, 22, "Print"],
Cell[558011, 15592, 310, 6, 22, "Print"],
Cell[558324, 15600, 308, 6, 22, "Print"],
Cell[558635, 15608, 39, 1, 22, "Print"],
Cell[558677, 15611, 300, 6, 22, "Print"],
Cell[558980, 15619, 310, 6, 22, "Print"],
Cell[559293, 15627, 308, 6, 22, "Print"],
Cell[559604, 15635, 39, 1, 22, "Print"],
Cell[559646, 15638, 300, 6, 22, "Print"],
Cell[559949, 15646, 310, 6, 22, "Print"],
Cell[560262, 15654, 308, 6, 22, "Print"],
Cell[560573, 15662, 39, 1, 22, "Print"],
Cell[560615, 15665, 300, 6, 22, "Print"],
Cell[560918, 15673, 310, 6, 22, "Print"],
Cell[561231, 15681, 308, 6, 22, "Print"],
Cell[561542, 15689, 39, 1, 22, "Print"],
Cell[561584, 15692, 525, 12, 24, "Print"],
Cell[562112, 15706, 535, 12, 24, "Print"],
Cell[562650, 15720, 528, 12, 22, "Print"],
Cell[563181, 15734, 39, 1, 22, "Print"],
Cell[563223, 15737, 300, 6, 22, "Print"],
Cell[563526, 15745, 310, 6, 22, "Print"],
Cell[563839, 15753, 308, 6, 22, "Print"],
Cell[564150, 15761, 39, 1, 22, "Print"],
Cell[564192, 15764, 300, 6, 22, "Print"],
Cell[564495, 15772, 310, 6, 22, "Print"],
Cell[564808, 15780, 308, 6, 22, "Print"],
Cell[565119, 15788, 39, 1, 22, "Print"],
Cell[565161, 15791, 300, 6, 22, "Print"],
Cell[565464, 15799, 310, 6, 22, "Print"],
Cell[565777, 15807, 308, 6, 22, "Print"],
Cell[566088, 15815, 39, 1, 22, "Print"],
Cell[566130, 15818, 300, 6, 22, "Print"],
Cell[566433, 15826, 310, 6, 22, "Print"],
Cell[566746, 15834, 308, 6, 22, "Print"],
Cell[567057, 15842, 39, 1, 22, "Print"],
Cell[567099, 15845, 300, 6, 22, "Print"],
Cell[567402, 15853, 310, 6, 22, "Print"],
Cell[567715, 15861, 308, 6, 22, "Print"],
Cell[568026, 15869, 39, 1, 22, "Print"],
Cell[568068, 15872, 525, 12, 24, "Print"],
Cell[568596, 15886, 535, 12, 24, "Print"],
Cell[569134, 15900, 529, 12, 22, "Print"],
Cell[569666, 15914, 39, 1, 22, "Print"],
Cell[569708, 15917, 300, 6, 22, "Print"],
Cell[570011, 15925, 310, 6, 22, "Print"],
Cell[570324, 15933, 308, 6, 22, "Print"],
Cell[570635, 15941, 39, 1, 22, "Print"],
Cell[570677, 15944, 300, 6, 22, "Print"],
Cell[570980, 15952, 310, 6, 22, "Print"],
Cell[571293, 15960, 308, 6, 22, "Print"],
Cell[571604, 15968, 39, 1, 22, "Print"],
Cell[571646, 15971, 300, 6, 22, "Print"],
Cell[571949, 15979, 310, 6, 22, "Print"],
Cell[572262, 15987, 308, 6, 22, "Print"],
Cell[572573, 15995, 39, 1, 22, "Print"],
Cell[572615, 15998, 300, 6, 22, "Print"],
Cell[572918, 16006, 310, 6, 22, "Print"],
Cell[573231, 16014, 308, 6, 22, "Print"],
Cell[573542, 16022, 39, 1, 22, "Print"],
Cell[573584, 16025, 300, 6, 22, "Print"],
Cell[573887, 16033, 310, 6, 22, "Print"],
Cell[574200, 16041, 308, 6, 22, "Print"],
Cell[574511, 16049, 39, 1, 22, "Print"],
Cell[574553, 16052, 524, 12, 24, "Print"],
Cell[575080, 16066, 535, 12, 24, "Print"],
Cell[575618, 16080, 529, 12, 22, "Print"],
Cell[576150, 16094, 39, 1, 22, "Print"],
Cell[576192, 16097, 300, 6, 22, "Print"],
Cell[576495, 16105, 310, 6, 22, "Print"],
Cell[576808, 16113, 308, 6, 22, "Print"],
Cell[577119, 16121, 39, 1, 22, "Print"],
Cell[577161, 16124, 302, 6, 22, "Print"],
Cell[577466, 16132, 312, 6, 22, "Print"],
Cell[577781, 16140, 310, 6, 22, "Print"],
Cell[578094, 16148, 39, 1, 22, "Print"],
Cell[578136, 16151, 302, 6, 22, "Print"],
Cell[578441, 16159, 312, 6, 22, "Print"],
Cell[578756, 16167, 310, 6, 22, "Print"],
Cell[579069, 16175, 39, 1, 22, "Print"],
Cell[579111, 16178, 302, 6, 22, "Print"],
Cell[579416, 16186, 312, 6, 22, "Print"],
Cell[579731, 16194, 310, 6, 22, "Print"],
Cell[580044, 16202, 39, 1, 22, "Print"],
Cell[580086, 16205, 302, 6, 22, "Print"],
Cell[580391, 16213, 312, 6, 22, "Print"],
Cell[580706, 16221, 310, 6, 22, "Print"],
Cell[581019, 16229, 39, 1, 22, "Print"],
Cell[581061, 16232, 526, 12, 24, "Print"],
Cell[581590, 16246, 537, 12, 24, "Print"],
Cell[582130, 16260, 531, 12, 22, "Print"],
Cell[582664, 16274, 39, 1, 22, "Print"],
Cell[582706, 16277, 302, 6, 22, "Print"],
Cell[583011, 16285, 312, 6, 22, "Print"],
Cell[583326, 16293, 310, 6, 22, "Print"],
Cell[583639, 16301, 39, 1, 22, "Print"],
Cell[583681, 16304, 302, 6, 22, "Print"],
Cell[583986, 16312, 312, 6, 22, "Print"],
Cell[584301, 16320, 310, 6, 22, "Print"],
Cell[584614, 16328, 39, 1, 22, "Print"],
Cell[584656, 16331, 302, 6, 22, "Print"],
Cell[584961, 16339, 312, 6, 22, "Print"],
Cell[585276, 16347, 310, 6, 22, "Print"],
Cell[585589, 16355, 39, 1, 22, "Print"],
Cell[585631, 16358, 302, 6, 22, "Print"],
Cell[585936, 16366, 312, 6, 22, "Print"],
Cell[586251, 16374, 310, 6, 22, "Print"],
Cell[586564, 16382, 39, 1, 22, "Print"],
Cell[586606, 16385, 302, 6, 22, "Print"],
Cell[586911, 16393, 312, 6, 22, "Print"],
Cell[587226, 16401, 310, 6, 22, "Print"],
Cell[587539, 16409, 39, 1, 22, "Print"],
Cell[587581, 16412, 527, 12, 24, "Print"],
Cell[588111, 16426, 537, 12, 24, "Print"],
Cell[588651, 16440, 531, 12, 22, "Print"],
Cell[589185, 16454, 39, 1, 22, "Print"],
Cell[589227, 16457, 302, 6, 22, "Print"],
Cell[589532, 16465, 312, 6, 22, "Print"],
Cell[589847, 16473, 310, 6, 22, "Print"],
Cell[590160, 16481, 39, 1, 22, "Print"],
Cell[590202, 16484, 302, 6, 22, "Print"],
Cell[590507, 16492, 312, 6, 22, "Print"],
Cell[590822, 16500, 310, 6, 22, "Print"],
Cell[591135, 16508, 39, 1, 22, "Print"],
Cell[591177, 16511, 302, 6, 22, "Print"],
Cell[591482, 16519, 312, 6, 22, "Print"],
Cell[591797, 16527, 310, 6, 22, "Print"],
Cell[592110, 16535, 39, 1, 22, "Print"],
Cell[592152, 16538, 302, 6, 22, "Print"],
Cell[592457, 16546, 312, 6, 22, "Print"],
Cell[592772, 16554, 310, 6, 22, "Print"],
Cell[593085, 16562, 39, 1, 22, "Print"],
Cell[593127, 16565, 302, 6, 22, "Print"],
Cell[593432, 16573, 312, 6, 22, "Print"],
Cell[593747, 16581, 310, 6, 22, "Print"],
Cell[594060, 16589, 39, 1, 22, "Print"],
Cell[594102, 16592, 529, 12, 24, "Print"],
Cell[594634, 16606, 539, 12, 24, "Print"],
Cell[595176, 16620, 531, 12, 22, "Print"],
Cell[595710, 16634, 39, 1, 22, "Print"],
Cell[595752, 16637, 302, 6, 22, "Print"],
Cell[596057, 16645, 312, 6, 22, "Print"],
Cell[596372, 16653, 310, 6, 22, "Print"],
Cell[596685, 16661, 39, 1, 22, "Print"],
Cell[596727, 16664, 302, 6, 22, "Print"],
Cell[597032, 16672, 312, 6, 22, "Print"],
Cell[597347, 16680, 310, 6, 22, "Print"],
Cell[597660, 16688, 39, 1, 22, "Print"],
Cell[597702, 16691, 302, 6, 22, "Print"],
Cell[598007, 16699, 312, 6, 22, "Print"],
Cell[598322, 16707, 310, 6, 22, "Print"],
Cell[598635, 16715, 39, 1, 22, "Print"],
Cell[598677, 16718, 302, 6, 22, "Print"],
Cell[598982, 16726, 312, 6, 22, "Print"],
Cell[599297, 16734, 310, 6, 22, "Print"],
Cell[599610, 16742, 39, 1, 22, "Print"],
Cell[599652, 16745, 302, 6, 22, "Print"],
Cell[599957, 16753, 312, 6, 22, "Print"],
Cell[600272, 16761, 310, 6, 22, "Print"],
Cell[600585, 16769, 39, 1, 22, "Print"],
Cell[600627, 16772, 529, 12, 24, "Print"],
Cell[601159, 16786, 539, 12, 24, "Print"],
Cell[601701, 16800, 531, 12, 22, "Print"],
Cell[602235, 16814, 39, 1, 22, "Print"],
Cell[602277, 16817, 302, 6, 22, "Print"],
Cell[602582, 16825, 312, 6, 22, "Print"],
Cell[602897, 16833, 310, 6, 22, "Print"],
Cell[603210, 16841, 39, 1, 22, "Print"],
Cell[603252, 16844, 302, 6, 22, "Print"],
Cell[603557, 16852, 312, 6, 22, "Print"],
Cell[603872, 16860, 310, 6, 22, "Print"],
Cell[604185, 16868, 39, 1, 22, "Print"],
Cell[604227, 16871, 302, 6, 22, "Print"],
Cell[604532, 16879, 312, 6, 22, "Print"],
Cell[604847, 16887, 310, 6, 22, "Print"],
Cell[605160, 16895, 39, 1, 22, "Print"],
Cell[605202, 16898, 302, 6, 22, "Print"],
Cell[605507, 16906, 312, 6, 22, "Print"],
Cell[605822, 16914, 310, 6, 22, "Print"],
Cell[606135, 16922, 39, 1, 22, "Print"],
Cell[606177, 16925, 302, 6, 22, "Print"],
Cell[606482, 16933, 312, 6, 22, "Print"],
Cell[606797, 16941, 310, 6, 22, "Print"],
Cell[607110, 16949, 39, 1, 22, "Print"],
Cell[607152, 16952, 528, 12, 24, "Print"],
Cell[607683, 16966, 539, 12, 24, "Print"],
Cell[608225, 16980, 530, 12, 22, "Print"],
Cell[608758, 16994, 39, 1, 22, "Print"],
Cell[608800, 16997, 302, 6, 22, "Print"],
Cell[609105, 17005, 312, 6, 22, "Print"],
Cell[609420, 17013, 310, 6, 22, "Print"],
Cell[609733, 17021, 39, 1, 22, "Print"],
Cell[609775, 17024, 302, 6, 22, "Print"],
Cell[610080, 17032, 312, 6, 22, "Print"],
Cell[610395, 17040, 310, 6, 22, "Print"],
Cell[610708, 17048, 39, 1, 22, "Print"],
Cell[610750, 17051, 302, 6, 22, "Print"],
Cell[611055, 17059, 312, 6, 22, "Print"],
Cell[611370, 17067, 310, 6, 22, "Print"],
Cell[611683, 17075, 39, 1, 22, "Print"],
Cell[611725, 17078, 302, 6, 22, "Print"],
Cell[612030, 17086, 312, 6, 22, "Print"],
Cell[612345, 17094, 310, 6, 22, "Print"],
Cell[612658, 17102, 39, 1, 22, "Print"],
Cell[612700, 17105, 302, 6, 22, "Print"],
Cell[613005, 17113, 312, 6, 22, "Print"],
Cell[613320, 17121, 310, 6, 22, "Print"],
Cell[613633, 17129, 39, 1, 22, "Print"],
Cell[613675, 17132, 529, 12, 24, "Print"],
Cell[614207, 17146, 537, 12, 24, "Print"],
Cell[614747, 17160, 531, 12, 22, "Print"],
Cell[615281, 17174, 39, 1, 22, "Print"],
Cell[615323, 17177, 302, 6, 22, "Print"],
Cell[615628, 17185, 312, 6, 22, "Print"],
Cell[615943, 17193, 310, 6, 22, "Print"],
Cell[616256, 17201, 39, 1, 22, "Print"],
Cell[616298, 17204, 302, 6, 22, "Print"],
Cell[616603, 17212, 312, 6, 22, "Print"],
Cell[616918, 17220, 310, 6, 22, "Print"],
Cell[617231, 17228, 39, 1, 22, "Print"],
Cell[617273, 17231, 302, 6, 22, "Print"],
Cell[617578, 17239, 312, 6, 22, "Print"],
Cell[617893, 17247, 310, 6, 22, "Print"],
Cell[618206, 17255, 39, 1, 22, "Print"],
Cell[618248, 17258, 302, 6, 22, "Print"],
Cell[618553, 17266, 312, 6, 22, "Print"],
Cell[618868, 17274, 310, 6, 22, "Print"],
Cell[619181, 17282, 39, 1, 22, "Print"],
Cell[619223, 17285, 302, 6, 22, "Print"],
Cell[619528, 17293, 312, 6, 22, "Print"],
Cell[619843, 17301, 310, 6, 22, "Print"],
Cell[620156, 17309, 39, 1, 22, "Print"],
Cell[620198, 17312, 529, 12, 24, "Print"],
Cell[620730, 17326, 539, 12, 24, "Print"],
Cell[621272, 17340, 531, 12, 22, "Print"],
Cell[621806, 17354, 39, 1, 22, "Print"],
Cell[621848, 17357, 302, 6, 22, "Print"],
Cell[622153, 17365, 312, 6, 22, "Print"],
Cell[622468, 17373, 310, 6, 22, "Print"],
Cell[622781, 17381, 39, 1, 22, "Print"],
Cell[622823, 17384, 302, 6, 22, "Print"],
Cell[623128, 17392, 312, 6, 22, "Print"],
Cell[623443, 17400, 310, 6, 22, "Print"],
Cell[623756, 17408, 39, 1, 22, "Print"],
Cell[623798, 17411, 302, 6, 22, "Print"],
Cell[624103, 17419, 312, 6, 22, "Print"],
Cell[624418, 17427, 310, 6, 22, "Print"],
Cell[624731, 17435, 39, 1, 22, "Print"],
Cell[624773, 17438, 302, 6, 22, "Print"],
Cell[625078, 17446, 312, 6, 22, "Print"],
Cell[625393, 17454, 310, 6, 22, "Print"],
Cell[625706, 17462, 39, 1, 22, "Print"],
Cell[625748, 17465, 302, 6, 22, "Print"],
Cell[626053, 17473, 312, 6, 22, "Print"],
Cell[626368, 17481, 310, 6, 22, "Print"],
Cell[626681, 17489, 39, 1, 22, "Print"],
Cell[626723, 17492, 529, 12, 24, "Print"],
Cell[627255, 17506, 539, 12, 24, "Print"],
Cell[627797, 17520, 530, 12, 22, "Print"],
Cell[628330, 17534, 39, 1, 22, "Print"],
Cell[628372, 17537, 302, 6, 22, "Print"],
Cell[628677, 17545, 312, 6, 22, "Print"],
Cell[628992, 17553, 310, 6, 22, "Print"],
Cell[629305, 17561, 39, 1, 22, "Print"],
Cell[629347, 17564, 302, 6, 22, "Print"],
Cell[629652, 17572, 312, 6, 22, "Print"],
Cell[629967, 17580, 310, 6, 22, "Print"],
Cell[630280, 17588, 39, 1, 22, "Print"],
Cell[630322, 17591, 302, 6, 22, "Print"],
Cell[630627, 17599, 312, 6, 22, "Print"],
Cell[630942, 17607, 310, 6, 22, "Print"],
Cell[631255, 17615, 39, 1, 22, "Print"],
Cell[631297, 17618, 302, 6, 22, "Print"],
Cell[631602, 17626, 312, 6, 22, "Print"],
Cell[631917, 17634, 310, 6, 22, "Print"],
Cell[632230, 17642, 39, 1, 22, "Print"],
Cell[632272, 17645, 302, 6, 22, "Print"],
Cell[632577, 17653, 312, 6, 22, "Print"],
Cell[632892, 17661, 310, 6, 22, "Print"],
Cell[633205, 17669, 39, 1, 22, "Print"],
Cell[633247, 17672, 529, 12, 24, "Print"],
Cell[633779, 17686, 539, 12, 24, "Print"],
Cell[634321, 17700, 531, 12, 22, "Print"],
Cell[634855, 17714, 39, 1, 22, "Print"],
Cell[634897, 17717, 302, 6, 22, "Print"],
Cell[635202, 17725, 312, 6, 22, "Print"],
Cell[635517, 17733, 310, 6, 22, "Print"],
Cell[635830, 17741, 39, 1, 22, "Print"],
Cell[635872, 17744, 302, 6, 22, "Print"],
Cell[636177, 17752, 312, 6, 22, "Print"],
Cell[636492, 17760, 310, 6, 22, "Print"],
Cell[636805, 17768, 39, 1, 22, "Print"],
Cell[636847, 17771, 302, 6, 22, "Print"],
Cell[637152, 17779, 312, 6, 22, "Print"],
Cell[637467, 17787, 310, 6, 22, "Print"],
Cell[637780, 17795, 39, 1, 22, "Print"],
Cell[637822, 17798, 302, 6, 22, "Print"],
Cell[638127, 17806, 312, 6, 22, "Print"],
Cell[638442, 17814, 310, 6, 22, "Print"],
Cell[638755, 17822, 39, 1, 22, "Print"],
Cell[638797, 17825, 302, 6, 22, "Print"],
Cell[639102, 17833, 312, 6, 22, "Print"],
Cell[639417, 17841, 310, 6, 22, "Print"],
Cell[639730, 17849, 39, 1, 22, "Print"],
Cell[639772, 17852, 529, 12, 24, "Print"],
Cell[640304, 17866, 538, 12, 24, "Print"],
Cell[640845, 17880, 531, 12, 22, "Print"],
Cell[641379, 17894, 39, 1, 22, "Print"],
Cell[641421, 17897, 302, 6, 22, "Print"],
Cell[641726, 17905, 312, 6, 22, "Print"],
Cell[642041, 17913, 310, 6, 22, "Print"],
Cell[642354, 17921, 39, 1, 22, "Print"],
Cell[642396, 17924, 302, 6, 22, "Print"],
Cell[642701, 17932, 312, 6, 22, "Print"],
Cell[643016, 17940, 310, 6, 22, "Print"],
Cell[643329, 17948, 39, 1, 22, "Print"],
Cell[643371, 17951, 302, 6, 22, "Print"],
Cell[643676, 17959, 312, 6, 22, "Print"],
Cell[643991, 17967, 310, 6, 22, "Print"],
Cell[644304, 17975, 39, 1, 22, "Print"],
Cell[644346, 17978, 302, 6, 22, "Print"],
Cell[644651, 17986, 312, 6, 22, "Print"],
Cell[644966, 17994, 310, 6, 22, "Print"],
Cell[645279, 18002, 39, 1, 22, "Print"],
Cell[645321, 18005, 302, 6, 22, "Print"],
Cell[645626, 18013, 312, 6, 22, "Print"],
Cell[645941, 18021, 310, 6, 22, "Print"],
Cell[646254, 18029, 39, 1, 22, "Print"],
Cell[646296, 18032, 529, 12, 24, "Print"],
Cell[646828, 18046, 539, 12, 24, "Print"],
Cell[647370, 18060, 531, 12, 22, "Print"],
Cell[647904, 18074, 39, 1, 22, "Print"],
Cell[647946, 18077, 302, 6, 22, "Print"],
Cell[648251, 18085, 312, 6, 22, "Print"],
Cell[648566, 18093, 310, 6, 22, "Print"],
Cell[648879, 18101, 39, 1, 22, "Print"],
Cell[648921, 18104, 302, 6, 22, "Print"],
Cell[649226, 18112, 312, 6, 22, "Print"],
Cell[649541, 18120, 310, 6, 22, "Print"],
Cell[649854, 18128, 39, 1, 22, "Print"],
Cell[649896, 18131, 302, 6, 22, "Print"],
Cell[650201, 18139, 312, 6, 22, "Print"],
Cell[650516, 18147, 310, 6, 22, "Print"],
Cell[650829, 18155, 39, 1, 22, "Print"],
Cell[650871, 18158, 302, 6, 22, "Print"],
Cell[651176, 18166, 312, 6, 22, "Print"],
Cell[651491, 18174, 310, 6, 22, "Print"],
Cell[651804, 18182, 39, 1, 22, "Print"],
Cell[651846, 18185, 302, 6, 22, "Print"],
Cell[652151, 18193, 312, 6, 22, "Print"],
Cell[652466, 18201, 310, 6, 22, "Print"],
Cell[652779, 18209, 39, 1, 22, "Print"],
Cell[652821, 18212, 529, 12, 24, "Print"],
Cell[653353, 18226, 538, 12, 24, "Print"],
Cell[653894, 18240, 531, 12, 22, "Print"],
Cell[654428, 18254, 39, 1, 22, "Print"],
Cell[654470, 18257, 302, 6, 22, "Print"],
Cell[654775, 18265, 312, 6, 22, "Print"],
Cell[655090, 18273, 310, 6, 22, "Print"],
Cell[655403, 18281, 39, 1, 22, "Print"],
Cell[655445, 18284, 302, 6, 22, "Print"],
Cell[655750, 18292, 312, 6, 22, "Print"],
Cell[656065, 18300, 310, 6, 22, "Print"],
Cell[656378, 18308, 39, 1, 22, "Print"],
Cell[656420, 18311, 302, 6, 22, "Print"],
Cell[656725, 18319, 312, 6, 22, "Print"],
Cell[657040, 18327, 310, 6, 22, "Print"],
Cell[657353, 18335, 39, 1, 22, "Print"],
Cell[657395, 18338, 302, 6, 22, "Print"],
Cell[657700, 18346, 312, 6, 22, "Print"],
Cell[658015, 18354, 310, 6, 22, "Print"],
Cell[658328, 18362, 39, 1, 22, "Print"],
Cell[658370, 18365, 302, 6, 22, "Print"],
Cell[658675, 18373, 312, 6, 22, "Print"],
Cell[658990, 18381, 310, 6, 22, "Print"],
Cell[659303, 18389, 39, 1, 22, "Print"],
Cell[659345, 18392, 529, 12, 24, "Print"],
Cell[659877, 18406, 538, 12, 24, "Print"],
Cell[660418, 18420, 531, 12, 22, "Print"],
Cell[660952, 18434, 39, 1, 22, "Print"],
Cell[660994, 18437, 302, 6, 22, "Print"],
Cell[661299, 18445, 312, 6, 22, "Print"],
Cell[661614, 18453, 310, 6, 22, "Print"],
Cell[661927, 18461, 39, 1, 22, "Print"],
Cell[661969, 18464, 302, 6, 22, "Print"],
Cell[662274, 18472, 312, 6, 22, "Print"],
Cell[662589, 18480, 310, 6, 22, "Print"],
Cell[662902, 18488, 39, 1, 22, "Print"],
Cell[662944, 18491, 302, 6, 22, "Print"],
Cell[663249, 18499, 312, 6, 22, "Print"],
Cell[663564, 18507, 310, 6, 22, "Print"],
Cell[663877, 18515, 39, 1, 22, "Print"],
Cell[663919, 18518, 302, 6, 22, "Print"],
Cell[664224, 18526, 312, 6, 22, "Print"],
Cell[664539, 18534, 310, 6, 22, "Print"],
Cell[664852, 18542, 39, 1, 22, "Print"],
Cell[664894, 18545, 38, 1, 22, "Print"],
Cell[664935, 18548, 298, 6, 22, "Print"],
Cell[665236, 18556, 308, 6, 22, "Print"],
Cell[665547, 18564, 306, 6, 22, "Print"],
Cell[665856, 18572, 39, 1, 22, "Print"],
Cell[665898, 18575, 298, 6, 22, "Print"],
Cell[666199, 18583, 308, 6, 22, "Print"],
Cell[666510, 18591, 306, 6, 22, "Print"],
Cell[666819, 18599, 39, 1, 22, "Print"],
Cell[666861, 18602, 298, 6, 22, "Print"],
Cell[667162, 18610, 308, 6, 22, "Print"],
Cell[667473, 18618, 306, 6, 22, "Print"],
Cell[667782, 18626, 39, 1, 22, "Print"],
Cell[667824, 18629, 475, 11, 22, "Print"],
Cell[668302, 18642, 485, 11, 22, "Print"],
Cell[668790, 18655, 498, 11, 22, "Print"],
Cell[669291, 18668, 39, 1, 22, "Print"],
Cell[669333, 18671, 298, 6, 22, "Print"],
Cell[669634, 18679, 308, 6, 22, "Print"],
Cell[669945, 18687, 306, 6, 22, "Print"],
Cell[670254, 18695, 39, 1, 22, "Print"],
Cell[670296, 18698, 298, 6, 22, "Print"],
Cell[670597, 18706, 308, 6, 22, "Print"],
Cell[670908, 18714, 306, 6, 22, "Print"],
Cell[671217, 18722, 39, 1, 22, "Print"],
Cell[671259, 18725, 298, 6, 22, "Print"],
Cell[671560, 18733, 308, 6, 22, "Print"],
Cell[671871, 18741, 306, 6, 22, "Print"],
Cell[672180, 18749, 39, 1, 22, "Print"],
Cell[672222, 18752, 298, 6, 22, "Print"],
Cell[672523, 18760, 308, 6, 22, "Print"],
Cell[672834, 18768, 306, 6, 22, "Print"],
Cell[673143, 18776, 39, 1, 22, "Print"],
Cell[673185, 18779, 298, 6, 22, "Print"],
Cell[673486, 18787, 308, 6, 22, "Print"],
Cell[673797, 18795, 306, 6, 22, "Print"],
Cell[674106, 18803, 39, 1, 22, "Print"],
Cell[674148, 18806, 493, 11, 22, "Print"],
Cell[674644, 18819, 503, 11, 22, "Print"],
Cell[675150, 18832, 498, 11, 22, "Print"],
Cell[675651, 18845, 39, 1, 22, "Print"],
Cell[675693, 18848, 300, 6, 22, "Print"],
Cell[675996, 18856, 310, 6, 22, "Print"],
Cell[676309, 18864, 308, 6, 22, "Print"],
Cell[676620, 18872, 39, 1, 22, "Print"],
Cell[676662, 18875, 300, 6, 22, "Print"],
Cell[676965, 18883, 310, 6, 22, "Print"],
Cell[677278, 18891, 308, 6, 22, "Print"],
Cell[677589, 18899, 39, 1, 22, "Print"],
Cell[677631, 18902, 300, 6, 22, "Print"],
Cell[677934, 18910, 310, 6, 22, "Print"],
Cell[678247, 18918, 308, 6, 22, "Print"],
Cell[678558, 18926, 39, 1, 22, "Print"],
Cell[678600, 18929, 300, 6, 22, "Print"],
Cell[678903, 18937, 310, 6, 22, "Print"],
Cell[679216, 18945, 308, 6, 22, "Print"],
Cell[679527, 18953, 39, 1, 22, "Print"],
Cell[679569, 18956, 300, 6, 22, "Print"],
Cell[679872, 18964, 310, 6, 22, "Print"],
Cell[680185, 18972, 308, 6, 22, "Print"],
Cell[680496, 18980, 39, 1, 22, "Print"],
Cell[680538, 18983, 509, 11, 22, "Print"],
Cell[681050, 18996, 525, 12, 22, "Print"],
Cell[681578, 19010, 529, 12, 22, "Print"],
Cell[682110, 19024, 39, 1, 22, "Print"],
Cell[682152, 19027, 300, 6, 22, "Print"],
Cell[682455, 19035, 310, 6, 22, "Print"],
Cell[682768, 19043, 308, 6, 22, "Print"],
Cell[683079, 19051, 39, 1, 22, "Print"],
Cell[683121, 19054, 300, 6, 22, "Print"],
Cell[683424, 19062, 310, 6, 22, "Print"],
Cell[683737, 19070, 308, 6, 22, "Print"],
Cell[684048, 19078, 39, 1, 22, "Print"],
Cell[684090, 19081, 300, 6, 22, "Print"],
Cell[684393, 19089, 310, 6, 22, "Print"],
Cell[684706, 19097, 308, 6, 22, "Print"],
Cell[685017, 19105, 39, 1, 22, "Print"],
Cell[685059, 19108, 300, 6, 22, "Print"],
Cell[685362, 19116, 310, 6, 22, "Print"],
Cell[685675, 19124, 308, 6, 22, "Print"],
Cell[685986, 19132, 39, 1, 22, "Print"],
Cell[686028, 19135, 300, 6, 22, "Print"],
Cell[686331, 19143, 310, 6, 22, "Print"],
Cell[686644, 19151, 308, 6, 22, "Print"],
Cell[686955, 19159, 39, 1, 22, "Print"],
Cell[686997, 19162, 512, 11, 24, "Print"],
Cell[687512, 19175, 529, 12, 24, "Print"],
Cell[688044, 19189, 529, 12, 22, "Print"],
Cell[688576, 19203, 39, 1, 22, "Print"],
Cell[688618, 19206, 300, 6, 22, "Print"],
Cell[688921, 19214, 310, 6, 22, "Print"],
Cell[689234, 19222, 308, 6, 22, "Print"],
Cell[689545, 19230, 39, 1, 22, "Print"],
Cell[689587, 19233, 300, 6, 22, "Print"],
Cell[689890, 19241, 310, 6, 22, "Print"],
Cell[690203, 19249, 308, 6, 22, "Print"],
Cell[690514, 19257, 39, 1, 22, "Print"],
Cell[690556, 19260, 300, 6, 22, "Print"],
Cell[690859, 19268, 310, 6, 22, "Print"],
Cell[691172, 19276, 308, 6, 22, "Print"],
Cell[691483, 19284, 39, 1, 22, "Print"],
Cell[691525, 19287, 300, 6, 22, "Print"],
Cell[691828, 19295, 310, 6, 22, "Print"],
Cell[692141, 19303, 308, 6, 22, "Print"],
Cell[692452, 19311, 39, 1, 22, "Print"],
Cell[692494, 19314, 300, 6, 22, "Print"],
Cell[692797, 19322, 310, 6, 22, "Print"],
Cell[693110, 19330, 308, 6, 22, "Print"],
Cell[693421, 19338, 39, 1, 22, "Print"],
Cell[693463, 19341, 513, 11, 24, "Print"],
Cell[693979, 19354, 530, 12, 24, "Print"],
Cell[694512, 19368, 529, 12, 22, "Print"],
Cell[695044, 19382, 39, 1, 22, "Print"],
Cell[695086, 19385, 300, 6, 22, "Print"],
Cell[695389, 19393, 310, 6, 22, "Print"],
Cell[695702, 19401, 308, 6, 22, "Print"],
Cell[696013, 19409, 39, 1, 22, "Print"],
Cell[696055, 19412, 300, 6, 22, "Print"],
Cell[696358, 19420, 310, 6, 22, "Print"],
Cell[696671, 19428, 308, 6, 22, "Print"],
Cell[696982, 19436, 39, 1, 22, "Print"],
Cell[697024, 19439, 300, 6, 22, "Print"],
Cell[697327, 19447, 310, 6, 22, "Print"],
Cell[697640, 19455, 308, 6, 22, "Print"],
Cell[697951, 19463, 39, 1, 22, "Print"],
Cell[697993, 19466, 300, 6, 22, "Print"],
Cell[698296, 19474, 310, 6, 22, "Print"],
Cell[698609, 19482, 308, 6, 22, "Print"],
Cell[698920, 19490, 39, 1, 22, "Print"],
Cell[698962, 19493, 300, 6, 22, "Print"],
Cell[699265, 19501, 310, 6, 22, "Print"],
Cell[699578, 19509, 308, 6, 22, "Print"],
Cell[699889, 19517, 39, 1, 22, "Print"],
Cell[699931, 19520, 513, 11, 24, "Print"],
Cell[700447, 19533, 530, 12, 24, "Print"],
Cell[700980, 19547, 529, 12, 22, "Print"],
Cell[701512, 19561, 39, 1, 22, "Print"],
Cell[701554, 19564, 300, 6, 22, "Print"],
Cell[701857, 19572, 310, 6, 22, "Print"],
Cell[702170, 19580, 308, 6, 22, "Print"],
Cell[702481, 19588, 39, 1, 22, "Print"],
Cell[702523, 19591, 300, 6, 22, "Print"],
Cell[702826, 19599, 310, 6, 22, "Print"],
Cell[703139, 19607, 308, 6, 22, "Print"],
Cell[703450, 19615, 39, 1, 22, "Print"],
Cell[703492, 19618, 300, 6, 22, "Print"],
Cell[703795, 19626, 310, 6, 22, "Print"],
Cell[704108, 19634, 308, 6, 22, "Print"],
Cell[704419, 19642, 39, 1, 22, "Print"],
Cell[704461, 19645, 300, 6, 22, "Print"],
Cell[704764, 19653, 310, 6, 22, "Print"],
Cell[705077, 19661, 308, 6, 22, "Print"],
Cell[705388, 19669, 39, 1, 22, "Print"],
Cell[705430, 19672, 300, 6, 22, "Print"],
Cell[705733, 19680, 310, 6, 22, "Print"],
Cell[706046, 19688, 308, 6, 22, "Print"],
Cell[706357, 19696, 39, 1, 22, "Print"],
Cell[706399, 19699, 525, 12, 24, "Print"],
Cell[706927, 19713, 535, 12, 24, "Print"],
Cell[707465, 19727, 529, 12, 22, "Print"],
Cell[707997, 19741, 39, 1, 22, "Print"],
Cell[708039, 19744, 300, 6, 22, "Print"],
Cell[708342, 19752, 310, 6, 22, "Print"],
Cell[708655, 19760, 308, 6, 22, "Print"],
Cell[708966, 19768, 39, 1, 22, "Print"],
Cell[709008, 19771, 300, 6, 22, "Print"],
Cell[709311, 19779, 310, 6, 22, "Print"],
Cell[709624, 19787, 308, 6, 22, "Print"],
Cell[709935, 19795, 39, 1, 22, "Print"],
Cell[709977, 19798, 300, 6, 22, "Print"],
Cell[710280, 19806, 310, 6, 22, "Print"],
Cell[710593, 19814, 308, 6, 22, "Print"],
Cell[710904, 19822, 39, 1, 22, "Print"],
Cell[710946, 19825, 300, 6, 22, "Print"],
Cell[711249, 19833, 310, 6, 22, "Print"],
Cell[711562, 19841, 308, 6, 22, "Print"],
Cell[711873, 19849, 39, 1, 22, "Print"],
Cell[711915, 19852, 300, 6, 22, "Print"],
Cell[712218, 19860, 310, 6, 22, "Print"],
Cell[712531, 19868, 308, 6, 22, "Print"],
Cell[712842, 19876, 39, 1, 22, "Print"],
Cell[712884, 19879, 524, 12, 24, "Print"],
Cell[713411, 19893, 535, 12, 24, "Print"],
Cell[713949, 19907, 529, 12, 22, "Print"],
Cell[714481, 19921, 39, 1, 22, "Print"],
Cell[714523, 19924, 300, 6, 22, "Print"],
Cell[714826, 19932, 310, 6, 22, "Print"],
Cell[715139, 19940, 308, 6, 22, "Print"],
Cell[715450, 19948, 39, 1, 22, "Print"],
Cell[715492, 19951, 300, 6, 22, "Print"],
Cell[715795, 19959, 310, 6, 22, "Print"],
Cell[716108, 19967, 308, 6, 22, "Print"],
Cell[716419, 19975, 39, 1, 22, "Print"],
Cell[716461, 19978, 300, 6, 22, "Print"],
Cell[716764, 19986, 310, 6, 22, "Print"],
Cell[717077, 19994, 308, 6, 22, "Print"],
Cell[717388, 20002, 39, 1, 22, "Print"],
Cell[717430, 20005, 300, 6, 22, "Print"],
Cell[717733, 20013, 310, 6, 22, "Print"],
Cell[718046, 20021, 308, 6, 22, "Print"],
Cell[718357, 20029, 39, 1, 22, "Print"],
Cell[718399, 20032, 300, 6, 22, "Print"],
Cell[718702, 20040, 310, 6, 22, "Print"],
Cell[719015, 20048, 308, 6, 22, "Print"],
Cell[719326, 20056, 39, 1, 22, "Print"],
Cell[719368, 20059, 525, 12, 24, "Print"],
Cell[719896, 20073, 535, 12, 24, "Print"],
Cell[720434, 20087, 529, 12, 22, "Print"],
Cell[720966, 20101, 39, 1, 22, "Print"],
Cell[721008, 20104, 300, 6, 22, "Print"],
Cell[721311, 20112, 310, 6, 22, "Print"],
Cell[721624, 20120, 308, 6, 22, "Print"],
Cell[721935, 20128, 39, 1, 22, "Print"],
Cell[721977, 20131, 300, 6, 22, "Print"],
Cell[722280, 20139, 310, 6, 22, "Print"],
Cell[722593, 20147, 308, 6, 22, "Print"],
Cell[722904, 20155, 39, 1, 22, "Print"],
Cell[722946, 20158, 300, 6, 22, "Print"],
Cell[723249, 20166, 310, 6, 22, "Print"],
Cell[723562, 20174, 308, 6, 22, "Print"],
Cell[723873, 20182, 39, 1, 22, "Print"],
Cell[723915, 20185, 300, 6, 22, "Print"],
Cell[724218, 20193, 310, 6, 22, "Print"],
Cell[724531, 20201, 308, 6, 22, "Print"],
Cell[724842, 20209, 39, 1, 22, "Print"],
Cell[724884, 20212, 300, 6, 22, "Print"],
Cell[725187, 20220, 310, 6, 22, "Print"],
Cell[725500, 20228, 308, 6, 22, "Print"],
Cell[725811, 20236, 39, 1, 22, "Print"],
Cell[725853, 20239, 525, 12, 24, "Print"],
Cell[726381, 20253, 535, 12, 24, "Print"],
Cell[726919, 20267, 528, 12, 22, "Print"],
Cell[727450, 20281, 39, 1, 22, "Print"],
Cell[727492, 20284, 300, 6, 22, "Print"],
Cell[727795, 20292, 310, 6, 22, "Print"],
Cell[728108, 20300, 308, 6, 22, "Print"],
Cell[728419, 20308, 39, 1, 22, "Print"],
Cell[728461, 20311, 300, 6, 22, "Print"],
Cell[728764, 20319, 310, 6, 22, "Print"],
Cell[729077, 20327, 308, 6, 22, "Print"],
Cell[729388, 20335, 39, 1, 22, "Print"],
Cell[729430, 20338, 300, 6, 22, "Print"],
Cell[729733, 20346, 310, 6, 22, "Print"],
Cell[730046, 20354, 308, 6, 22, "Print"],
Cell[730357, 20362, 39, 1, 22, "Print"],
Cell[730399, 20365, 300, 6, 22, "Print"],
Cell[730702, 20373, 310, 6, 22, "Print"],
Cell[731015, 20381, 308, 6, 22, "Print"],
Cell[731326, 20389, 39, 1, 22, "Print"],
Cell[731368, 20392, 300, 6, 22, "Print"],
Cell[731671, 20400, 310, 6, 22, "Print"],
Cell[731984, 20408, 308, 6, 22, "Print"],
Cell[732295, 20416, 39, 1, 22, "Print"],
Cell[732337, 20419, 525, 12, 24, "Print"],
Cell[732865, 20433, 534, 12, 24, "Print"],
Cell[733402, 20447, 529, 12, 22, "Print"],
Cell[733934, 20461, 39, 1, 22, "Print"],
Cell[733976, 20464, 300, 6, 22, "Print"],
Cell[734279, 20472, 310, 6, 22, "Print"],
Cell[734592, 20480, 308, 6, 22, "Print"],
Cell[734903, 20488, 39, 1, 22, "Print"],
Cell[734945, 20491, 300, 6, 22, "Print"],
Cell[735248, 20499, 310, 6, 22, "Print"],
Cell[735561, 20507, 308, 6, 22, "Print"],
Cell[735872, 20515, 39, 1, 22, "Print"],
Cell[735914, 20518, 300, 6, 22, "Print"],
Cell[736217, 20526, 310, 6, 22, "Print"],
Cell[736530, 20534, 308, 6, 22, "Print"],
Cell[736841, 20542, 39, 1, 22, "Print"],
Cell[736883, 20545, 300, 6, 22, "Print"],
Cell[737186, 20553, 310, 6, 22, "Print"],
Cell[737499, 20561, 308, 6, 22, "Print"],
Cell[737810, 20569, 39, 1, 22, "Print"],
Cell[737852, 20572, 300, 6, 22, "Print"],
Cell[738155, 20580, 310, 6, 22, "Print"],
Cell[738468, 20588, 308, 6, 22, "Print"],
Cell[738779, 20596, 39, 1, 22, "Print"],
Cell[738821, 20599, 524, 12, 24, "Print"],
Cell[739348, 20613, 534, 12, 24, "Print"],
Cell[739885, 20627, 529, 12, 22, "Print"],
Cell[740417, 20641, 39, 1, 22, "Print"],
Cell[740459, 20644, 300, 6, 22, "Print"],
Cell[740762, 20652, 310, 6, 22, "Print"],
Cell[741075, 20660, 308, 6, 22, "Print"],
Cell[741386, 20668, 39, 1, 22, "Print"],
Cell[741428, 20671, 300, 6, 22, "Print"],
Cell[741731, 20679, 310, 6, 22, "Print"],
Cell[742044, 20687, 308, 6, 22, "Print"],
Cell[742355, 20695, 39, 1, 22, "Print"],
Cell[742397, 20698, 300, 6, 22, "Print"],
Cell[742700, 20706, 310, 6, 22, "Print"],
Cell[743013, 20714, 308, 6, 22, "Print"],
Cell[743324, 20722, 39, 1, 22, "Print"],
Cell[743366, 20725, 300, 6, 22, "Print"],
Cell[743669, 20733, 310, 6, 22, "Print"],
Cell[743982, 20741, 308, 6, 22, "Print"],
Cell[744293, 20749, 39, 1, 22, "Print"],
Cell[744335, 20752, 300, 6, 22, "Print"],
Cell[744638, 20760, 310, 6, 22, "Print"],
Cell[744951, 20768, 308, 6, 22, "Print"],
Cell[745262, 20776, 39, 1, 22, "Print"],
Cell[745304, 20779, 524, 12, 24, "Print"],
Cell[745831, 20793, 534, 12, 24, "Print"],
Cell[746368, 20807, 529, 12, 22, "Print"],
Cell[746900, 20821, 39, 1, 22, "Print"],
Cell[746942, 20824, 300, 6, 22, "Print"],
Cell[747245, 20832, 310, 6, 22, "Print"],
Cell[747558, 20840, 308, 6, 22, "Print"],
Cell[747869, 20848, 39, 1, 22, "Print"],
Cell[747911, 20851, 300, 6, 22, "Print"],
Cell[748214, 20859, 310, 6, 22, "Print"],
Cell[748527, 20867, 308, 6, 22, "Print"],
Cell[748838, 20875, 39, 1, 22, "Print"],
Cell[748880, 20878, 300, 6, 22, "Print"],
Cell[749183, 20886, 310, 6, 22, "Print"],
Cell[749496, 20894, 308, 6, 22, "Print"],
Cell[749807, 20902, 39, 1, 22, "Print"],
Cell[749849, 20905, 300, 6, 22, "Print"],
Cell[750152, 20913, 310, 6, 22, "Print"],
Cell[750465, 20921, 308, 6, 22, "Print"],
Cell[750776, 20929, 39, 1, 22, "Print"],
Cell[750818, 20932, 300, 6, 22, "Print"],
Cell[751121, 20940, 310, 6, 22, "Print"],
Cell[751434, 20948, 308, 6, 22, "Print"],
Cell[751745, 20956, 39, 1, 22, "Print"],
Cell[751787, 20959, 525, 12, 24, "Print"],
Cell[752315, 20973, 535, 12, 24, "Print"],
Cell[752853, 20987, 529, 12, 22, "Print"],
Cell[753385, 21001, 39, 1, 22, "Print"],
Cell[753427, 21004, 300, 6, 22, "Print"],
Cell[753730, 21012, 310, 6, 22, "Print"],
Cell[754043, 21020, 308, 6, 22, "Print"],
Cell[754354, 21028, 39, 1, 22, "Print"],
Cell[754396, 21031, 300, 6, 22, "Print"],
Cell[754699, 21039, 310, 6, 22, "Print"],
Cell[755012, 21047, 308, 6, 22, "Print"],
Cell[755323, 21055, 39, 1, 22, "Print"],
Cell[755365, 21058, 300, 6, 22, "Print"],
Cell[755668, 21066, 310, 6, 22, "Print"],
Cell[755981, 21074, 308, 6, 22, "Print"],
Cell[756292, 21082, 39, 1, 22, "Print"],
Cell[756334, 21085, 300, 6, 22, "Print"],
Cell[756637, 21093, 310, 6, 22, "Print"],
Cell[756950, 21101, 308, 6, 22, "Print"],
Cell[757261, 21109, 39, 1, 22, "Print"],
Cell[757303, 21112, 300, 6, 22, "Print"],
Cell[757606, 21120, 310, 6, 22, "Print"],
Cell[757919, 21128, 308, 6, 22, "Print"],
Cell[758230, 21136, 39, 1, 22, "Print"],
Cell[758272, 21139, 525, 12, 24, "Print"],
Cell[758800, 21153, 535, 12, 24, "Print"],
Cell[759338, 21167, 529, 12, 22, "Print"],
Cell[759870, 21181, 39, 1, 22, "Print"],
Cell[759912, 21184, 300, 6, 22, "Print"],
Cell[760215, 21192, 310, 6, 22, "Print"],
Cell[760528, 21200, 308, 6, 22, "Print"],
Cell[760839, 21208, 39, 1, 22, "Print"],
Cell[760881, 21211, 300, 6, 22, "Print"],
Cell[761184, 21219, 310, 6, 22, "Print"],
Cell[761497, 21227, 308, 6, 22, "Print"],
Cell[761808, 21235, 39, 1, 22, "Print"],
Cell[761850, 21238, 300, 6, 22, "Print"],
Cell[762153, 21246, 310, 6, 22, "Print"],
Cell[762466, 21254, 308, 6, 22, "Print"],
Cell[762777, 21262, 39, 1, 22, "Print"],
Cell[762819, 21265, 300, 6, 22, "Print"],
Cell[763122, 21273, 310, 6, 22, "Print"],
Cell[763435, 21281, 308, 6, 22, "Print"],
Cell[763746, 21289, 39, 1, 22, "Print"],
Cell[763788, 21292, 300, 6, 22, "Print"],
Cell[764091, 21300, 310, 6, 22, "Print"],
Cell[764404, 21308, 308, 6, 22, "Print"],
Cell[764715, 21316, 39, 1, 22, "Print"],
Cell[764757, 21319, 525, 12, 24, "Print"],
Cell[765285, 21333, 535, 12, 24, "Print"],
Cell[765823, 21347, 529, 12, 22, "Print"],
Cell[766355, 21361, 39, 1, 22, "Print"],
Cell[766397, 21364, 300, 6, 22, "Print"],
Cell[766700, 21372, 310, 6, 22, "Print"],
Cell[767013, 21380, 308, 6, 22, "Print"],
Cell[767324, 21388, 39, 1, 22, "Print"],
Cell[767366, 21391, 300, 6, 22, "Print"],
Cell[767669, 21399, 310, 6, 22, "Print"],
Cell[767982, 21407, 308, 6, 22, "Print"],
Cell[768293, 21415, 39, 1, 22, "Print"],
Cell[768335, 21418, 300, 6, 22, "Print"],
Cell[768638, 21426, 310, 6, 22, "Print"],
Cell[768951, 21434, 308, 6, 22, "Print"],
Cell[769262, 21442, 39, 1, 22, "Print"],
Cell[769304, 21445, 300, 6, 22, "Print"],
Cell[769607, 21453, 310, 6, 22, "Print"],
Cell[769920, 21461, 308, 6, 22, "Print"],
Cell[770231, 21469, 39, 1, 22, "Print"],
Cell[770273, 21472, 300, 6, 22, "Print"],
Cell[770576, 21480, 310, 6, 22, "Print"],
Cell[770889, 21488, 308, 6, 22, "Print"],
Cell[771200, 21496, 39, 1, 22, "Print"],
Cell[771242, 21499, 525, 12, 24, "Print"],
Cell[771770, 21513, 535, 12, 24, "Print"],
Cell[772308, 21527, 529, 12, 22, "Print"],
Cell[772840, 21541, 39, 1, 22, "Print"],
Cell[772882, 21544, 302, 6, 22, "Print"],
Cell[773187, 21552, 312, 6, 22, "Print"],
Cell[773502, 21560, 310, 6, 22, "Print"],
Cell[773815, 21568, 39, 1, 22, "Print"],
Cell[773857, 21571, 302, 6, 22, "Print"],
Cell[774162, 21579, 312, 6, 22, "Print"],
Cell[774477, 21587, 310, 6, 22, "Print"],
Cell[774790, 21595, 39, 1, 22, "Print"],
Cell[774832, 21598, 302, 6, 22, "Print"],
Cell[775137, 21606, 312, 6, 22, "Print"],
Cell[775452, 21614, 310, 6, 22, "Print"],
Cell[775765, 21622, 39, 1, 22, "Print"],
Cell[775807, 21625, 302, 6, 22, "Print"],
Cell[776112, 21633, 312, 6, 22, "Print"],
Cell[776427, 21641, 310, 6, 22, "Print"],
Cell[776740, 21649, 39, 1, 22, "Print"],
Cell[776782, 21652, 302, 6, 22, "Print"],
Cell[777087, 21660, 312, 6, 22, "Print"],
Cell[777402, 21668, 310, 6, 22, "Print"],
Cell[777715, 21676, 39, 1, 22, "Print"],
Cell[777757, 21679, 527, 12, 24, "Print"],
Cell[778287, 21693, 537, 12, 24, "Print"],
Cell[778827, 21707, 530, 12, 22, "Print"],
Cell[779360, 21721, 39, 1, 22, "Print"],
Cell[779402, 21724, 302, 6, 22, "Print"],
Cell[779707, 21732, 312, 6, 22, "Print"],
Cell[780022, 21740, 310, 6, 22, "Print"],
Cell[780335, 21748, 39, 1, 22, "Print"],
Cell[780377, 21751, 302, 6, 22, "Print"],
Cell[780682, 21759, 312, 6, 22, "Print"],
Cell[780997, 21767, 310, 6, 22, "Print"],
Cell[781310, 21775, 39, 1, 22, "Print"],
Cell[781352, 21778, 302, 6, 22, "Print"],
Cell[781657, 21786, 312, 6, 22, "Print"],
Cell[781972, 21794, 310, 6, 22, "Print"],
Cell[782285, 21802, 39, 1, 22, "Print"],
Cell[782327, 21805, 302, 6, 22, "Print"],
Cell[782632, 21813, 312, 6, 22, "Print"],
Cell[782947, 21821, 310, 6, 22, "Print"],
Cell[783260, 21829, 39, 1, 22, "Print"],
Cell[783302, 21832, 302, 6, 22, "Print"],
Cell[783607, 21840, 312, 6, 22, "Print"],
Cell[783922, 21848, 310, 6, 22, "Print"],
Cell[784235, 21856, 39, 1, 22, "Print"],
Cell[784277, 21859, 526, 12, 24, "Print"],
Cell[784806, 21873, 537, 12, 24, "Print"],
Cell[785346, 21887, 531, 12, 22, "Print"],
Cell[785880, 21901, 39, 1, 22, "Print"],
Cell[785922, 21904, 302, 6, 22, "Print"],
Cell[786227, 21912, 312, 6, 22, "Print"],
Cell[786542, 21920, 310, 6, 22, "Print"],
Cell[786855, 21928, 39, 1, 22, "Print"],
Cell[786897, 21931, 302, 6, 22, "Print"],
Cell[787202, 21939, 312, 6, 22, "Print"],
Cell[787517, 21947, 310, 6, 22, "Print"],
Cell[787830, 21955, 39, 1, 22, "Print"],
Cell[787872, 21958, 302, 6, 22, "Print"],
Cell[788177, 21966, 312, 6, 22, "Print"],
Cell[788492, 21974, 310, 6, 22, "Print"],
Cell[788805, 21982, 39, 1, 22, "Print"],
Cell[788847, 21985, 302, 6, 22, "Print"],
Cell[789152, 21993, 312, 6, 22, "Print"],
Cell[789467, 22001, 310, 6, 22, "Print"],
Cell[789780, 22009, 39, 1, 22, "Print"],
Cell[789822, 22012, 302, 6, 22, "Print"],
Cell[790127, 22020, 312, 6, 22, "Print"],
Cell[790442, 22028, 310, 6, 22, "Print"],
Cell[790755, 22036, 39, 1, 22, "Print"],
Cell[790797, 22039, 529, 12, 24, "Print"],
Cell[791329, 22053, 538, 12, 24, "Print"],
Cell[791870, 22067, 531, 12, 22, "Print"],
Cell[792404, 22081, 39, 1, 22, "Print"],
Cell[792446, 22084, 302, 6, 22, "Print"],
Cell[792751, 22092, 312, 6, 22, "Print"],
Cell[793066, 22100, 310, 6, 22, "Print"],
Cell[793379, 22108, 39, 1, 22, "Print"],
Cell[793421, 22111, 302, 6, 22, "Print"],
Cell[793726, 22119, 312, 6, 22, "Print"],
Cell[794041, 22127, 310, 6, 22, "Print"],
Cell[794354, 22135, 39, 1, 22, "Print"],
Cell[794396, 22138, 302, 6, 22, "Print"],
Cell[794701, 22146, 312, 6, 22, "Print"],
Cell[795016, 22154, 310, 6, 22, "Print"],
Cell[795329, 22162, 39, 1, 22, "Print"],
Cell[795371, 22165, 302, 6, 22, "Print"],
Cell[795676, 22173, 312, 6, 22, "Print"],
Cell[795991, 22181, 310, 6, 22, "Print"],
Cell[796304, 22189, 39, 1, 22, "Print"],
Cell[796346, 22192, 302, 6, 22, "Print"],
Cell[796651, 22200, 312, 6, 22, "Print"],
Cell[796966, 22208, 310, 6, 22, "Print"],
Cell[797279, 22216, 39, 1, 22, "Print"],
Cell[797321, 22219, 528, 12, 24, "Print"],
Cell[797852, 22233, 539, 12, 24, "Print"],
Cell[798394, 22247, 531, 12, 22, "Print"],
Cell[798928, 22261, 39, 1, 22, "Print"],
Cell[798970, 22264, 302, 6, 22, "Print"],
Cell[799275, 22272, 312, 6, 22, "Print"],
Cell[799590, 22280, 310, 6, 22, "Print"],
Cell[799903, 22288, 39, 1, 22, "Print"],
Cell[799945, 22291, 302, 6, 22, "Print"],
Cell[800250, 22299, 312, 6, 22, "Print"],
Cell[800565, 22307, 310, 6, 22, "Print"],
Cell[800878, 22315, 39, 1, 22, "Print"],
Cell[800920, 22318, 302, 6, 22, "Print"],
Cell[801225, 22326, 312, 6, 22, "Print"],
Cell[801540, 22334, 310, 6, 22, "Print"],
Cell[801853, 22342, 39, 1, 22, "Print"],
Cell[801895, 22345, 302, 6, 22, "Print"],
Cell[802200, 22353, 312, 6, 22, "Print"],
Cell[802515, 22361, 310, 6, 22, "Print"],
Cell[802828, 22369, 39, 1, 22, "Print"],
Cell[802870, 22372, 302, 6, 22, "Print"],
Cell[803175, 22380, 312, 6, 22, "Print"],
Cell[803490, 22388, 310, 6, 22, "Print"],
Cell[803803, 22396, 39, 1, 22, "Print"],
Cell[803845, 22399, 529, 12, 24, "Print"],
Cell[804377, 22413, 539, 12, 24, "Print"],
Cell[804919, 22427, 530, 12, 22, "Print"],
Cell[805452, 22441, 39, 1, 22, "Print"],
Cell[805494, 22444, 302, 6, 22, "Print"],
Cell[805799, 22452, 312, 6, 22, "Print"],
Cell[806114, 22460, 310, 6, 22, "Print"],
Cell[806427, 22468, 39, 1, 22, "Print"],
Cell[806469, 22471, 302, 6, 22, "Print"],
Cell[806774, 22479, 312, 6, 22, "Print"],
Cell[807089, 22487, 310, 6, 22, "Print"],
Cell[807402, 22495, 39, 1, 22, "Print"],
Cell[807444, 22498, 302, 6, 22, "Print"],
Cell[807749, 22506, 312, 6, 22, "Print"],
Cell[808064, 22514, 310, 6, 22, "Print"],
Cell[808377, 22522, 39, 1, 22, "Print"],
Cell[808419, 22525, 302, 6, 22, "Print"],
Cell[808724, 22533, 312, 6, 22, "Print"],
Cell[809039, 22541, 310, 6, 22, "Print"],
Cell[809352, 22549, 39, 1, 22, "Print"],
Cell[809394, 22552, 302, 6, 22, "Print"],
Cell[809699, 22560, 312, 6, 22, "Print"],
Cell[810014, 22568, 310, 6, 22, "Print"],
Cell[810327, 22576, 39, 1, 22, "Print"],
Cell[810369, 22579, 528, 12, 24, "Print"],
Cell[810900, 22593, 539, 12, 24, "Print"],
Cell[811442, 22607, 531, 12, 22, "Print"],
Cell[811976, 22621, 39, 1, 22, "Print"],
Cell[812018, 22624, 302, 6, 22, "Print"],
Cell[812323, 22632, 312, 6, 22, "Print"],
Cell[812638, 22640, 310, 6, 22, "Print"],
Cell[812951, 22648, 39, 1, 22, "Print"],
Cell[812993, 22651, 302, 6, 22, "Print"],
Cell[813298, 22659, 312, 6, 22, "Print"],
Cell[813613, 22667, 310, 6, 22, "Print"],
Cell[813926, 22675, 39, 1, 22, "Print"],
Cell[813968, 22678, 302, 6, 22, "Print"],
Cell[814273, 22686, 312, 6, 22, "Print"],
Cell[814588, 22694, 310, 6, 22, "Print"],
Cell[814901, 22702, 39, 1, 22, "Print"],
Cell[814943, 22705, 302, 6, 22, "Print"],
Cell[815248, 22713, 312, 6, 22, "Print"],
Cell[815563, 22721, 310, 6, 22, "Print"],
Cell[815876, 22729, 39, 1, 22, "Print"],
Cell[815918, 22732, 302, 6, 22, "Print"],
Cell[816223, 22740, 312, 6, 22, "Print"],
Cell[816538, 22748, 310, 6, 22, "Print"],
Cell[816851, 22756, 39, 1, 22, "Print"],
Cell[816893, 22759, 529, 12, 24, "Print"],
Cell[817425, 22773, 537, 12, 24, "Print"],
Cell[817965, 22787, 531, 12, 22, "Print"],
Cell[818499, 22801, 39, 1, 22, "Print"],
Cell[818541, 22804, 302, 6, 22, "Print"],
Cell[818846, 22812, 312, 6, 22, "Print"],
Cell[819161, 22820, 310, 6, 22, "Print"],
Cell[819474, 22828, 39, 1, 22, "Print"],
Cell[819516, 22831, 302, 6, 22, "Print"],
Cell[819821, 22839, 312, 6, 22, "Print"],
Cell[820136, 22847, 310, 6, 22, "Print"],
Cell[820449, 22855, 39, 1, 22, "Print"],
Cell[820491, 22858, 302, 6, 22, "Print"],
Cell[820796, 22866, 312, 6, 22, "Print"],
Cell[821111, 22874, 310, 6, 22, "Print"],
Cell[821424, 22882, 39, 1, 22, "Print"],
Cell[821466, 22885, 302, 6, 22, "Print"],
Cell[821771, 22893, 312, 6, 22, "Print"],
Cell[822086, 22901, 310, 6, 22, "Print"],
Cell[822399, 22909, 39, 1, 22, "Print"],
Cell[822441, 22912, 302, 6, 22, "Print"],
Cell[822746, 22920, 312, 6, 22, "Print"],
Cell[823061, 22928, 310, 6, 22, "Print"],
Cell[823374, 22936, 39, 1, 22, "Print"],
Cell[823416, 22939, 528, 12, 24, "Print"],
Cell[823947, 22953, 539, 12, 24, "Print"],
Cell[824489, 22967, 531, 12, 22, "Print"],
Cell[825023, 22981, 39, 1, 22, "Print"],
Cell[825065, 22984, 302, 6, 22, "Print"],
Cell[825370, 22992, 312, 6, 22, "Print"],
Cell[825685, 23000, 310, 6, 22, "Print"],
Cell[825998, 23008, 39, 1, 22, "Print"],
Cell[826040, 23011, 302, 6, 22, "Print"],
Cell[826345, 23019, 312, 6, 22, "Print"],
Cell[826660, 23027, 310, 6, 22, "Print"],
Cell[826973, 23035, 39, 1, 22, "Print"],
Cell[827015, 23038, 302, 6, 22, "Print"],
Cell[827320, 23046, 312, 6, 22, "Print"],
Cell[827635, 23054, 310, 6, 22, "Print"],
Cell[827948, 23062, 39, 1, 22, "Print"],
Cell[827990, 23065, 302, 6, 22, "Print"],
Cell[828295, 23073, 312, 6, 22, "Print"],
Cell[828610, 23081, 310, 6, 22, "Print"],
Cell[828923, 23089, 39, 1, 22, "Print"],
Cell[828965, 23092, 302, 6, 22, "Print"],
Cell[829270, 23100, 312, 6, 22, "Print"],
Cell[829585, 23108, 310, 6, 22, "Print"],
Cell[829898, 23116, 39, 1, 22, "Print"],
Cell[829940, 23119, 529, 12, 24, "Print"],
Cell[830472, 23133, 538, 12, 24, "Print"],
Cell[831013, 23147, 531, 12, 22, "Print"],
Cell[831547, 23161, 39, 1, 22, "Print"],
Cell[831589, 23164, 302, 6, 22, "Print"],
Cell[831894, 23172, 312, 6, 22, "Print"],
Cell[832209, 23180, 310, 6, 22, "Print"],
Cell[832522, 23188, 39, 1, 22, "Print"],
Cell[832564, 23191, 302, 6, 22, "Print"],
Cell[832869, 23199, 312, 6, 22, "Print"],
Cell[833184, 23207, 310, 6, 22, "Print"],
Cell[833497, 23215, 39, 1, 22, "Print"],
Cell[833539, 23218, 302, 6, 22, "Print"],
Cell[833844, 23226, 312, 6, 22, "Print"],
Cell[834159, 23234, 310, 6, 22, "Print"],
Cell[834472, 23242, 39, 1, 22, "Print"],
Cell[834514, 23245, 302, 6, 22, "Print"],
Cell[834819, 23253, 312, 6, 22, "Print"],
Cell[835134, 23261, 310, 6, 22, "Print"],
Cell[835447, 23269, 39, 1, 22, "Print"],
Cell[835489, 23272, 302, 6, 22, "Print"],
Cell[835794, 23280, 312, 6, 22, "Print"],
Cell[836109, 23288, 310, 6, 22, "Print"],
Cell[836422, 23296, 39, 1, 22, "Print"],
Cell[836464, 23299, 527, 12, 24, "Print"],
Cell[836994, 23313, 538, 12, 24, "Print"],
Cell[837535, 23327, 531, 12, 22, "Print"],
Cell[838069, 23341, 39, 1, 22, "Print"],
Cell[838111, 23344, 302, 6, 22, "Print"],
Cell[838416, 23352, 312, 6, 22, "Print"],
Cell[838731, 23360, 310, 6, 22, "Print"],
Cell[839044, 23368, 39, 1, 22, "Print"],
Cell[839086, 23371, 302, 6, 22, "Print"],
Cell[839391, 23379, 312, 6, 22, "Print"],
Cell[839706, 23387, 310, 6, 22, "Print"],
Cell[840019, 23395, 39, 1, 22, "Print"],
Cell[840061, 23398, 302, 6, 22, "Print"],
Cell[840366, 23406, 312, 6, 22, "Print"],
Cell[840681, 23414, 310, 6, 22, "Print"],
Cell[840994, 23422, 39, 1, 22, "Print"],
Cell[841036, 23425, 302, 6, 22, "Print"],
Cell[841341, 23433, 312, 6, 22, "Print"],
Cell[841656, 23441, 310, 6, 22, "Print"],
Cell[841969, 23449, 39, 1, 22, "Print"],
Cell[842011, 23452, 302, 6, 22, "Print"],
Cell[842316, 23460, 312, 6, 22, "Print"],
Cell[842631, 23468, 310, 6, 22, "Print"],
Cell[842944, 23476, 39, 1, 22, "Print"],
Cell[842986, 23479, 529, 12, 24, "Print"],
Cell[843518, 23493, 539, 12, 24, "Print"],
Cell[844060, 23507, 531, 12, 22, "Print"],
Cell[844594, 23521, 39, 1, 22, "Print"],
Cell[844636, 23524, 302, 6, 22, "Print"],
Cell[844941, 23532, 312, 6, 22, "Print"],
Cell[845256, 23540, 310, 6, 22, "Print"],
Cell[845569, 23548, 39, 1, 22, "Print"],
Cell[845611, 23551, 302, 6, 22, "Print"],
Cell[845916, 23559, 312, 6, 22, "Print"],
Cell[846231, 23567, 310, 6, 22, "Print"],
Cell[846544, 23575, 39, 1, 22, "Print"],
Cell[846586, 23578, 302, 6, 22, "Print"],
Cell[846891, 23586, 312, 6, 22, "Print"],
Cell[847206, 23594, 310, 6, 22, "Print"],
Cell[847519, 23602, 39, 1, 22, "Print"],
Cell[847561, 23605, 302, 6, 22, "Print"],
Cell[847866, 23613, 312, 6, 22, "Print"],
Cell[848181, 23621, 310, 6, 22, "Print"],
Cell[848494, 23629, 39, 1, 22, "Print"],
Cell[848536, 23632, 302, 6, 22, "Print"],
Cell[848841, 23640, 312, 6, 22, "Print"],
Cell[849156, 23648, 310, 6, 22, "Print"],
Cell[849469, 23656, 39, 1, 22, "Print"],
Cell[849511, 23659, 529, 12, 24, "Print"],
Cell[850043, 23673, 537, 12, 24, "Print"],
Cell[850583, 23687, 531, 12, 22, "Print"],
Cell[851117, 23701, 39, 1, 22, "Print"],
Cell[851159, 23704, 302, 6, 22, "Print"],
Cell[851464, 23712, 312, 6, 22, "Print"],
Cell[851779, 23720, 310, 6, 22, "Print"],
Cell[852092, 23728, 39, 1, 22, "Print"],
Cell[852134, 23731, 302, 6, 22, "Print"],
Cell[852439, 23739, 312, 6, 22, "Print"],
Cell[852754, 23747, 310, 6, 22, "Print"],
Cell[853067, 23755, 39, 1, 22, "Print"],
Cell[853109, 23758, 302, 6, 22, "Print"],
Cell[853414, 23766, 312, 6, 22, "Print"],
Cell[853729, 23774, 310, 6, 22, "Print"],
Cell[854042, 23782, 39, 1, 22, "Print"],
Cell[854084, 23785, 302, 6, 22, "Print"],
Cell[854389, 23793, 312, 6, 22, "Print"],
Cell[854704, 23801, 310, 6, 22, "Print"],
Cell[855017, 23809, 39, 1, 22, "Print"],
Cell[855059, 23812, 302, 6, 22, "Print"],
Cell[855364, 23820, 312, 6, 22, "Print"],
Cell[855679, 23828, 310, 6, 22, "Print"],
Cell[855992, 23836, 39, 1, 22, "Print"],
Cell[856034, 23839, 529, 12, 24, "Print"],
Cell[856566, 23853, 539, 12, 24, "Print"],
Cell[857108, 23867, 531, 12, 22, "Print"],
Cell[857642, 23881, 39, 1, 22, "Print"],
Cell[857684, 23884, 302, 6, 22, "Print"],
Cell[857989, 23892, 312, 6, 22, "Print"],
Cell[858304, 23900, 310, 6, 22, "Print"],
Cell[858617, 23908, 39, 1, 22, "Print"],
Cell[858659, 23911, 302, 6, 22, "Print"],
Cell[858964, 23919, 312, 6, 22, "Print"],
Cell[859279, 23927, 310, 6, 22, "Print"],
Cell[859592, 23935, 39, 1, 22, "Print"],
Cell[859634, 23938, 302, 6, 22, "Print"],
Cell[859939, 23946, 312, 6, 22, "Print"],
Cell[860254, 23954, 310, 6, 22, "Print"],
Cell[860567, 23962, 39, 1, 22, "Print"],
Cell[860609, 23965, 38, 1, 22, "Print"],
Cell[860650, 23968, 298, 6, 22, "Print"],
Cell[860951, 23976, 308, 6, 22, "Print"],
Cell[861262, 23984, 306, 6, 22, "Print"],
Cell[861571, 23992, 39, 1, 22, "Print"],
Cell[861613, 23995, 298, 6, 22, "Print"],
Cell[861914, 24003, 308, 6, 22, "Print"],
Cell[862225, 24011, 306, 6, 22, "Print"],
Cell[862534, 24019, 39, 1, 22, "Print"],
Cell[862576, 24022, 298, 6, 22, "Print"],
Cell[862877, 24030, 308, 6, 22, "Print"],
Cell[863188, 24038, 306, 6, 22, "Print"],
Cell[863497, 24046, 39, 1, 22, "Print"],
Cell[863539, 24049, 298, 6, 22, "Print"],
Cell[863840, 24057, 308, 6, 22, "Print"],
Cell[864151, 24065, 306, 6, 22, "Print"],
Cell[864460, 24073, 39, 1, 22, "Print"],
Cell[864502, 24076, 475, 11, 22, "Print"],
Cell[864980, 24089, 485, 11, 22, "Print"],
Cell[865468, 24102, 498, 11, 22, "Print"],
Cell[865969, 24115, 39, 1, 22, "Print"],
Cell[866011, 24118, 298, 6, 22, "Print"],
Cell[866312, 24126, 308, 6, 22, "Print"],
Cell[866623, 24134, 306, 6, 22, "Print"],
Cell[866932, 24142, 39, 1, 22, "Print"],
Cell[866974, 24145, 298, 6, 22, "Print"],
Cell[867275, 24153, 308, 6, 22, "Print"],
Cell[867586, 24161, 306, 6, 22, "Print"],
Cell[867895, 24169, 39, 1, 22, "Print"],
Cell[867937, 24172, 298, 6, 22, "Print"],
Cell[868238, 24180, 308, 6, 22, "Print"],
Cell[868549, 24188, 306, 6, 22, "Print"],
Cell[868858, 24196, 39, 1, 22, "Print"],
Cell[868900, 24199, 298, 6, 22, "Print"],
Cell[869201, 24207, 308, 6, 22, "Print"],
Cell[869512, 24215, 306, 6, 22, "Print"],
Cell[869821, 24223, 39, 1, 22, "Print"],
Cell[869863, 24226, 298, 6, 22, "Print"],
Cell[870164, 24234, 308, 6, 22, "Print"],
Cell[870475, 24242, 306, 6, 22, "Print"],
Cell[870784, 24250, 39, 1, 22, "Print"],
Cell[870826, 24253, 479, 11, 22, "Print"],
Cell[871308, 24266, 489, 11, 22, "Print"],
Cell[871800, 24279, 500, 11, 22, "Print"],
Cell[872303, 24292, 39, 1, 22, "Print"],
Cell[872345, 24295, 300, 6, 22, "Print"],
Cell[872648, 24303, 310, 6, 22, "Print"],
Cell[872961, 24311, 308, 6, 22, "Print"],
Cell[873272, 24319, 39, 1, 22, "Print"],
Cell[873314, 24322, 300, 6, 22, "Print"],
Cell[873617, 24330, 310, 6, 22, "Print"],
Cell[873930, 24338, 308, 6, 22, "Print"],
Cell[874241, 24346, 39, 1, 22, "Print"],
Cell[874283, 24349, 300, 6, 22, "Print"],
Cell[874586, 24357, 310, 6, 22, "Print"],
Cell[874899, 24365, 308, 6, 22, "Print"],
Cell[875210, 24373, 39, 1, 22, "Print"],
Cell[875252, 24376, 300, 6, 22, "Print"],
Cell[875555, 24384, 310, 6, 22, "Print"],
Cell[875868, 24392, 308, 6, 22, "Print"],
Cell[876179, 24400, 39, 1, 22, "Print"],
Cell[876221, 24403, 300, 6, 22, "Print"],
Cell[876524, 24411, 310, 6, 22, "Print"],
Cell[876837, 24419, 308, 6, 22, "Print"],
Cell[877148, 24427, 39, 1, 22, "Print"],
Cell[877190, 24430, 507, 11, 22, "Print"],
Cell[877700, 24443, 524, 12, 22, "Print"],
Cell[878227, 24457, 500, 11, 22, "Print"],
Cell[878730, 24470, 39, 1, 22, "Print"],
Cell[878772, 24473, 300, 6, 22, "Print"],
Cell[879075, 24481, 310, 6, 22, "Print"],
Cell[879388, 24489, 308, 6, 22, "Print"],
Cell[879699, 24497, 39, 1, 22, "Print"],
Cell[879741, 24500, 300, 6, 22, "Print"],
Cell[880044, 24508, 310, 6, 22, "Print"],
Cell[880357, 24516, 308, 6, 22, "Print"],
Cell[880668, 24524, 39, 1, 22, "Print"],
Cell[880710, 24527, 300, 6, 22, "Print"],
Cell[881013, 24535, 310, 6, 22, "Print"],
Cell[881326, 24543, 308, 6, 22, "Print"],
Cell[881637, 24551, 39, 1, 22, "Print"],
Cell[881679, 24554, 300, 6, 22, "Print"],
Cell[881982, 24562, 310, 6, 22, "Print"],
Cell[882295, 24570, 308, 6, 22, "Print"],
Cell[882606, 24578, 39, 1, 22, "Print"],
Cell[882648, 24581, 300, 6, 22, "Print"],
Cell[882951, 24589, 310, 6, 22, "Print"],
Cell[883264, 24597, 308, 6, 22, "Print"],
Cell[883575, 24605, 39, 1, 22, "Print"],
Cell[883617, 24608, 512, 11, 24, "Print"],
Cell[884132, 24621, 529, 12, 24, "Print"],
Cell[884664, 24635, 500, 11, 22, "Print"],
Cell[885167, 24648, 39, 1, 22, "Print"],
Cell[885209, 24651, 300, 6, 22, "Print"],
Cell[885512, 24659, 310, 6, 22, "Print"],
Cell[885825, 24667, 308, 6, 22, "Print"],
Cell[886136, 24675, 39, 1, 22, "Print"],
Cell[886178, 24678, 300, 6, 22, "Print"],
Cell[886481, 24686, 310, 6, 22, "Print"],
Cell[886794, 24694, 308, 6, 22, "Print"],
Cell[887105, 24702, 39, 1, 22, "Print"],
Cell[887147, 24705, 300, 6, 22, "Print"],
Cell[887450, 24713, 310, 6, 22, "Print"],
Cell[887763, 24721, 308, 6, 22, "Print"],
Cell[888074, 24729, 39, 1, 22, "Print"],
Cell[888116, 24732, 300, 6, 22, "Print"],
Cell[888419, 24740, 310, 6, 22, "Print"],
Cell[888732, 24748, 308, 6, 22, "Print"],
Cell[889043, 24756, 39, 1, 22, "Print"],
Cell[889085, 24759, 300, 6, 22, "Print"],
Cell[889388, 24767, 310, 6, 22, "Print"],
Cell[889701, 24775, 308, 6, 22, "Print"],
Cell[890012, 24783, 39, 1, 22, "Print"],
Cell[890054, 24786, 512, 11, 24, "Print"],
Cell[890569, 24799, 530, 12, 24, "Print"],
Cell[891102, 24813, 528, 12, 22, "Print"],
Cell[891633, 24827, 39, 1, 22, "Print"],
Cell[891675, 24830, 300, 6, 22, "Print"],
Cell[891978, 24838, 310, 6, 22, "Print"],
Cell[892291, 24846, 308, 6, 22, "Print"],
Cell[892602, 24854, 39, 1, 22, "Print"],
Cell[892644, 24857, 300, 6, 22, "Print"],
Cell[892947, 24865, 310, 6, 22, "Print"],
Cell[893260, 24873, 308, 6, 22, "Print"],
Cell[893571, 24881, 39, 1, 22, "Print"],
Cell[893613, 24884, 300, 6, 22, "Print"],
Cell[893916, 24892, 310, 6, 22, "Print"],
Cell[894229, 24900, 308, 6, 22, "Print"],
Cell[894540, 24908, 39, 1, 22, "Print"],
Cell[894582, 24911, 300, 6, 22, "Print"],
Cell[894885, 24919, 310, 6, 22, "Print"],
Cell[895198, 24927, 308, 6, 22, "Print"],
Cell[895509, 24935, 39, 1, 22, "Print"],
Cell[895551, 24938, 300, 6, 22, "Print"],
Cell[895854, 24946, 310, 6, 22, "Print"],
Cell[896167, 24954, 308, 6, 22, "Print"],
Cell[896478, 24962, 39, 1, 22, "Print"],
Cell[896520, 24965, 514, 11, 24, "Print"],
Cell[897037, 24978, 531, 12, 24, "Print"],
Cell[897571, 24992, 528, 12, 22, "Print"],
Cell[898102, 25006, 39, 1, 22, "Print"],
Cell[898144, 25009, 300, 6, 22, "Print"],
Cell[898447, 25017, 310, 6, 22, "Print"],
Cell[898760, 25025, 308, 6, 22, "Print"],
Cell[899071, 25033, 39, 1, 22, "Print"],
Cell[899113, 25036, 300, 6, 22, "Print"],
Cell[899416, 25044, 310, 6, 22, "Print"],
Cell[899729, 25052, 308, 6, 22, "Print"],
Cell[900040, 25060, 39, 1, 22, "Print"],
Cell[900082, 25063, 300, 6, 22, "Print"],
Cell[900385, 25071, 310, 6, 22, "Print"],
Cell[900698, 25079, 308, 6, 22, "Print"],
Cell[901009, 25087, 39, 1, 22, "Print"],
Cell[901051, 25090, 300, 6, 22, "Print"],
Cell[901354, 25098, 310, 6, 22, "Print"],
Cell[901667, 25106, 308, 6, 22, "Print"],
Cell[901978, 25114, 39, 1, 22, "Print"],
Cell[902020, 25117, 300, 6, 22, "Print"],
Cell[902323, 25125, 310, 6, 22, "Print"],
Cell[902636, 25133, 308, 6, 22, "Print"],
Cell[902947, 25141, 39, 1, 22, "Print"],
Cell[902989, 25144, 525, 12, 24, "Print"],
Cell[903517, 25158, 534, 12, 24, "Print"],
Cell[904054, 25172, 529, 12, 22, "Print"],
Cell[904586, 25186, 39, 1, 22, "Print"],
Cell[904628, 25189, 300, 6, 22, "Print"],
Cell[904931, 25197, 310, 6, 22, "Print"],
Cell[905244, 25205, 308, 6, 22, "Print"],
Cell[905555, 25213, 39, 1, 22, "Print"],
Cell[905597, 25216, 300, 6, 22, "Print"],
Cell[905900, 25224, 310, 6, 22, "Print"],
Cell[906213, 25232, 308, 6, 22, "Print"],
Cell[906524, 25240, 39, 1, 22, "Print"],
Cell[906566, 25243, 300, 6, 22, "Print"],
Cell[906869, 25251, 310, 6, 22, "Print"],
Cell[907182, 25259, 308, 6, 22, "Print"],
Cell[907493, 25267, 39, 1, 22, "Print"],
Cell[907535, 25270, 300, 6, 22, "Print"],
Cell[907838, 25278, 310, 6, 22, "Print"],
Cell[908151, 25286, 308, 6, 22, "Print"],
Cell[908462, 25294, 39, 1, 22, "Print"],
Cell[908504, 25297, 300, 6, 22, "Print"],
Cell[908807, 25305, 310, 6, 22, "Print"],
Cell[909120, 25313, 308, 6, 22, "Print"],
Cell[909431, 25321, 39, 1, 22, "Print"],
Cell[909473, 25324, 525, 12, 24, "Print"],
Cell[910001, 25338, 535, 12, 24, "Print"],
Cell[910539, 25352, 529, 12, 22, "Print"],
Cell[911071, 25366, 39, 1, 22, "Print"],
Cell[911113, 25369, 300, 6, 22, "Print"],
Cell[911416, 25377, 310, 6, 22, "Print"],
Cell[911729, 25385, 308, 6, 22, "Print"],
Cell[912040, 25393, 39, 1, 22, "Print"],
Cell[912082, 25396, 300, 6, 22, "Print"],
Cell[912385, 25404, 310, 6, 22, "Print"],
Cell[912698, 25412, 308, 6, 22, "Print"],
Cell[913009, 25420, 39, 1, 22, "Print"],
Cell[913051, 25423, 300, 6, 22, "Print"],
Cell[913354, 25431, 310, 6, 22, "Print"],
Cell[913667, 25439, 308, 6, 22, "Print"],
Cell[913978, 25447, 39, 1, 22, "Print"],
Cell[914020, 25450, 300, 6, 22, "Print"],
Cell[914323, 25458, 310, 6, 22, "Print"],
Cell[914636, 25466, 308, 6, 22, "Print"],
Cell[914947, 25474, 39, 1, 22, "Print"],
Cell[914989, 25477, 300, 6, 22, "Print"],
Cell[915292, 25485, 310, 6, 22, "Print"],
Cell[915605, 25493, 308, 6, 22, "Print"],
Cell[915916, 25501, 39, 1, 22, "Print"],
Cell[915958, 25504, 525, 12, 24, "Print"],
Cell[916486, 25518, 535, 12, 24, "Print"],
Cell[917024, 25532, 529, 12, 22, "Print"],
Cell[917556, 25546, 39, 1, 22, "Print"],
Cell[917598, 25549, 300, 6, 22, "Print"],
Cell[917901, 25557, 310, 6, 22, "Print"],
Cell[918214, 25565, 308, 6, 22, "Print"],
Cell[918525, 25573, 39, 1, 22, "Print"],
Cell[918567, 25576, 300, 6, 22, "Print"],
Cell[918870, 25584, 310, 6, 22, "Print"],
Cell[919183, 25592, 308, 6, 22, "Print"],
Cell[919494, 25600, 39, 1, 22, "Print"],
Cell[919536, 25603, 300, 6, 22, "Print"],
Cell[919839, 25611, 310, 6, 22, "Print"],
Cell[920152, 25619, 308, 6, 22, "Print"],
Cell[920463, 25627, 39, 1, 22, "Print"],
Cell[920505, 25630, 300, 6, 22, "Print"],
Cell[920808, 25638, 310, 6, 22, "Print"],
Cell[921121, 25646, 308, 6, 22, "Print"],
Cell[921432, 25654, 39, 1, 22, "Print"],
Cell[921474, 25657, 300, 6, 22, "Print"],
Cell[921777, 25665, 310, 6, 22, "Print"],
Cell[922090, 25673, 308, 6, 22, "Print"],
Cell[922401, 25681, 39, 1, 22, "Print"],
Cell[922443, 25684, 525, 12, 24, "Print"],
Cell[922971, 25698, 535, 12, 24, "Print"],
Cell[923509, 25712, 529, 12, 22, "Print"],
Cell[924041, 25726, 39, 1, 22, "Print"],
Cell[924083, 25729, 300, 6, 22, "Print"],
Cell[924386, 25737, 310, 6, 22, "Print"],
Cell[924699, 25745, 308, 6, 22, "Print"],
Cell[925010, 25753, 39, 1, 22, "Print"],
Cell[925052, 25756, 300, 6, 22, "Print"],
Cell[925355, 25764, 310, 6, 22, "Print"],
Cell[925668, 25772, 308, 6, 22, "Print"],
Cell[925979, 25780, 39, 1, 22, "Print"],
Cell[926021, 25783, 300, 6, 22, "Print"],
Cell[926324, 25791, 310, 6, 22, "Print"],
Cell[926637, 25799, 308, 6, 22, "Print"],
Cell[926948, 25807, 39, 1, 22, "Print"],
Cell[926990, 25810, 300, 6, 22, "Print"],
Cell[927293, 25818, 310, 6, 22, "Print"],
Cell[927606, 25826, 308, 6, 22, "Print"],
Cell[927917, 25834, 39, 1, 22, "Print"],
Cell[927959, 25837, 300, 6, 22, "Print"],
Cell[928262, 25845, 310, 6, 22, "Print"],
Cell[928575, 25853, 308, 6, 22, "Print"],
Cell[928886, 25861, 39, 1, 22, "Print"],
Cell[928928, 25864, 524, 12, 24, "Print"],
Cell[929455, 25878, 535, 12, 24, "Print"],
Cell[929993, 25892, 529, 12, 22, "Print"],
Cell[930525, 25906, 39, 1, 22, "Print"],
Cell[930567, 25909, 300, 6, 22, "Print"],
Cell[930870, 25917, 310, 6, 22, "Print"],
Cell[931183, 25925, 308, 6, 22, "Print"],
Cell[931494, 25933, 39, 1, 22, "Print"],
Cell[931536, 25936, 300, 6, 22, "Print"],
Cell[931839, 25944, 310, 6, 22, "Print"],
Cell[932152, 25952, 308, 6, 22, "Print"],
Cell[932463, 25960, 39, 1, 22, "Print"],
Cell[932505, 25963, 300, 6, 22, "Print"],
Cell[932808, 25971, 310, 6, 22, "Print"],
Cell[933121, 25979, 308, 6, 22, "Print"],
Cell[933432, 25987, 39, 1, 22, "Print"],
Cell[933474, 25990, 300, 6, 22, "Print"],
Cell[933777, 25998, 310, 6, 22, "Print"],
Cell[934090, 26006, 308, 6, 22, "Print"],
Cell[934401, 26014, 39, 1, 22, "Print"],
Cell[934443, 26017, 300, 6, 22, "Print"],
Cell[934746, 26025, 310, 6, 22, "Print"],
Cell[935059, 26033, 308, 6, 22, "Print"],
Cell[935370, 26041, 39, 1, 22, "Print"],
Cell[935412, 26044, 525, 12, 24, "Print"],
Cell[935940, 26058, 535, 12, 24, "Print"],
Cell[936478, 26072, 529, 12, 22, "Print"],
Cell[937010, 26086, 39, 1, 22, "Print"],
Cell[937052, 26089, 300, 6, 22, "Print"],
Cell[937355, 26097, 310, 6, 22, "Print"],
Cell[937668, 26105, 308, 6, 22, "Print"],
Cell[937979, 26113, 39, 1, 22, "Print"],
Cell[938021, 26116, 300, 6, 22, "Print"],
Cell[938324, 26124, 310, 6, 22, "Print"],
Cell[938637, 26132, 308, 6, 22, "Print"],
Cell[938948, 26140, 39, 1, 22, "Print"],
Cell[938990, 26143, 300, 6, 22, "Print"],
Cell[939293, 26151, 310, 6, 22, "Print"],
Cell[939606, 26159, 308, 6, 22, "Print"],
Cell[939917, 26167, 39, 1, 22, "Print"],
Cell[939959, 26170, 300, 6, 22, "Print"],
Cell[940262, 26178, 310, 6, 22, "Print"],
Cell[940575, 26186, 308, 6, 22, "Print"],
Cell[940886, 26194, 39, 1, 22, "Print"],
Cell[940928, 26197, 300, 6, 22, "Print"],
Cell[941231, 26205, 310, 6, 22, "Print"],
Cell[941544, 26213, 308, 6, 22, "Print"],
Cell[941855, 26221, 39, 1, 22, "Print"],
Cell[941897, 26224, 525, 12, 24, "Print"],
Cell[942425, 26238, 535, 12, 24, "Print"],
Cell[942963, 26252, 529, 12, 22, "Print"],
Cell[943495, 26266, 39, 1, 22, "Print"],
Cell[943537, 26269, 300, 6, 22, "Print"],
Cell[943840, 26277, 310, 6, 22, "Print"],
Cell[944153, 26285, 308, 6, 22, "Print"],
Cell[944464, 26293, 39, 1, 22, "Print"],
Cell[944506, 26296, 300, 6, 22, "Print"],
Cell[944809, 26304, 310, 6, 22, "Print"],
Cell[945122, 26312, 308, 6, 22, "Print"],
Cell[945433, 26320, 39, 1, 22, "Print"],
Cell[945475, 26323, 300, 6, 22, "Print"],
Cell[945778, 26331, 310, 6, 22, "Print"],
Cell[946091, 26339, 308, 6, 22, "Print"],
Cell[946402, 26347, 39, 1, 22, "Print"],
Cell[946444, 26350, 300, 6, 22, "Print"],
Cell[946747, 26358, 310, 6, 22, "Print"],
Cell[947060, 26366, 308, 6, 22, "Print"],
Cell[947371, 26374, 39, 1, 22, "Print"],
Cell[947413, 26377, 300, 6, 22, "Print"],
Cell[947716, 26385, 310, 6, 22, "Print"],
Cell[948029, 26393, 308, 6, 22, "Print"],
Cell[948340, 26401, 39, 1, 22, "Print"],
Cell[948382, 26404, 525, 12, 24, "Print"],
Cell[948910, 26418, 534, 12, 24, "Print"],
Cell[949447, 26432, 529, 12, 22, "Print"],
Cell[949979, 26446, 39, 1, 22, "Print"],
Cell[950021, 26449, 300, 6, 22, "Print"],
Cell[950324, 26457, 310, 6, 22, "Print"],
Cell[950637, 26465, 308, 6, 22, "Print"],
Cell[950948, 26473, 39, 1, 22, "Print"],
Cell[950990, 26476, 300, 6, 22, "Print"],
Cell[951293, 26484, 310, 6, 22, "Print"],
Cell[951606, 26492, 308, 6, 22, "Print"],
Cell[951917, 26500, 39, 1, 22, "Print"],
Cell[951959, 26503, 300, 6, 22, "Print"],
Cell[952262, 26511, 310, 6, 22, "Print"],
Cell[952575, 26519, 308, 6, 22, "Print"],
Cell[952886, 26527, 39, 1, 22, "Print"],
Cell[952928, 26530, 300, 6, 22, "Print"],
Cell[953231, 26538, 310, 6, 22, "Print"],
Cell[953544, 26546, 308, 6, 22, "Print"],
Cell[953855, 26554, 39, 1, 22, "Print"],
Cell[953897, 26557, 300, 6, 22, "Print"],
Cell[954200, 26565, 310, 6, 22, "Print"],
Cell[954513, 26573, 308, 6, 22, "Print"],
Cell[954824, 26581, 39, 1, 22, "Print"],
Cell[954866, 26584, 525, 12, 24, "Print"],
Cell[955394, 26598, 535, 12, 24, "Print"],
Cell[955932, 26612, 529, 12, 22, "Print"],
Cell[956464, 26626, 39, 1, 22, "Print"],
Cell[956506, 26629, 300, 6, 22, "Print"],
Cell[956809, 26637, 310, 6, 22, "Print"],
Cell[957122, 26645, 308, 6, 22, "Print"],
Cell[957433, 26653, 39, 1, 22, "Print"],
Cell[957475, 26656, 300, 6, 22, "Print"],
Cell[957778, 26664, 310, 6, 22, "Print"],
Cell[958091, 26672, 308, 6, 22, "Print"],
Cell[958402, 26680, 39, 1, 22, "Print"],
Cell[958444, 26683, 300, 6, 22, "Print"],
Cell[958747, 26691, 310, 6, 22, "Print"],
Cell[959060, 26699, 308, 6, 22, "Print"],
Cell[959371, 26707, 39, 1, 22, "Print"],
Cell[959413, 26710, 300, 6, 22, "Print"],
Cell[959716, 26718, 310, 6, 22, "Print"],
Cell[960029, 26726, 308, 6, 22, "Print"],
Cell[960340, 26734, 39, 1, 22, "Print"],
Cell[960382, 26737, 300, 6, 22, "Print"],
Cell[960685, 26745, 310, 6, 22, "Print"],
Cell[960998, 26753, 308, 6, 22, "Print"],
Cell[961309, 26761, 39, 1, 22, "Print"],
Cell[961351, 26764, 525, 12, 24, "Print"],
Cell[961879, 26778, 533, 12, 24, "Print"],
Cell[962415, 26792, 526, 12, 22, "Print"],
Cell[962944, 26806, 39, 1, 22, "Print"],
Cell[962986, 26809, 300, 6, 22, "Print"],
Cell[963289, 26817, 310, 6, 22, "Print"],
Cell[963602, 26825, 308, 6, 22, "Print"],
Cell[963913, 26833, 39, 1, 22, "Print"],
Cell[963955, 26836, 300, 6, 22, "Print"],
Cell[964258, 26844, 310, 6, 22, "Print"],
Cell[964571, 26852, 308, 6, 22, "Print"],
Cell[964882, 26860, 39, 1, 22, "Print"],
Cell[964924, 26863, 300, 6, 22, "Print"],
Cell[965227, 26871, 310, 6, 22, "Print"],
Cell[965540, 26879, 308, 6, 22, "Print"],
Cell[965851, 26887, 39, 1, 22, "Print"],
Cell[965893, 26890, 300, 6, 22, "Print"],
Cell[966196, 26898, 310, 6, 22, "Print"],
Cell[966509, 26906, 308, 6, 22, "Print"],
Cell[966820, 26914, 39, 1, 22, "Print"],
Cell[966862, 26917, 300, 6, 22, "Print"],
Cell[967165, 26925, 310, 6, 22, "Print"],
Cell[967478, 26933, 308, 6, 22, "Print"],
Cell[967789, 26941, 39, 1, 22, "Print"],
Cell[967831, 26944, 526, 12, 24, "Print"],
Cell[968360, 26958, 537, 12, 24, "Print"],
Cell[968900, 26972, 531, 12, 22, "Print"],
Cell[969434, 26986, 39, 1, 22, "Print"],
Cell[969476, 26989, 302, 6, 22, "Print"],
Cell[969781, 26997, 312, 6, 22, "Print"],
Cell[970096, 27005, 310, 6, 22, "Print"],
Cell[970409, 27013, 39, 1, 22, "Print"],
Cell[970451, 27016, 302, 6, 22, "Print"],
Cell[970756, 27024, 312, 6, 22, "Print"],
Cell[971071, 27032, 310, 6, 22, "Print"],
Cell[971384, 27040, 39, 1, 22, "Print"],
Cell[971426, 27043, 302, 6, 22, "Print"],
Cell[971731, 27051, 312, 6, 22, "Print"],
Cell[972046, 27059, 310, 6, 22, "Print"],
Cell[972359, 27067, 39, 1, 22, "Print"],
Cell[972401, 27070, 302, 6, 22, "Print"],
Cell[972706, 27078, 312, 6, 22, "Print"],
Cell[973021, 27086, 310, 6, 22, "Print"],
Cell[973334, 27094, 39, 1, 22, "Print"],
Cell[973376, 27097, 302, 6, 22, "Print"],
Cell[973681, 27105, 312, 6, 22, "Print"],
Cell[973996, 27113, 310, 6, 22, "Print"],
Cell[974309, 27121, 39, 1, 22, "Print"],
Cell[974351, 27124, 527, 12, 24, "Print"],
Cell[974881, 27138, 537, 12, 24, "Print"],
Cell[975421, 27152, 531, 12, 22, "Print"],
Cell[975955, 27166, 39, 1, 22, "Print"],
Cell[975997, 27169, 302, 6, 22, "Print"],
Cell[976302, 27177, 312, 6, 22, "Print"],
Cell[976617, 27185, 310, 6, 22, "Print"],
Cell[976930, 27193, 39, 1, 22, "Print"],
Cell[976972, 27196, 302, 6, 22, "Print"],
Cell[977277, 27204, 312, 6, 22, "Print"],
Cell[977592, 27212, 310, 6, 22, "Print"],
Cell[977905, 27220, 39, 1, 22, "Print"],
Cell[977947, 27223, 302, 6, 22, "Print"],
Cell[978252, 27231, 312, 6, 22, "Print"],
Cell[978567, 27239, 310, 6, 22, "Print"],
Cell[978880, 27247, 39, 1, 22, "Print"],
Cell[978922, 27250, 302, 6, 22, "Print"],
Cell[979227, 27258, 312, 6, 22, "Print"],
Cell[979542, 27266, 310, 6, 22, "Print"],
Cell[979855, 27274, 39, 1, 22, "Print"],
Cell[979897, 27277, 302, 6, 22, "Print"],
Cell[980202, 27285, 312, 6, 22, "Print"],
Cell[980517, 27293, 310, 6, 22, "Print"],
Cell[980830, 27301, 39, 1, 22, "Print"],
Cell[980872, 27304, 527, 12, 24, "Print"],
Cell[981402, 27318, 537, 12, 24, "Print"],
Cell[981942, 27332, 531, 12, 22, "Print"],
Cell[982476, 27346, 39, 1, 22, "Print"],
Cell[982518, 27349, 302, 6, 22, "Print"],
Cell[982823, 27357, 312, 6, 22, "Print"],
Cell[983138, 27365, 310, 6, 22, "Print"],
Cell[983451, 27373, 39, 1, 22, "Print"],
Cell[983493, 27376, 302, 6, 22, "Print"],
Cell[983798, 27384, 312, 6, 22, "Print"],
Cell[984113, 27392, 310, 6, 22, "Print"],
Cell[984426, 27400, 39, 1, 22, "Print"],
Cell[984468, 27403, 302, 6, 22, "Print"],
Cell[984773, 27411, 312, 6, 22, "Print"],
Cell[985088, 27419, 310, 6, 22, "Print"],
Cell[985401, 27427, 39, 1, 22, "Print"],
Cell[985443, 27430, 302, 6, 22, "Print"],
Cell[985748, 27438, 312, 6, 22, "Print"],
Cell[986063, 27446, 310, 6, 22, "Print"],
Cell[986376, 27454, 39, 1, 22, "Print"],
Cell[986418, 27457, 302, 6, 22, "Print"],
Cell[986723, 27465, 312, 6, 22, "Print"],
Cell[987038, 27473, 310, 6, 22, "Print"],
Cell[987351, 27481, 39, 1, 22, "Print"],
Cell[987393, 27484, 528, 12, 24, "Print"],
Cell[987924, 27498, 539, 12, 24, "Print"],
Cell[988466, 27512, 531, 12, 22, "Print"],
Cell[989000, 27526, 39, 1, 22, "Print"],
Cell[989042, 27529, 302, 6, 22, "Print"],
Cell[989347, 27537, 312, 6, 22, "Print"],
Cell[989662, 27545, 310, 6, 22, "Print"],
Cell[989975, 27553, 39, 1, 22, "Print"],
Cell[990017, 27556, 302, 6, 22, "Print"],
Cell[990322, 27564, 312, 6, 22, "Print"],
Cell[990637, 27572, 310, 6, 22, "Print"],
Cell[990950, 27580, 39, 1, 22, "Print"],
Cell[990992, 27583, 302, 6, 22, "Print"],
Cell[991297, 27591, 312, 6, 22, "Print"],
Cell[991612, 27599, 310, 6, 22, "Print"],
Cell[991925, 27607, 39, 1, 22, "Print"],
Cell[991967, 27610, 302, 6, 22, "Print"],
Cell[992272, 27618, 312, 6, 22, "Print"],
Cell[992587, 27626, 310, 6, 22, "Print"],
Cell[992900, 27634, 39, 1, 22, "Print"],
Cell[992942, 27637, 302, 6, 22, "Print"],
Cell[993247, 27645, 312, 6, 22, "Print"],
Cell[993562, 27653, 310, 6, 22, "Print"],
Cell[993875, 27661, 39, 1, 22, "Print"],
Cell[993917, 27664, 529, 12, 24, "Print"],
Cell[994449, 27678, 539, 12, 24, "Print"],
Cell[994991, 27692, 530, 12, 22, "Print"],
Cell[995524, 27706, 39, 1, 22, "Print"],
Cell[995566, 27709, 302, 6, 22, "Print"],
Cell[995871, 27717, 312, 6, 22, "Print"],
Cell[996186, 27725, 310, 6, 22, "Print"],
Cell[996499, 27733, 39, 1, 22, "Print"],
Cell[996541, 27736, 302, 6, 22, "Print"],
Cell[996846, 27744, 312, 6, 22, "Print"],
Cell[997161, 27752, 310, 6, 22, "Print"],
Cell[997474, 27760, 39, 1, 22, "Print"],
Cell[997516, 27763, 302, 6, 22, "Print"],
Cell[997821, 27771, 312, 6, 22, "Print"],
Cell[998136, 27779, 310, 6, 22, "Print"],
Cell[998449, 27787, 39, 1, 22, "Print"],
Cell[998491, 27790, 302, 6, 22, "Print"],
Cell[998796, 27798, 312, 6, 22, "Print"],
Cell[999111, 27806, 310, 6, 22, "Print"],
Cell[999424, 27814, 39, 1, 22, "Print"],
Cell[999466, 27817, 302, 6, 22, "Print"],
Cell[999771, 27825, 312, 6, 22, "Print"],
Cell[1000086, 27833, 310, 6, 22, "Print"],
Cell[1000399, 27841, 39, 1, 22, "Print"],
Cell[1000441, 27844, 528, 12, 24, "Print"],
Cell[1000972, 27858, 537, 12, 24, "Print"],
Cell[1001512, 27872, 531, 12, 22, "Print"],
Cell[1002046, 27886, 39, 1, 22, "Print"],
Cell[1002088, 27889, 302, 6, 22, "Print"],
Cell[1002393, 27897, 312, 6, 22, "Print"],
Cell[1002708, 27905, 310, 6, 22, "Print"],
Cell[1003021, 27913, 39, 1, 22, "Print"],
Cell[1003063, 27916, 302, 6, 22, "Print"],
Cell[1003368, 27924, 312, 6, 22, "Print"],
Cell[1003683, 27932, 310, 6, 22, "Print"],
Cell[1003996, 27940, 39, 1, 22, "Print"],
Cell[1004038, 27943, 302, 6, 22, "Print"],
Cell[1004343, 27951, 312, 6, 22, "Print"],
Cell[1004658, 27959, 310, 6, 22, "Print"],
Cell[1004971, 27967, 39, 1, 22, "Print"],
Cell[1005013, 27970, 302, 6, 22, "Print"],
Cell[1005318, 27978, 312, 6, 22, "Print"],
Cell[1005633, 27986, 310, 6, 22, "Print"],
Cell[1005946, 27994, 39, 1, 22, "Print"],
Cell[1005988, 27997, 302, 6, 22, "Print"],
Cell[1006293, 28005, 312, 6, 22, "Print"],
Cell[1006608, 28013, 310, 6, 22, "Print"],
Cell[1006921, 28021, 39, 1, 22, "Print"],
Cell[1006963, 28024, 529, 12, 24, "Print"],
Cell[1007495, 28038, 539, 12, 24, "Print"],
Cell[1008037, 28052, 531, 12, 22, "Print"],
Cell[1008571, 28066, 39, 1, 22, "Print"],
Cell[1008613, 28069, 302, 6, 22, "Print"],
Cell[1008918, 28077, 312, 6, 22, "Print"],
Cell[1009233, 28085, 310, 6, 22, "Print"],
Cell[1009546, 28093, 39, 1, 22, "Print"],
Cell[1009588, 28096, 302, 6, 22, "Print"],
Cell[1009893, 28104, 312, 6, 22, "Print"],
Cell[1010208, 28112, 310, 6, 22, "Print"],
Cell[1010521, 28120, 39, 1, 22, "Print"],
Cell[1010563, 28123, 302, 6, 22, "Print"],
Cell[1010868, 28131, 312, 6, 22, "Print"],
Cell[1011183, 28139, 310, 6, 22, "Print"],
Cell[1011496, 28147, 39, 1, 22, "Print"],
Cell[1011538, 28150, 302, 6, 22, "Print"],
Cell[1011843, 28158, 312, 6, 22, "Print"],
Cell[1012158, 28166, 310, 6, 22, "Print"],
Cell[1012471, 28174, 39, 1, 22, "Print"],
Cell[1012513, 28177, 302, 6, 22, "Print"],
Cell[1012818, 28185, 312, 6, 22, "Print"],
Cell[1013133, 28193, 310, 6, 22, "Print"],
Cell[1013446, 28201, 39, 1, 22, "Print"],
Cell[1013488, 28204, 529, 12, 24, "Print"],
Cell[1014020, 28218, 538, 12, 24, "Print"],
Cell[1014561, 28232, 531, 12, 22, "Print"],
Cell[1015095, 28246, 39, 1, 22, "Print"],
Cell[1015137, 28249, 302, 6, 22, "Print"],
Cell[1015442, 28257, 312, 6, 22, "Print"],
Cell[1015757, 28265, 310, 6, 22, "Print"],
Cell[1016070, 28273, 39, 1, 22, "Print"],
Cell[1016112, 28276, 302, 6, 22, "Print"],
Cell[1016417, 28284, 312, 6, 22, "Print"],
Cell[1016732, 28292, 310, 6, 22, "Print"],
Cell[1017045, 28300, 39, 1, 22, "Print"],
Cell[1017087, 28303, 302, 6, 22, "Print"],
Cell[1017392, 28311, 312, 6, 22, "Print"],
Cell[1017707, 28319, 310, 6, 22, "Print"],
Cell[1018020, 28327, 39, 1, 22, "Print"],
Cell[1018062, 28330, 302, 6, 22, "Print"],
Cell[1018367, 28338, 312, 6, 22, "Print"],
Cell[1018682, 28346, 310, 6, 22, "Print"],
Cell[1018995, 28354, 39, 1, 22, "Print"],
Cell[1019037, 28357, 302, 6, 22, "Print"],
Cell[1019342, 28365, 312, 6, 22, "Print"],
Cell[1019657, 28373, 310, 6, 22, "Print"],
Cell[1019970, 28381, 39, 1, 22, "Print"],
Cell[1020012, 28384, 529, 12, 24, "Print"],
Cell[1020544, 28398, 538, 12, 24, "Print"],
Cell[1021085, 28412, 530, 12, 22, "Print"],
Cell[1021618, 28426, 39, 1, 22, "Print"],
Cell[1021660, 28429, 302, 6, 22, "Print"],
Cell[1021965, 28437, 312, 6, 22, "Print"],
Cell[1022280, 28445, 310, 6, 22, "Print"],
Cell[1022593, 28453, 39, 1, 22, "Print"],
Cell[1022635, 28456, 302, 6, 22, "Print"],
Cell[1022940, 28464, 312, 6, 22, "Print"],
Cell[1023255, 28472, 310, 6, 22, "Print"],
Cell[1023568, 28480, 39, 1, 22, "Print"],
Cell[1023610, 28483, 302, 6, 22, "Print"],
Cell[1023915, 28491, 312, 6, 22, "Print"],
Cell[1024230, 28499, 310, 6, 22, "Print"],
Cell[1024543, 28507, 39, 1, 22, "Print"],
Cell[1024585, 28510, 302, 6, 22, "Print"],
Cell[1024890, 28518, 312, 6, 22, "Print"],
Cell[1025205, 28526, 310, 6, 22, "Print"],
Cell[1025518, 28534, 39, 1, 22, "Print"],
Cell[1025560, 28537, 302, 6, 22, "Print"],
Cell[1025865, 28545, 312, 6, 22, "Print"],
Cell[1026180, 28553, 310, 6, 22, "Print"],
Cell[1026493, 28561, 39, 1, 22, "Print"],
Cell[1026535, 28564, 529, 12, 24, "Print"],
Cell[1027067, 28578, 538, 12, 24, "Print"],
Cell[1027608, 28592, 531, 12, 22, "Print"],
Cell[1028142, 28606, 39, 1, 22, "Print"],
Cell[1028184, 28609, 302, 6, 22, "Print"],
Cell[1028489, 28617, 312, 6, 22, "Print"],
Cell[1028804, 28625, 310, 6, 22, "Print"],
Cell[1029117, 28633, 39, 1, 22, "Print"],
Cell[1029159, 28636, 302, 6, 22, "Print"],
Cell[1029464, 28644, 312, 6, 22, "Print"],
Cell[1029779, 28652, 310, 6, 22, "Print"],
Cell[1030092, 28660, 39, 1, 22, "Print"],
Cell[1030134, 28663, 302, 6, 22, "Print"],
Cell[1030439, 28671, 312, 6, 22, "Print"],
Cell[1030754, 28679, 310, 6, 22, "Print"],
Cell[1031067, 28687, 39, 1, 22, "Print"],
Cell[1031109, 28690, 302, 6, 22, "Print"],
Cell[1031414, 28698, 312, 6, 22, "Print"],
Cell[1031729, 28706, 310, 6, 22, "Print"],
Cell[1032042, 28714, 39, 1, 22, "Print"],
Cell[1032084, 28717, 302, 6, 22, "Print"],
Cell[1032389, 28725, 312, 6, 22, "Print"],
Cell[1032704, 28733, 310, 6, 22, "Print"],
Cell[1033017, 28741, 39, 1, 22, "Print"],
Cell[1033059, 28744, 529, 12, 24, "Print"],
Cell[1033591, 28758, 538, 12, 24, "Print"],
Cell[1034132, 28772, 531, 12, 22, "Print"],
Cell[1034666, 28786, 39, 1, 22, "Print"],
Cell[1034708, 28789, 302, 6, 22, "Print"],
Cell[1035013, 28797, 312, 6, 22, "Print"],
Cell[1035328, 28805, 310, 6, 22, "Print"],
Cell[1035641, 28813, 39, 1, 22, "Print"],
Cell[1035683, 28816, 302, 6, 22, "Print"],
Cell[1035988, 28824, 312, 6, 22, "Print"],
Cell[1036303, 28832, 310, 6, 22, "Print"],
Cell[1036616, 28840, 39, 1, 22, "Print"],
Cell[1036658, 28843, 302, 6, 22, "Print"],
Cell[1036963, 28851, 312, 6, 22, "Print"],
Cell[1037278, 28859, 310, 6, 22, "Print"],
Cell[1037591, 28867, 39, 1, 22, "Print"],
Cell[1037633, 28870, 302, 6, 22, "Print"],
Cell[1037938, 28878, 312, 6, 22, "Print"],
Cell[1038253, 28886, 310, 6, 22, "Print"],
Cell[1038566, 28894, 39, 1, 22, "Print"],
Cell[1038608, 28897, 302, 6, 22, "Print"],
Cell[1038913, 28905, 312, 6, 22, "Print"],
Cell[1039228, 28913, 310, 6, 22, "Print"],
Cell[1039541, 28921, 39, 1, 22, "Print"],
Cell[1039583, 28924, 526, 12, 24, "Print"],
Cell[1040112, 28938, 539, 12, 24, "Print"],
Cell[1040654, 28952, 531, 12, 22, "Print"],
Cell[1041188, 28966, 39, 1, 22, "Print"],
Cell[1041230, 28969, 302, 6, 22, "Print"],
Cell[1041535, 28977, 312, 6, 22, "Print"],
Cell[1041850, 28985, 310, 6, 22, "Print"],
Cell[1042163, 28993, 39, 1, 22, "Print"],
Cell[1042205, 28996, 302, 6, 22, "Print"],
Cell[1042510, 29004, 312, 6, 22, "Print"],
Cell[1042825, 29012, 310, 6, 22, "Print"],
Cell[1043138, 29020, 39, 1, 22, "Print"],
Cell[1043180, 29023, 302, 6, 22, "Print"],
Cell[1043485, 29031, 312, 6, 22, "Print"],
Cell[1043800, 29039, 310, 6, 22, "Print"],
Cell[1044113, 29047, 39, 1, 22, "Print"],
Cell[1044155, 29050, 302, 6, 22, "Print"],
Cell[1044460, 29058, 312, 6, 22, "Print"],
Cell[1044775, 29066, 310, 6, 22, "Print"],
Cell[1045088, 29074, 39, 1, 22, "Print"],
Cell[1045130, 29077, 302, 6, 22, "Print"],
Cell[1045435, 29085, 312, 6, 22, "Print"],
Cell[1045750, 29093, 310, 6, 22, "Print"],
Cell[1046063, 29101, 39, 1, 22, "Print"],
Cell[1046105, 29104, 529, 12, 24, "Print"],
Cell[1046637, 29118, 539, 12, 24, "Print"],
Cell[1047179, 29132, 531, 12, 22, "Print"],
Cell[1047713, 29146, 39, 1, 22, "Print"],
Cell[1047755, 29149, 302, 6, 22, "Print"],
Cell[1048060, 29157, 312, 6, 22, "Print"],
Cell[1048375, 29165, 310, 6, 22, "Print"],
Cell[1048688, 29173, 39, 1, 22, "Print"],
Cell[1048730, 29176, 302, 6, 22, "Print"],
Cell[1049035, 29184, 312, 6, 22, "Print"],
Cell[1049350, 29192, 310, 6, 22, "Print"],
Cell[1049663, 29200, 39, 1, 22, "Print"],
Cell[1049705, 29203, 302, 6, 22, "Print"],
Cell[1050010, 29211, 312, 6, 22, "Print"],
Cell[1050325, 29219, 310, 6, 22, "Print"],
Cell[1050638, 29227, 39, 1, 22, "Print"],
Cell[1050680, 29230, 302, 6, 22, "Print"],
Cell[1050985, 29238, 312, 6, 22, "Print"],
Cell[1051300, 29246, 310, 6, 22, "Print"],
Cell[1051613, 29254, 39, 1, 22, "Print"],
Cell[1051655, 29257, 302, 6, 22, "Print"],
Cell[1051960, 29265, 312, 6, 22, "Print"],
Cell[1052275, 29273, 310, 6, 22, "Print"],
Cell[1052588, 29281, 39, 1, 22, "Print"],
Cell[1052630, 29284, 529, 12, 24, "Print"],
Cell[1053162, 29298, 538, 12, 24, "Print"],
Cell[1053703, 29312, 531, 12, 22, "Print"],
Cell[1054237, 29326, 39, 1, 22, "Print"],
Cell[1054279, 29329, 302, 6, 22, "Print"],
Cell[1054584, 29337, 312, 6, 22, "Print"],
Cell[1054899, 29345, 310, 6, 22, "Print"],
Cell[1055212, 29353, 39, 1, 22, "Print"],
Cell[1055254, 29356, 302, 6, 22, "Print"],
Cell[1055559, 29364, 312, 6, 22, "Print"],
Cell[1055874, 29372, 310, 6, 22, "Print"],
Cell[1056187, 29380, 39, 1, 22, "Print"],
Cell[1056229, 29383, 70, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1056336, 29389, 46, 1, 27, "Input"],
Cell[1056385, 29392, 41, 1, 26, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

